@@ -41,13 +41,12 @@
 #include <kprocess.h>
 
 // ark includes
-#include "arkwidgetbase.h"
-#include "arksettings.h"
+#include "arkwidget.h"
+#include "settings.h"
 #include "ar.h"
 
-ArArch::ArArch( ArkSettings *_settings, ArkWidgetBase *_gui,
-		  const QString & _fileName )
-  : Arch(_settings, _gui, _fileName )
+ArArch::ArArch( ArkWidget *_gui, const QString & _fileName )
+  : Arch(_gui, _fileName )
 {
   m_archiver_program = "ar";
   m_unarchiver_program = QString::null;
@@ -108,7 +107,7 @@ void ArArch::open()
 
   if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
     {
-      KMessageBox::error( 0, i18n("Couldn't start a subprocess.") );
+      KMessageBox::error( 0, i18n("Could not start a subprocess.") );
       emit sigOpen(this, false, QString::null, 0 );
     }
   kdDebug(1601) << "-ArArch::open" << endl;
@@ -127,14 +126,14 @@ void ArArch::create()
 
   if (kp->start(KProcess::Block) == false)
     {
-      KMessageBox::error( 0, i18n("Couldn't start a subprocess.") );
+      KMessageBox::error( 0, i18n("Could not start a subprocess.") );
       emit sigCreate(this, false, m_filename,
-		     Arch::Extract | Arch::Delete | Arch::Add 
+		     Arch::Extract | Arch::Delete | Arch::Add
 		     | Arch::View);
     }
   else
     emit sigCreate(this, true, m_filename,
-		   Arch::Extract | Arch::Delete | Arch::Add 
+		   Arch::Extract | Arch::Delete | Arch::Add
 		   | Arch::View);
 }
 
@@ -144,41 +143,23 @@ void ArArch::addFile( QStringList *urls )
   KProcess *kp = new KProcess;
   kp->clearArguments();
   *kp << m_archiver_program;
-	
-  if (m_settings->getAddReplaceOnlyWithNewer())
+
+  if (Settings::replaceOnlyWithNewer())
 	  *kp << "ru";
   else
 	  *kp << "r";
 
   *kp << m_filename;
 
-  QString base;
-  QString url;
-  QString file;
-
-	
   QStringList::ConstIterator iter;
+  KURL url( urls->first() );
+  QDir::setCurrent( url.directory() );
   for (iter = urls->begin(); iter != urls->end(); ++iter )
   {
-    url = *iter;
-    // comment out for now until I figure out what happened to this function!
-    //    KURL::decodeURL(url); // Because of special characters
-    file = url.right(url.length()-5);
-
-    if( file[file.length()-1]=='/' )
-      file[file.length()-1]='\0';
-    if( ! m_settings->getaddPath() )
-    {
-      int pos;
-      pos = file.findRev( '/' );
-      base = file.left( pos );
-      pos++;
-      QDir::setCurrent(base);
-      base = file.right( file.length()-pos );
-      file = base;
-    }
-    *kp << file;
+    KURL fileURL( *iter );
+    *kp << fileURL.fileName();
   }
+
   connect( kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
 	   this, SLOT(slotReceivedOutput(KProcess*, char*, int)));
   connect( kp, SIGNAL(receivedStderr(KProcess*, char*, int)),
@@ -189,7 +170,7 @@ void ArArch::addFile( QStringList *urls )
 
   if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
     {
-      KMessageBox::error( 0, i18n("Couldn't start a subprocess.") );
+      KMessageBox::error( 0, i18n("Could not start a subprocess.") );
       emit sigAdd(false);
     }
 
@@ -216,26 +197,26 @@ void ArArch::unarchFile(QStringList *_fileList, const QString & _destDir, bool )
 
   bool ret = QDir::setCurrent(dest);
  // I already checked the validity of the dir before coming here
-  Q_ASSERT(ret); 
+  Q_ASSERT(ret);
 
   KProcess *kp = new KProcess;
   kp->clearArguments();
-  
+
   *kp << m_archiver_program;
   *kp << "vx";
   *kp << m_filename;
-  
+
   // if the list is empty, no filenames go on the command line,
   // and we then extract everything in the archive.
   if (_fileList)
     {
       for ( QStringList::Iterator it = _fileList->begin();
-	    it != _fileList->end(); ++it ) 
+	    it != _fileList->end(); ++it )
 	{
 	  *kp << (*it);
 	}
     }
- 
+
   connect( kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
 	   this, SLOT(slotReceivedOutput(KProcess*, char*, int)));
   connect( kp, SIGNAL(receivedStderr(KProcess*, char*, int)),
@@ -243,10 +224,10 @@ void ArArch::unarchFile(QStringList *_fileList, const QString & _destDir, bool )
 
   connect( kp, SIGNAL(processExited(KProcess*)), this,
 	   SLOT(slotExtractExited(KProcess*)));
-  
+
   if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
     {
-      KMessageBox::error( 0, i18n("Couldn't start a subprocess.") );
+      KMessageBox::error( 0, i18n("Could not start a subprocess.") );
       emit sigExtract(false);
     }
 }
@@ -261,7 +242,7 @@ void ArArch::remove(QStringList *list)
   m_shellErrorData = "";
   KProcess *kp = new KProcess;
   kp->clearArguments();
-  
+
   *kp << m_archiver_program << "d" << m_filename;
   for ( QStringList::Iterator it = list->begin();
 	it != list->end(); ++it )
@@ -280,10 +261,10 @@ void ArArch::remove(QStringList *list)
 
   if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
     {
-      KMessageBox::error( 0, i18n("Couldn't start a subprocess.") );
+      KMessageBox::error( 0, i18n("Could not start a subprocess.") );
       emit sigDelete(false);
     }
-  
+
   kdDebug(1601) << "-ArArch::remove" << endl;
 }
 
