@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: ar.h,v 1.21 2003/03/07 22:06:46 waba Exp $
+ $Id: ar.h,v 1.23 2004/05/31 20:31:43 bmeyer Exp $
 
  ark -- archiver for the KDE project
 
@@ -35,14 +35,13 @@ class QCString;
 class QStringList;
 
 class Arch;
-class ArkSettings;
-class ArkWidgetBase;
+class ArkWidget;
 
 class ArArch : public Arch 
 {
   Q_OBJECT
 public:
-  ArArch( ArkSettings *_settings, ArkWidgetBase *_gui,
+  ArArch( ArkWidget *_gui,
 	   const QString & _fileName );
   virtual ~ArArch() {}
 
