@@ -44,8 +44,7 @@
 
 // ark includes
 #include "arch.h"
-#include "arksettings.h"
-#include "arkwidgetbase.h"
+#include "arkwidget.h"
 #include "arkutils.h"
 
 // the archive types
@@ -64,9 +63,9 @@ Arch::ArchColumns::ArchColumns(int col, QRegExp reg, int length, bool opt) :
 }
 
 
-Arch::Arch(ArkSettings *_settings, ArkWidgetBase *_viewer,
+Arch::Arch( ArkWidget *_viewer,
 	   const QString & _fileName )
-  : m_filename(_fileName), m_buffer(""), m_settings(_settings),
+  : m_filename(_fileName), m_buffer(""),
     m_gui(_viewer), m_bReadOnly(false), m_bNotifyWhenDeleteFails(true),
     m_header_removed(false), m_finished(false),
 	m_numCols(0), m_dateCol(-1), m_fixYear(-1), m_fixMonth(-1),
@@ -102,24 +101,6 @@ void Arch::slotCancel()
   //  m_kp->kill();
 }
 
-void Arch::slotStoreDataStdout(KProcess*, char* _data, int _length)
-{
-  char c = _data[_length];
-  _data[_length] = '\0';
-
-  m_settings->appendShellOutputData( _data );
-  _data[_length] = c;
-}
-
-void Arch::slotStoreDataStderr(KProcess*, char* _data, int _length)
-{
-  char c = _data[_length];
-  _data[_length] = '\0';
-
-  m_shellErrorData.append( _data );
-  _data[_length] = c;
-}
-
 void Arch::slotOpenExited(KProcess* _kp)
 {
   kdDebug(1601) << "normalExit = " << _kp->normalExit() << endl;
@@ -161,8 +142,8 @@ void Arch::slotDeleteExited(KProcess *_kp)
       if(stderrIsError())
 	{
 	  QApplication::restoreOverrideCursor();
-	  KMessageBox::error(m_gui->getArkWidget(),
-		 i18n("You probably don't have sufficient permissions.\n"
+	  KMessageBox::error(m_gui,
+		 i18n("You probably do not have sufficient permissions.\n"
 		      "Please check the file owner and the integrity "
 		      "of the archive.") );
 	}
@@ -174,7 +155,7 @@ void Arch::slotDeleteExited(KProcess *_kp)
       if (m_bNotifyWhenDeleteFails)
 	{
 	  QApplication::restoreOverrideCursor();
-	  KMessageBox::sorry(m_gui->getArkWidget(), i18n("The deletion failed."),
+	  KMessageBox::sorry(m_gui, i18n("The deletion failed."),
 			     i18n("Error") );
 	}
       else bSuccess = true;
@@ -202,7 +183,7 @@ void Arch::slotExtractExited(KProcess *_kp)
       if(stderrIsError())
 	{
 	  QApplication::restoreOverrideCursor();
-	  int ret = KMessageBox::warningYesNo(m_gui->getArkWidget(),
+	  int ret = KMessageBox::warningYesNo(m_gui,
 		i18n("The extract operation failed.\n"
 		     "Do you wish to view the shell output?"), i18n("Error"));
 	  if (ret == KMessageBox::Yes)
@@ -234,8 +215,8 @@ void Arch::slotAddExited(KProcess *_kp)
       if(stderrIsError())
 	{
 	  QApplication::restoreOverrideCursor();
-	  KMessageBox::error(m_gui->getArkWidget(),
-			     i18n("You probably don't have sufficient permissions.\n"
+	  KMessageBox::error(m_gui,
+			     i18n("You probably do not have sufficient permissions.\n"
 				  "Please check the file owner and the integrity "
 				  "of the archive."));
 	}
@@ -245,7 +226,7 @@ void Arch::slotAddExited(KProcess *_kp)
   else
     {
       QApplication::restoreOverrideCursor();
-      int ret = KMessageBox::warningYesNo(m_gui->getArkWidget(),
+      int ret = KMessageBox::warningYesNo(m_gui,
 		 i18n("The add operation failed.\n"
 		      "Do you wish to view the shell output?"), i18n("Error"));
 	  if (ret == KMessageBox::Yes)
@@ -269,7 +250,7 @@ void Arch::slotReceivedOutput(KProcess*, char* _data, int _length)
   char c = _data[_length];
   _data[_length] = '\0';
 
-  m_settings->appendShellOutputData( _data );
+  appendShellOutputData( _data );
   _data[_length] = c;
 }
 
@@ -279,7 +260,7 @@ void Arch::slotReceivedTOC(KProcess*, char* _data, int _length)
   char c = _data[_length];
   _data[_length] = '\0';
 
-  m_settings->appendShellOutputData( _data );
+  appendShellOutputData( _data );
 
   int lfChar, startChar = 0;
 
@@ -384,20 +365,19 @@ bool Arch::processLine(const QCString &line)
 }
 
 
-Arch *Arch::archFactory(ArchType aType, ArkSettings *settings,
-            ArkWidgetBase *parent, const QString &filename,
+Arch *Arch::archFactory(ArchType aType,
+            ArkWidget *parent, const QString &filename,
             const QString & openAsMimeType )
 {
 	switch(aType)
 	{
-	case TAR_FORMAT: return new TarArch(settings, parent, filename, openAsMimeType);
-	case ZIP_FORMAT: return new ZipArch(settings, parent, filename);
-	case LHA_FORMAT: return new LhaArch(settings, parent, filename);
-	case COMPRESSED_FORMAT: return new CompressedFile(settings,
-							  parent, filename, openAsMimeType);
-	case ZOO_FORMAT: return new ZooArch(settings, parent, filename);
-	case RAR_FORMAT: return new RarArch(settings, parent, filename);
-	case AA_FORMAT: return new ArArch(settings, parent, filename);
+	case TAR_FORMAT: return new TarArch(parent, filename, openAsMimeType);
+	case ZIP_FORMAT: return new ZipArch(parent, filename);
+	case LHA_FORMAT: return new LhaArch(parent, filename);
+	case COMPRESSED_FORMAT: return new CompressedFile(parent, filename, openAsMimeType);
+	case ZOO_FORMAT: return new ZooArch(parent, filename);
+	case RAR_FORMAT: return new RarArch(parent, filename);
+	case AA_FORMAT: return new ArArch(parent, filename);
 	case UNKNOWN_FORMAT:
 	default: return 0;
 	}
