@@ -52,9 +52,9 @@
 #include <qobject.h>
 #include <qptrlist.h>	// Some very annoying hackery in arkwidgetpart
 #include <qregexp.h>
+#include <qstring.h>
 #include <kurl.h>
 
-class QString;
 class QCString;
 template<class type> class QPtrList;
 class QRegExp;
@@ -62,8 +62,7 @@ class QStringList;
 class KProcess;
 
 class FileListView;
-class ArkSettings;
-class ArkWidgetBase;
+class ArkWidget;
 
 enum ArchType {UNKNOWN_FORMAT, ZIP_FORMAT, TAR_FORMAT, AA_FORMAT,
 	       LHA_FORMAT, RAR_FORMAT, ZOO_FORMAT, COMPRESSED_FORMAT};
@@ -96,7 +95,7 @@ protected:
   };
 
 public:
-  Arch(ArkSettings *_settings, ArkWidgetBase *_viewer,
+  Arch( ArkWidget *_viewer,
        const QString & _fileName);
   virtual ~Arch();
 
@@ -135,14 +134,16 @@ public:
 
   QString getUtility() { return m_archiver_program; }
 
-  static Arch *archFactory(ArchType aType, ArkSettings *settings,
-                ArkWidgetBase *parent, const QString &filename,
+  void appendShellOutputData( const char * data ) { m_lastShellOutput.append( data ); }
+  void clearShellOutput() { m_lastShellOutput.truncate( 0 ); }
+  const QString& getLastShellOutput() const { return m_lastShellOutput; }
+
+  static Arch *archFactory(ArchType aType,
+                ArkWidget *parent, const QString &filename,
                 const QString &openAsMimeType = QString::null );
 
 protected slots:
   void slotCancel();
-  void slotStoreDataStdout(KProcess*, char*, int);
-  void slotStoreDataStderr(KProcess*, char*, int);
   void slotOpenExited(KProcess*);
 
   void slotExtractExited(KProcess*);
@@ -164,9 +165,9 @@ signals:
 protected:  // data
   QString m_filename;
   QString m_shellErrorData;
+  QString m_lastShellOutput;
   QCString m_buffer;
-  ArkSettings *m_settings;
-  ArkWidgetBase *m_gui;
+  ArkWidget *m_gui;
   bool m_bReadOnly; // for readonly archives
   bool m_error;
 
