@@ -15,11 +15,12 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
 #include <kaboutdata.h>
+#include <kinstance.h>
 
 #include "ark_part.h"
 #include "arkfactory.h"
@@ -28,13 +29,7 @@ KInstance* ArkFactory::s_instance = 0L;
 KAboutData* ArkFactory::s_about = 0L;
 int ArkFactory::instanceNumber = 0;
 
-extern "C"
-{
-    void* init_libarkpart()
-    {
-        return new ArkFactory;
-    }
-}
+K_EXPORT_COMPONENT_FACTORY( libarkpart, ArkFactory )
 
 ArkFactory::~ArkFactory()
 {
