@@ -34,6 +34,9 @@
 
 // Qt includes
 #include <qlayout.h>
+#include <qstringlist.h>
+#include <qlabel.h>
+#include <qcheckbox.h>
 
 // KDE includes
 #include <kdebug.h>
@@ -51,19 +54,49 @@
 #include <kfiledialog.h>
 #include <kdirselectdialog.h>
 #include <kurldrag.h>
+#include <klistviewsearchline.h>
+#include <ktoolbar.h>
+#include <kconfigdialog.h>
+#include <ktrader.h>
+
+// settings
+#include "settings.h"
+#include "general.h"
+#include "addition.h"
+#include "extraction.h"
+#include "folders.h"
+#include <kpopupmenu.h>
+#include <kdialog.h>
 
 // ark includes
 #include "arkapp.h"
-#include "generalOptDlg.h"
 #include "selectDlg.h"
 #include "archiveformatdlg.h"
 #include "extractdlg.h"
 #include "arkwidget.h"
 #include "filelistview.h"
-#include "arksettings.h"
 #include "arkutils.h"
 #include "archiveformatinfo.h"
 #include "compressedfile.h"
+#include "searchbar.h"
+#include "shellOutputDlg.h"
+#include "arkviewer.h"
+
+static void viewInExternalViewer( ArkWidget* parent, const QString& filename )
+{
+    QString mimetype = KMimeType::findByURL( filename )->name();
+    bool view = true;
+
+    if ( KRun::isExecutable( mimetype ) )
+    {
+        QString text = i18n( "The file you're trying to view may be an executable. Running untrusted executables may compromise your system's security.\nAre you sure you want to run that file?" );
+        view = ( KMessageBox::warningYesNo( parent, text ) == KMessageBox::Yes );
+    }
+
+    if ( view )
+        KRun::runURL( filename, mimetype );
+
+}
 
 //----------------------------------------------------------------------
 //
@@ -72,32 +105,145 @@
 //----------------------------------------------------------------------
 
 ArkWidget::ArkWidget( QWidget *parent, const char *name ) :
-        QWidget(parent, name), ArkWidgetBase(this),
-        m_bBusy( false ), m_bBusyHold( false ), m_extractOnly(false),
-        m_extractRemote(false), m_openAsMimeType(QString::null),
-        m_pTempAddList(NULL), mpDownloadedList(NULL),
-        m_bArchivePopupEnabled( false ), m_convert_tmpDir( NULL ),
-        m_convertSuccess( false ), m_createRealArchTmpDir( NULL ),
-        m_extractRemoteTmpDir( NULL ), m_modified( false )
+        QVBox(parent, name), m_bBusy( false ), m_bBusyHold( false ),
+	m_extractOnly( false ), m_extractRemote(false), 
+	m_openAsMimeType(QString::null), m_pTempAddList(NULL), 
+	mpDownloadedList(NULL), m_bArchivePopupEnabled( false ), 
+	m_convert_tmpDir( NULL ), m_convertSuccess( false ),
+	m_createRealArchTmpDir( NULL ),	m_extractRemoteTmpDir( NULL ),
+	m_modified( false ), m_searchToolBar( 0 ), m_searchBar( 0 ),
+	arch( 0 ), archiveContent( 0 ),
+	m_archType( UNKNOWN_FORMAT ), m_nSizeOfFiles( 0 ),
+	m_nSizeOfSelectedFiles( 0 ), m_nNumFiles( 0 ), m_nNumSelectedFiles( 0 ),
+	m_bIsArchiveOpen( false ), m_bIsSimpleCompressedFile( false ),
+	m_bDropSourceIsSelf( false ), m_extractList( 0 )
 {
-    kdDebug(1601) << "+ArkWidget::ArkWidget" << endl;
-    QHBoxLayout * l = new QHBoxLayout( this );
-    l->setAutoAdd( true );
+    m_tmpDir = new KTempDir( locateLocal( "tmp", "ark" ) );
+
+    if ( m_tmpDir->status() != 0 )
+    {
+	    kdWarning( 1601 ) << "Could not create a temporary directory. status() returned "
+	                      << m_tmpDir->status() << "." << endl;
+	    m_tmpDir = NULL;
+    }
+	
+    m_searchToolBar = new KToolBar( this, "searchBar" );
+    m_searchToolBar->boxLayout()->setSpacing( KDialog::spacingHint() );
+
+    QLabel * l1 = new QLabel( i18n( "&Search:" ), m_searchToolBar, "kde toolbar widget" );
+    m_searchBar = new SearchBar( m_searchToolBar, 0 );
+    l1->setBuddy( m_searchBar );
+
+    m_searchToolBar->setStretchableWidget( m_searchBar );
+
+    if ( !Settings::showSearchBar() )
+        m_searchToolBar->hide();
+    
     createFileListView();
+
+    m_searchBar->setListView( archiveContent );
+
     // enable DnD
     setAcceptDrops(true);
-    kdDebug(1601) << "-ArkWidget::ArkWidget" << endl;
 }
 
 ArkWidget::~ArkWidget()
 {
     cleanArkTmpDir();
     ready();
-    kdDebug(1601) << "-ArkWidget::~ArkWidget" << endl;
     delete mpDownloadedList;
     delete m_pTempAddList;
+    delete archiveContent;
+    archiveContent = 0;
+    delete arch;
+    Settings::writeConfig();
 }
 
+void ArkWidget::cleanArkTmpDir()
+{
+	if ( m_tmpDir )
+	{
+		m_tmpDir->unlink();
+		delete m_tmpDir;
+		m_tmpDir = NULL;
+	}
+	return;
+}
+
+const FileLVI * ArkWidget::getFileLVI( const QString& _filename ) const
+{
+	FileLVI * flvi = ( FileLVI* ) archiveContent->firstChild();
+	
+	while ( flvi )
+	{
+		QString curFilename = flvi->fileName();
+		if ( curFilename == _filename )
+			return flvi;
+		flvi = ( FileLVI* ) flvi->itemBelow();
+	}
+	
+	return 0;
+}
+
+void ArkWidget::setHeaders( QStringList* _headers, int * _rightAlignCols, int _numColsToAlignRight )
+{
+	clearHeaders();
+
+	for ( QStringList::Iterator it = _headers->begin(); it != _headers->end(); ++it )
+	{
+		QString str = *it;
+		archiveContent->addColumn( str );
+	}
+
+	for ( int i = 0; i < _numColsToAlignRight; ++i )
+	{
+		archiveContent->setColumnAlignment( _rightAlignCols[ i ], QListView::AlignRight );
+	}
+}
+
+void ArkWidget::clearHeaders()
+{
+	while ( archiveContent->columns() > 0 )
+	{
+		archiveContent->removeColumn( 0 );
+	}
+}
+
+void ArkWidget::listingAdd( QStringList * _entries )
+{
+	FileLVI *flvi = new FileLVI( archiveContent );
+
+	int i = 0;
+	
+	for ( QStringList::Iterator it = _entries->begin(); it != _entries->end(); ++it )
+	{
+		flvi->setText( i, *it );
+		++i;
+	}
+}
+
+void ArkWidget::viewShellOutput()
+{
+	ShellOutputDlg* sod = new ShellOutputDlg( arch->getLastShellOutput(), this );
+	sod->exec();
+	delete sod;
+}
+
+void ArkWidget::closeArch()
+{
+	if ( isArchiveOpen() )
+	{
+		delete arch;
+		arch = 0;
+		m_bIsArchiveOpen = false;
+	}
+
+	if ( 0 != archiveContent )
+	{
+		archiveContent->clear();
+		clearHeaders();
+	}
+}
 
 ////////////////////////////////////////////////////////////////////
 ///////////////////////// updateStatusTotals ///////////////////////
@@ -126,7 +272,6 @@ ArkWidget::updateStatusTotals()
 void
 ArkWidget::busy( const QString & text )
 {
-    kdDebug( 1601 ) << "ArkWidget::busy()+" << endl;
     emit setBusy( text );
 
     if ( m_bBusy )
@@ -134,7 +279,6 @@ ArkWidget::busy( const QString & text )
 
     QApplication::setOverrideCursor( waitCursor );
     m_bBusy = true;
-    kdDebug( 1601 ) << "ArkWidget::busy()-" << endl;
 }
 
 void
@@ -160,7 +304,6 @@ ArkWidget::resumeBusy()
 void
 ArkWidget::ready()
 {
-    kdDebug( 1601 ) << "ArkWidget::ready()+" << endl;
     if ( !m_bBusy )
         return;
 
@@ -168,7 +311,6 @@ ArkWidget::ready()
     emit setReady();
     m_bBusyHold = false;
     m_bBusy = false;
-    kdDebug( 1601 ) << "ArkWidget::ready()-" << endl;
 }
 
 //////////////////////////////////////////////////////////////////////
@@ -217,7 +359,7 @@ void
 ArkWidget::convertTo( const KURL & u )
 {
     busy( i18n( "Saving..." ) );
-    m_convert_tmpDir =  new KTempDir( m_settings->getTmpDir() + "convtmp" );
+    m_convert_tmpDir =  new KTempDir( tmpDir() + "convtmp" );
     m_convert_tmpDir->setAutoDelete( true );
     connect( arch, SIGNAL( sigExtract( bool ) ), this, SLOT( convertSlotExtractDone( bool ) ) );
     m_convert_saveAsURL = u;
@@ -241,7 +383,7 @@ ArkWidget::convertSlotCreate()
     if ( m_convert_saveAsURL.isLocalFile() )
         archToCreate = m_convert_saveAsURL.path();
     else
-        archToCreate = m_settings->getTmpDir() + m_convert_saveAsURL.fileName();
+        archToCreate = tmpDir() + m_convert_saveAsURL.fileName();
 
     createArchive( archToCreate );
 }
@@ -276,10 +418,10 @@ ArkWidget::convertSlotCreateDone( bool success )
         //////////////////////////////////////////////////////
         *it = QString::fromLatin1( "file:" )+ m_convert_tmpDir->name() + *it;
     }
-    bool bOldRecVal = m_settings->getZipAddRecurseDirs();
+    bool bOldRecVal = Settings::rarRecurseSubdirs();
     connect( arch, SIGNAL( sigAdd( bool ) ), this, SLOT( convertSlotAddDone( bool ) ) );
     arch->addFile( &entries );
-    m_settings->setZipAddRecurseDirs( bOldRecVal );
+    Settings::setRarRecurseSubdirs( bOldRecVal );
 }
 
 void
@@ -308,7 +450,7 @@ ArkWidget::convertFinish()
         }
         else
         {
-            KIO::NetAccess::upload( m_settings->getTmpDir()
+            KIO::NetAccess::upload( tmpDir()
                        + m_convert_saveAsURL.fileName(), m_convert_saveAsURL, this );
             // TODO: save bandwidth - we already have a local tmp file ...
             emit openURLRequest( m_convert_saveAsURL );
@@ -396,7 +538,7 @@ ArkWidget::extractToSlotOpenDone( bool success )
     // little code duplication from action_extract():
     if ( !m_extractTo_targetDirectory.isLocalFile() )
     {
-        m_extractRemoteTmpDir = new KTempDir( m_settings->getTmpDir() + "extremote" );
+        m_extractRemoteTmpDir = new KTempDir( tmpDir() + "extremote" );
         m_extractRemoteTmpDir->setAutoDelete( true );
 
         extractDir = m_extractRemoteTmpDir->name();
@@ -415,7 +557,7 @@ ArkWidget::extractToSlotOpenDone( bool success )
     QStringList alreadyExisting = existingFiles( extractDir, empty );
     kdDebug( 1601 ) << "Already existing files count: " << existingFiles( extractDir, empty ).count() << endl;
     bool keepGoing = true;
-    if ( !m_settings->getExtractOverwrite() && !alreadyExisting.isEmpty() )
+    if ( !Settings::extractOverwrite() && !alreadyExisting.isEmpty() )
     {
        if ( alreadyExisting.count() == m_nNumFiles )
         {
@@ -453,7 +595,7 @@ ArkWidget::extractToSlotExtractDone( bool success )
     disconnect( arch, SIGNAL( sigExtract( bool ) ), this, SLOT( extractToSlotExtractDone( bool ) ) );
     if ( !success )
     {
-        kdDebug( 1601 ) << "Last Shell Output" << *( m_settings->getLastShellOutput() ) << endl;
+        kdDebug( 1601 ) << "Last Shell Output" << arch->getLastShellOutput() << endl;
         KMessageBox::error( this, i18n( "An error occurred while extracting the archive." ) );
         emit request_file_quit();
         return;
@@ -496,7 +638,7 @@ ArkWidget::addToArchive( const KURL::List & filesToAdd, const KURL & archive)
         if ( archive.isLocalFile() )
             createArchive( archive.path() );
         else
-            createArchive( m_settings->getTmpDir() + archive.fileName() );
+            createArchive( tmpDir() + archive.fileName() );
 
 
         return;
@@ -548,7 +690,7 @@ ArkWidget::addToArchiveSlotOpenDone( bool success )
     }
 
     QStringList list = m_addToArchive_filesToAdd.toStringList();
-    if ( !ArkUtils::diskHasSpace( m_strArchName, ArkUtils::getSizes( &list ) ) )
+    if ( !ArkUtils::diskHasSpace( tmpDir(), ArkUtils::getSizes( &list ) ) )
     {
         KMessageBox::error( this, i18n( "Not enough free disc space to extract the archive." ) );
         emit request_file_quit();
@@ -644,7 +786,7 @@ ArkWidget::file_open(const KURL& url)
     // Set the current archive filename to the filename
     m_strArchName = strFile;
     m_url = url;
-    m_settings->clearShellOutput();
+    //arch->clearShellOutput();
 
     openArchive( strFile );
 
@@ -748,7 +890,6 @@ ArkWidget::file_new()
     strFile = url.path();
     if (!strFile.isEmpty())
     {
-        m_settings->clearShellOutput();
         file_close();
         createArchive( strFile );
     }
@@ -757,12 +898,17 @@ ArkWidget::file_new()
 void
 ArkWidget::extractOnlyOpenDone()
 {
-    int oldMode = m_settings->getExtractDirMode();
-    QString oldFixedExtractDir = m_settings->getFixedExtractDir();
-    m_settings->setExtractDirCfg( m_url.upURL().path(), ArkSettings::FIXED_EXTRACT_DIR );
+    int oldMode = Settings::extractDirMode();
+    QString oldFixedExtractDir = Settings::extractDir();
+
+    Settings::setLastExtractDir( m_url.upURL().path() );
+    Settings::setExtractDirMode( 2 ); // 2 means use custom dir
+    
     bool done = action_extract();
     // Extract should have started before this returns, so hopefully safe.
-    m_settings->setExtractDirCfg( oldFixedExtractDir, oldMode );
+    Settings::setLastExtractDir( oldFixedExtractDir );
+    Settings::setExtractDirMode( oldMode );
+    
     // last extract dir is still set, but this is not a problem
     if( !done )
     {
@@ -852,10 +998,8 @@ ArkWidget::slotExtractRemoteDone(KIO::Job *job)
 void
 ArkWidget::disableAll() // private
 {
-    kdDebug(1601) << "+ArkWidget::disableAll" << endl;
     emit disableAllActions();
     archiveContent->setUpdatesEnabled(true);
-    kdDebug(1601) << "-ArkWidget::disableAll" << endl;
 }
 
 void
@@ -894,11 +1038,10 @@ ArkWidget::file_close()
 void
 ArkWidget::edit_select()
 {
-    SelectDlg *sd = new SelectDlg( m_settings, this );
+    SelectDlg *sd = new SelectDlg( this );
     if ( sd->exec() )
     {
         QString exp = sd->getRegExp();
-        m_settings->setSelectRegExp( exp );
 
         QRegExp reg_exp( exp, true, true );
         if (!reg_exp.isValid())
@@ -1013,7 +1156,7 @@ ArkWidget::createRealArchive( const QString & strFilename, const QStringList & f
     m_compressedFile = static_cast< CompressedFile * >( arch )->tempFileName();
     KURL u1, u2;
     u1.setPath( m_compressedFile );
-    m_createRealArchTmpDir = new KTempDir( m_settings->getTmpDir() + "create_real_arch" );
+    m_createRealArchTmpDir = new KTempDir( tmpDir() + "create_real_arch" );
     u2.setPath( m_createRealArchTmpDir->name() + u1.fileName() );
     KIO::NetAccess::copy( u1, u2, this );
     m_compressedFile = "file:" + u2.path(); // AGAIN THE 5 SPACES Hack :-(
@@ -1105,9 +1248,8 @@ ArkWidget::action_add()
         }
         return;
     }
-    kdDebug(1601) << "Add dir: " << m_settings->getAddDir() << endl;
 
-    KFileDialog fileDlg( m_settings->getAddDir(), QString::null, this, "adddlg", true );
+    KFileDialog fileDlg( Settings::addDir(), QString::null, this, "adddlg", true );
     fileDlg.setMode( KFile::Mode( KFile::Files | KFile::ExistingOnly ) );
     fileDlg.setCaption(i18n("Select Files to Add"));
 
@@ -1142,7 +1284,7 @@ ArkWidget::action_add()
 void
 ArkWidget::addFile(QStringList *list)
 {
-    if ( !ArkUtils::diskHasSpace( m_strArchName, ArkUtils::getSizes( list ) ) )
+    if ( !ArkUtils::diskHasSpace( tmpDir(), ArkUtils::getSizes( list ) ) )
         return;
 
     disableAll();
@@ -1165,7 +1307,7 @@ ArkWidget::addFile(QStringList *list)
 void
 ArkWidget::action_add_dir()
 {
-    KURL u = KDirSelectDialog::selectDirectory( m_settings->getAddDir(),
+    KURL u = KDirSelectDialog::selectDirectory( Settings::addDir(),
                                                     false, this,
                                                     i18n("Select Folder to Add"));
 
@@ -1223,7 +1365,7 @@ ArkWidget::toLocalFile( QString & str )
     {
         if(!mpDownloadedList)
             mpDownloadedList = new QStringList();
-        QString tempfile = m_settings->getTmpDir();
+        QString tempfile = tmpDir();
         tempfile += str.right(str.length() - str.findRev("/") - 1);
         if( !KIO::NetAccess::dircopy(url, tempfile, this) )
             return KURL();
@@ -1397,7 +1539,7 @@ void
 ArkWidget::prepareViewFiles( const QStringList & fileList )
 {
     QString destTmpDirectory;
-    destTmpDirectory = m_settings->getTmpDir();
+    destTmpDirectory = tmpDir();
 
     QStringList * list = new QStringList( fileList );
     arch->unarchFile( list, destTmpDirectory, true);
@@ -1527,7 +1669,7 @@ ArkWidget::action_extract()
     }
 
 
-    ExtractDlg *dlg = new ExtractDlg(m_settings, this, 0, prefix);
+    ExtractDlg *dlg = new ExtractDlg(this, 0, m_url.filename(), prefix);
 
     // if they choose pattern, we have to tell arkwidget to select
     // those files... once we're in the dialog code it's too late.
@@ -1560,7 +1702,7 @@ ArkWidget::action_extract()
 
         if ( !m_extractURL.isLocalFile() )
         {
-            m_extractRemoteTmpDir = new KTempDir( m_settings->getTmpDir() + "extremote" );
+            m_extractRemoteTmpDir = new KTempDir( tmpDir() + "extremote" );
             m_extractRemoteTmpDir->setAutoDelete( true );
 
             extractDir = m_extractRemoteTmpDir->name();
@@ -1580,7 +1722,7 @@ ArkWidget::action_extract()
 
         // if overwrite is false, then we need to check for failure of
         // extractions.
-        bool bOvwrt = m_settings->getExtractOverwrite();
+        bool bOvwrt = Settings::extractOverwrite();
 
         switch(extractOp)
         {
@@ -1606,7 +1748,7 @@ ArkWidget::action_extract()
         case ExtractDlg::Selected:
         case ExtractDlg::Current:
             {
-                int nTotalSize = 0;
+                KIO::filesize_t nTotalSize = 0;
                 if (extractOp != ExtractDlg::Current )
                 {
                     // make a list to send to unarchFile
@@ -1658,6 +1800,10 @@ ArkWidget::action_extract()
             // never happens
             break;
         }
+        if ( dlg->viewFolderAfterExtraction() )
+        {
+            KRun::runURL( dlg->extractDir(), "inode/directory" );
+        }
 
         delete dlg;
     }
@@ -1791,17 +1937,27 @@ void
 ArkWidget::viewSlotExtractDone()
 {
     chmod( QFile::encodeName( m_strFileToView ), 0400 );
-    QString mimetype = KMimeType::findByURL( m_strFileToView )->name();
     bool view = true;
 
-    if ( KRun::isExecutable( mimetype ) )
+    if ( Settings::useIntegratedViewer() )
     {
-    	QString text = i18n( "The file you're trying to view may be an executable. Running untrusted executables may compromise your system's security.\nAre you sure you want to view that file?" );
-        view = ( KMessageBox::warningYesNo( this, text ) == KMessageBox::Yes );
-    }
+        ArkViewer * viewer = new ArkViewer( this, "viewer" );
 
-    if ( view )
-    	KRun::runURL( m_strFileToView, mimetype, true );
+        if ( !viewer->view( m_strFileToView ) )
+        {
+            kdDebug( 1601 ) << "ArkWidget::viewSlotExtractDone(): Internal Viewer can't view this file." << endl;
+            QString text = i18n( "The internal viewer is not able to display this file. Would you like to view it using an external program?" );
+            view = ( KMessageBox::warningYesNo( this, text ) == KMessageBox::Yes );
+
+            if ( view )
+                viewInExternalViewer( this, m_strFileToView );
+
+        }
+    }
+    else
+    {
+        viewInExternalViewer( this, m_strFileToView );
+    }
 
     disconnect( arch, SIGNAL( sigExtract( bool ) ), this,
                 SLOT( viewSlotExtractDone( ) ) );
@@ -1827,8 +1983,7 @@ ArkWidget::showCurrentFile()
 
     QString fullname;
     fullname = "file:";
-    fullname += m_settings->getTmpDir();
-    fullname += "/";
+    fullname += tmpDir();
     fullname += name;
 
     kdDebug(1601) << "File to be viewed: " << fullname << endl;
@@ -1837,30 +1992,13 @@ ArkWidget::showCurrentFile()
     extractList.append(name);
 
     m_strFileToView = fullname;
-    if (ArkUtils::diskHasSpace( m_settings->getTmpDir(), pItem->fileSize() ) )
+    if (ArkUtils::diskHasSpace( tmpDir(), pItem->fileSize() ) )
     {
         disableAll();
         prepareViewFiles( extractList );
     }
 }
 
-// Options menu //////////////////////////////////////////////////////
-
-void
-ArkWidget::options_dirs()
-{
-    GeneralOptDlg *dd = new GeneralOptDlg( m_settings, this );
-    dd->exec();
-    delete dd;
-}
-
-
-void
-ArkWidget::options_saveNow()
-{
-    m_settings->writeConfigurationNow();
-}
-
 // Popup /////////////////////////////////////////////////////////////
 
 void
@@ -2124,7 +2262,7 @@ ArkWidget::startDragSlotExtractDone( bool )
     for (QStringList::Iterator it = mDragFiles.begin(); it != mDragFiles.end(); ++it)
     {
         KURL url;
-        url.setPath( m_settings->getTmpDir() + '/' + *it );
+        url.setPath( tmpDir() + *it );
         list.append( url );
     }
 
@@ -2144,19 +2282,21 @@ ArkWidget::arkWarning(const QString& msg)
 void
 ArkWidget::createFileListView()
 {
-	kdDebug() << "ArkWidget::createFileListView" << endl;
+	kdDebug(1601) << "ArkWidget::createFileListView" << endl;
 	//delete archiveContent;
 	if ( !archiveContent )
 	{
 		archiveContent = new FileListView(this, this);
 		archiveContent->setMultiSelection(true);
-		archiveContent->show();
+		//archiveContent->show();
 		connect( archiveContent, SIGNAL( selectionChanged()), this, SLOT( slotSelectionChanged() ) );
 		connect( archiveContent, SIGNAL( rightButtonPressed(QListViewItem *, const QPoint &, int)),
 				this, SLOT(doPopup(QListViewItem *, const QPoint &, int)));
 		connect( archiveContent, SIGNAL( startDragRequest( const QStringList & ) ),
 				this, SLOT( startDrag( const QStringList & ) ) );
-		connect( archiveContent, SIGNAL( doubleClicked(QListViewItem *, const QPoint &, int ) ),
+		connect( archiveContent, SIGNAL( executed(QListViewItem *, const QPoint &, int ) ),
+				this, SLOT( viewFile() ) );
+		connect( archiveContent, SIGNAL( returnPressed(QListViewItem * ) ),
 				this, SLOT( viewFile() ) );
     }
     archiveContent->clear();
@@ -2170,7 +2310,7 @@ Arch * ArkWidget::getNewArchive( const QString & _fileName )
     QString type = KMimeType::findByURL( _fileName )->name();
     ArchType archtype = ArchiveFormatInfo::self()->archTypeForMimeType(type);
     kdDebug( 1601 ) << "archtype is recognised as: " << archtype << endl;
-    if(0 == (newArch = Arch::archFactory(archtype, m_settings, this,
+    if(0 == (newArch = Arch::archFactory(archtype, this,
                                          _fileName)))
     {
         KMessageBox::error(this, i18n("Unknown archive format or corrupted archive") );
@@ -2227,6 +2367,7 @@ ArkWidget::slotCreate(Arch * _newarch, bool _success, const QString & _filename,
         emit setWindowCaption( _filename );
         emit addRecentURL( u );
         createFileListView();
+	archiveContent->show();
         m_bIsArchiveOpen = true;
         arch = _newarch;
         m_bIsSimpleCompressedFile =
@@ -2275,7 +2416,7 @@ ArkWidget::openArchive( const QString & _filename )
     }
 
     kdDebug( 1601 ) << "m_openAsMimeType is: " << m_openAsMimeType << endl;
-    if( 0 == ( newArch = Arch::archFactory( archtype, m_settings, this,
+    if( 0 == ( newArch = Arch::archFactory( archtype, this,
                                             _filename, m_openAsMimeType) ) )
     {
         emit setWindowCaption( QString::null );
@@ -2301,6 +2442,7 @@ ArkWidget::openArchive( const QString & _filename )
     archiveContent->setUpdatesEnabled( false );
     arch = newArch;
     newArch->open();
+    emit addRecentURL( m_url );
 }
 
 void
@@ -2311,11 +2453,13 @@ ArkWidget::slotOpen( Arch * /* _newarch */, bool _success, const QString & _file
     archiveContent->setUpdatesEnabled(true);
     archiveContent->triggerUpdate();
 
+    archiveContent->show();
+
     if ( _success )
     {
         QFileInfo fi( _filename );
         QString path = fi.dirPath( true );
-        m_settings->setLastOpenDir( path );
+	Settings::setLastOpenDir( path );
 
         if ( !fi.isWritable() )
         {
@@ -2348,4 +2492,46 @@ ArkWidget::slotOpen( Arch * /* _newarch */, bool _success, const QString & _file
     kdDebug(1601) << "-ArkWidget::slotOpen" << endl;
 }
 
+
+void ArkWidget::slotShowSearchBarToggled( bool b )
+{
+	if ( b )
+	{
+		m_searchToolBar->show();
+		Settings::setShowSearchBar( true );
+	}
+	else
+	{
+		m_searchToolBar->hide();
+		Settings::setShowSearchBar( false );
+	}
+}
+
+/**
+ * Show Settings dialog.
+ */
+void ArkWidget::showSettings(){
+  if(KConfigDialog::showDialog("settings"))
+    return;
+  
+  KConfigDialog *dialog = new KConfigDialog(this, "settings", Settings::self());
+
+  General* genPage = new General(0, "General");
+  dialog->addPage(genPage, i18n("General"), "ark", i18n("General Settings"));
+  dialog->addPage(new Addition(0, "Addition"), i18n("Addition"), "ark_addfile", i18n("File Addition Settings"));
+  dialog->addPage(new Extraction(0, "Extraction"), i18n("Extraction"), "ark_extract", i18n("Extraction Settings"));
+  dialog->addPage(new Folders(0, "Folders"), i18n("Folders"), "folder", i18n("Folder Settings"));
+
+  KTrader::OfferList offers;
+
+  offers = KTrader::self()->query( "KonqPopupMenu/Plugin", "Library == 'libarkplugin'" );
+
+  if ( offers.isEmpty() )
+	  genPage->kcfg_KonquerorIntegration->setEnabled( false );
+  else
+	  genPage->konqIntegrationLabel->setText( QString::null );
+  
+  dialog->show();
+}
+
 #include "arkwidget.moc"
