@@ -11,25 +11,25 @@ i18n(" Method ")
 i18n(" Version ")
 i18n(" Owner ")
 i18n(" Group ")
-i18n("(used as part of a sentence)","start-up directory")
-i18n("directory for opening files (used as part of a sentence)","open directory")
-i18n("directory for extracting files (used as part of a sentence)","extract directory")
-i18n("directory for adding files (used as part of a sentence)","add directory")
+i18n("(used as part of a sentence)","start-up folder")
+i18n("folder for opening files (used as part of a sentence)","open folder")
+i18n("folder for extracting files (used as part of a sentence)","extract folder")
+i18n("folder for adding files (used as part of a sentence)","add folder")
 
 i18n("Settings")
 i18n("&Adding")
 i18n("&Extracting")
-i18n("&Directories")
+i18n("&Folders")
 i18n("Add Settings")
 i18n("Extract Settings")
 i18n("Replace &old files only with newer files")
 i18n("Keep entries &generic (Lha)")
 i18n("Force &MS-DOS short filenames (Zip)")
-i18n("Tranlate LF to DOS &CRLF (Zip)")
-i18n("&Recursively add subdirectories (Zip, Rar)")
+i18n("Translate LF to DOS &CRLF (Zip)")
+i18n("&Recursively add subfolders (Zip, Rar)")
 i18n("&Store symlinks as links (Zip, Rar)")
 i18n("O&verwrite files (Zip, Tar, Zoo, Rar)")
 i18n("&Preserve permissions (Tar)")
-i18n("&Ignore directory names (Zip)")
+i18n("&Ignore folder names (Zip)")
 i18n("Convert filenames to &lowercase (Zip, Rar)")
 i18n("Convert filenames to &uppercase (Rar)")
