@@ -165,7 +165,7 @@ void FileLVI::setText(int column, const QString &text)
         if ( l>0 && text[l] == '%' )
             m_ratio = text.left(l).toDouble();
         else
-        m_ratio = text.toDouble();
+            m_ratio = text.toDouble();
         QListViewItem::setText(column, i18n("Packed Ratio", "%1 %").arg(KGlobal::locale()->formatNumber(m_ratio, 1)));
     }
     else if ( colName == timeStampStrCol )
@@ -186,12 +186,13 @@ FileListView::FileListView(ArkWidget *baseArk, QWidget *parent,
 			   const char* name)
 	: KListView(parent, name), m_pParent(baseArk)
 {
-  sortColumn = 0;
-  increasing = TRUE;
   QWhatsThis::add(this, i18n("This area is for displaying information about the files contained within an archive."));
 
-  setMouseTracking(false);
-  setSelectionModeExt(FileManager);
+  setMultiSelection( true );
+  setSelectionModeExt( FileManager );
+  setDragEnabled( true );
+  setItemsMovable( false );
+  
   m_bPressed = false;
 }
 
@@ -235,30 +236,6 @@ columnName FileListView::nameOfColumn( int index )
     return colMap[ index ];
 }
 
-
-void FileListView::paintEmptyArea(QPainter *p, const QRect &rect)
-{
-	QListView::paintEmptyArea(p, rect);
-	if(0 == childCount())
-	{
-		p->drawText(2, 16, i18n("No files in current archive"));
-	}
-}
-
-
-void FileListView::setSorting(int column, bool inc)
-{
-	if(sortColumn == column)
-	{
-		increasing = !inc;
-	}
-	else{
-		sortColumn = column;
-		increasing = inc;
-	}
-	KListView::setSorting(sortColumn, increasing);
-}
-
 QStringList FileListView::selectedFilenames() const
 {
 	QStringList files;
