@@ -1,7 +1,5 @@
 /*
 
- $Id: lha.cpp,v 1.14 2003/03/07 22:10:32 waba Exp $
-
  ark -- archiver for the KDE project
 
  Copyright (C)
@@ -47,15 +45,14 @@
 #include <kprocess.h>
 
 // ark includes
-#include "arkwidgetbase.h"
-#include "arksettings.h"
+#include "arkwidget.h"
+#include "settings.h"
 #include "arch.h"
 #include "lha.h"
 #include "arkutils.h"
 
-LhaArch::LhaArch( ArkSettings *_settings, ArkWidgetBase *_gui,
-		  const QString & _fileName )
-  : Arch(_settings, _gui, _fileName )
+LhaArch::LhaArch( ArkWidget *_gui, const QString & _fileName )
+  : Arch( _gui, _fileName )
 {
   kdDebug(1601) << "LhaArch constructor" << endl;
   m_archiver_program = "lha";
@@ -159,7 +156,7 @@ void LhaArch::open()
 
   if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
     {
-      KMessageBox::error( 0, i18n("Couldn't start a subprocess.") );
+      KMessageBox::error( 0, i18n("Could not start a subprocess.") );
       emit sigOpen(this, false, QString::null, 0 );
     }
 
@@ -218,42 +215,25 @@ void LhaArch::addFile( QStringList *urls )
   *kp << m_archiver_program;
 
   QString strOptions;
-  if (m_settings->getAddReplaceOnlyWithNewer())
+  if (Settings::replaceOnlyWithNewer())
     strOptions = "u";
   else
     strOptions = "a";
-  if (m_settings->getLhaGeneric())
+  if (Settings::lhaGeneric())
     strOptions += "g";
 
   *kp << strOptions << m_filename;
 
-  QString base;
-  QString url;
-  QString file;
-
-
   QStringList::ConstIterator iter;
+  KURL url( urls->first() );
+  QDir::setCurrent( url.directory() );
   for (iter = urls->begin(); iter != urls->end(); ++iter )
   {
-    url = *iter;
-    // comment out for now until I figure out what happened to this function!
-    //    KURL::decodeURL(url); // Because of special characters
-    file = url.right(url.length()-5);
-
-    if( file[file.length()-1]=='/' )
-      file[file.length()-1]='\0';
-    if( ! m_settings->getaddPath() )
-    {
-      int pos;
-      pos = file.findRev( '/' );
-      base = file.left( pos );
-      pos++;
-      QDir::setCurrent(base);
-      base = file.right( file.length()-pos );
-      file = base;
-    }
-    *kp << file;
+    KURL fileURL( *iter );
+    *kp << fileURL.fileName();
   }
+
+
   connect( kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
 	   this, SLOT(slotReceivedOutput(KProcess*, char*, int)));
   connect( kp, SIGNAL(receivedStderr(KProcess*, char*, int)),
@@ -264,7 +244,7 @@ void LhaArch::addFile( QStringList *urls )
 
   if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
     {
-      KMessageBox::error( 0, i18n("Couldn't start a subprocess.") );
+      KMessageBox::error( 0, i18n("Could not start a subprocess.") );
       emit sigAdd(false);
     }
 
@@ -272,7 +252,7 @@ void LhaArch::addFile( QStringList *urls )
 }
 
 void LhaArch::unarchFile(QStringList *_fileList, const QString & _destDir,
-			 bool viewFriendly)
+			 bool /*viewFriendly*/)
 {
   // if _fileList is empty, we extract all.
   // if _destDir is empty, abort with error.
@@ -315,7 +295,7 @@ void LhaArch::unarchFile(QStringList *_fileList, const QString & _destDir,
 
   if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
     {
-      KMessageBox::error( 0, i18n("Couldn't start a subprocess.") );
+      KMessageBox::error( 0, i18n("Could not start a subprocess.") );
       emit sigExtract(false);
     }
 }
@@ -349,7 +329,7 @@ void LhaArch::remove(QStringList *list)
 
   if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
     {
-      KMessageBox::error( 0, i18n("Couldn't start a subprocess.") );
+      KMessageBox::error( 0, i18n("Could not start a subprocess.") );
       emit sigDelete(false);
     }
 
