@@ -1,6 +1,6 @@
 /*
 
- $Id: shellOutputDlg.cpp,v 1.11.4.1 2004/04/14 11:45:00 binner Exp $
+ $Id: shellOutputDlg.cpp,v 1.14 2004/05/26 10:38:08 pinto Exp $
 
  ark -- archiver for the KDE project
 
@@ -27,32 +27,34 @@
 
 // Qt includes
 #include <qlayout.h>
+#include <qtextedit.h>
+#include <qstring.h>
 
 #include <klocale.h>
-#include <kpushbutton.h>
-#include <kstdguiitem.h>
 
 // ark includes
 #include "shellOutputDlg.h"
-#include "shellOutputDlg.moc"
-#include "arksettings.h"
 
-ShellOutputDlg::ShellOutputDlg( ArkSettings *_data, QWidget *_parent,
+ShellOutputDlg::ShellOutputDlg( const QString& text, QWidget *_parent,
 				const char *_name )
-	: QDialog( _parent, _name, true )
+	: KDialogBase( _parent, _name, true, i18n( "Shell Output" ), KDialogBase::Ok, KDialogBase::Ok, true )
 {
-  setCaption( i18n("Shell Output") );
-  QGridLayout *grid1 = new QGridLayout(this,10,5,15,7);
-  QMultiLineEdit *l1 = new QMultiLineEdit( this );
-  l1->setReadOnly( true );
-  grid1->addMultiCellWidget(l1,0,8,0,4);
+	m_outputViewer = new QTextEdit( this );
+	m_outputViewer->setTextFormat( Qt::PlainText );
+	m_outputViewer->setReadOnly( true );
 
-  l1->setText( *(_data->getLastShellOutput()) );
-  l1->setCursorPosition(l1->numLines(), 0);
+	m_outputViewer->setText( text );
+	m_outputViewer->setCursorPosition( m_outputViewer->lines(), 0 );
 
-  QPushButton *close = new KPushButton( KStdGuiItem::close(), this );
-  grid1->addWidget(close,9,4);
-  connect( close, SIGNAL( clicked() ), SLOT( accept() ) );
-  close->setFocus();
-  resize(520, 380);
+	setMainWidget( m_outputViewer );
+
+	resize( 520, 380 );
 }
+
+ShellOutputDlg::~ShellOutputDlg()
+{
+	delete m_outputViewer;
+	m_outputViewer = 0;
+}
+
+#include "shellOutputDlg.moc"
