@@ -41,14 +41,19 @@
 //
 
 // C includes
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
 #include <stdio.h>
 #include <stdlib.h>
 
 // Qt includes
 #include <qdir.h>
+#include <qregexp.h>
 
 // KDE includes
 #include <kdebug.h>
+#include <klargefile.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <ktempfile.h>
@@ -59,23 +64,24 @@
 #include <ktar.h>
 
 // ark includes
-#include "arkwidgetbase.h"
-#include "arksettings.h"
+#include "arkwidget.h"
+#include "settings.h"
 #include "tar.h"
 #include "filelistview.h"
 
 static char *makeAccessString(mode_t mode);
 
-TarArch::TarArch( ArkSettings *_settings, ArkWidgetBase *_gui,
+TarArch::TarArch( ArkWidget *_gui,
                   const QString & _filename, const QString & _openAsMimeType)
-  : Arch(_settings, _gui, _filename), createTmpInProgress(false),
+  : Arch( _gui, _filename), createTmpInProgress(false),
     updateInProgress(false), deleteInProgress(false), fd(NULL),
     m_pTmpProc( NULL ), m_pTmpProc2( NULL ), tarptr( NULL ), failed( false )
 {
     m_tmpDir = NULL;
+    m_dotslash = false;
     m_filesToAdd = m_filesToRemove = QStringList();
     kdDebug(1601) << "+TarArch::TarArch" << endl;
-    m_archiver_program = m_settings->getTarCommand();
+    m_archiver_program = Settings::tarExe();
     m_unarchiver_program = QString::null;
     verifyUtilityIsAvailable(m_archiver_program, m_unarchiver_program);
 
@@ -92,7 +98,7 @@ TarArch::TarArch( ArkSettings *_settings, ArkWidgetBase *_gui,
     else
     {
         compressed = true;
-        m_tmpDir = new KTempDir( _settings->getTmpDir()
+        m_tmpDir = new KTempDir( _gui->tmpDir()
                                  + QString::fromLatin1( "temp_tar" ) );
         m_tmpDir->setAutoDelete( true );
         m_tmpDir->qDir()->cd( m_tmpDir->name() );
@@ -125,7 +131,11 @@ void TarArch::updateArch()
   if (compressed)
     {
       updateInProgress = true;
-      fd = fopen( QFile::encodeName(m_filename), "w" );
+      int f_desc = KDE_open(QFile::encodeName(m_filename), O_CREAT | O_TRUNC | O_WRONLY, 0666);
+      if (f_desc != -1)
+          fd = fdopen( f_desc, "w" );
+      else
+          fd = NULL;
 
       KProcess *kp = new KProcess;
       kp->clearArguments();
@@ -219,7 +229,12 @@ TarArch::open()
         QFile::remove(tmpfile); // just to make sure
     setHeaders();
 
+//  m_shellErrorData = "";
+    clearShellOutput();
     // might as well plunk the output of tar -tvf in the shell output window...
+    //
+    // Now it's essential - used later to decide whether pathnames in the
+    // tar archive are plain or start with "./"
     KProcess *kp = new KProcess;
 
     *kp << m_archiver_program;
@@ -238,13 +253,13 @@ TarArch::open()
     connect(kp, SIGNAL(processExited(KProcess *)),
             this, SLOT(slotListingDone(KProcess *)));
     connect(kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
-            this, SLOT(slotReceivedOutput( KProcess *, char *, int )));
+        this, SLOT(slotReceivedOutput( KProcess *, char *, int )));
     connect( kp, SIGNAL(receivedStderr(KProcess*, char*, int)),
-            this, SLOT(slotReceivedOutput(KProcess*, char*, int)));
+        this, SLOT(slotReceivedOutput(KProcess*, char*, int)));
 
     if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
     {
-        KMessageBox::error( 0, i18n("Couldn't start a subprocess.") );
+        KMessageBox::error( 0, i18n("Could not start a subprocess.") );
     }
 
     // We list afterwards because we want the signals at the end
@@ -301,12 +316,12 @@ void TarArch::openSecondCreateTempDone()
                 || getUnCompressor() == QString("bunzip2") ) )
     {
         disconnect( this, SIGNAL( createTempDone() ), this, SLOT( openSecondCreateTempDone() ) );
-        kdDebug(1601)  << "Creating KTar from failed IO_RW " << m_filename << 
+        kdDebug(1601)  << "Creating KTar from failed IO_RW " << m_filename <<
             " using uncompressor " << getUnCompressor() << endl;
         if ( KMimeType::findByFileContent( tmpfile )->name() != "application/x-zerosize" )
         {
             tarptr = new KTar(tmpfile);
-            failed = !tarptr->open(IO_ReadOnly); 
+            failed = !tarptr->open(IO_ReadOnly);
         }
     }
 
@@ -334,6 +349,30 @@ void TarArch::openSecondCreateTempDone()
 
 void TarArch::slotListingDone(KProcess *_kp)
 {
+  const QString list = getLastShellOutput();
+  FileListView *flv = m_gui->fileList();
+  if (flv!=NULL && flv->count()>0)
+  {
+    const QString firstfile = ((FileLVI *) flv->firstChild())->fileName();
+    if (list.find(QRegExp(QString("\\s\\./%1[/\\n]").arg(firstfile)))>=0)
+    {
+      m_dotslash = true;
+      kdDebug(1601) << k_funcinfo << "archive has dot-slash" << endl;
+    }
+    else
+    {
+      if (list.find(QRegExp(QString("\\s%1[/\\n]").arg(firstfile)))>=0)
+      {
+        m_dotslash = false;
+        kdDebug(1601) << k_funcinfo << "archive doesn't have dot-slash" << endl;
+      }
+      else
+      {
+        kdDebug(1601) << k_funcinfo << "cannot match '" << firstfile << "' in listing!" << endl;
+      }
+    }
+  }
+
   delete _kp;
 }
 
@@ -440,7 +479,11 @@ void TarArch::createTmp()
             }
             // the tmpfile does not yet exist, so we create it.
             createTmpInProgress = true;
-            fd = fopen( QFile::encodeName(tmpfile), "w" );
+            int f_desc = KDE_open(QFile::encodeName(tmpfile), O_CREAT | O_TRUNC | O_WRONLY, 0666);
+            if (f_desc != -1)
+                fd = fdopen( f_desc, "w" );
+            else
+                fd = NULL;
 
             KProcess *kp = new KProcess;
             kp->clearArguments();
@@ -466,7 +509,7 @@ void TarArch::createTmp()
                     this, SLOT(slotReceivedOutput(KProcess*, char*, int)));
             if (kp->start(KProcess::NotifyOnExit, flag ) == false)
             {
-                KMessageBox::error(0, i18n("I can't fork a decompressor"));
+                KMessageBox::error(0, i18n("Unable to fork a decompressor"));
 		emit sigOpen( this, false, QString::null, 0 );
             }
         }
@@ -511,17 +554,9 @@ void TarArch::deleteOldFiles(QStringList *urls, bool bAddOnlyNew)
   QStringList::ConstIterator iter;
   for (iter = urls->begin(); iter != urls->end(); ++iter )
   {
-    QString filename;
-    str = *iter;
-    if (str.left(5) == "file:")
-      // get rid of "file:" part of url
-      filename = str.right(str.length()-5);
-    str = str.right(str.length()-8); // get rid of leading /
-    if (!m_settings->getaddPath())
-      str = str.right(str.length()-str.findRev('/')-1);
-
+    KURL url( *iter );
     // find the file entry in the archive listing
-    const FileLVI * lv = m_gui->getFileLVI(str);
+    const FileLVI * lv = m_gui->getFileLVI( url.fileName() );
     if ( !lv ) // it isn't in there, so skip it.
       continue;
 
@@ -531,7 +566,7 @@ void TarArch::deleteOldFiles(QStringList *urls, bool bAddOnlyNew)
       // old. Otherwise we aren't adding it anyway, so we can go on to the next
       // file with a "continue".
 
-      QFileInfo fileInfo(filename);
+      QFileInfo fileInfo( url.path() );
       QDateTime addFileMTime = fileInfo.lastModified();
       QDateTime oldFileMTime = lv->timeStamp();
 
@@ -548,13 +583,13 @@ void TarArch::deleteOldFiles(QStringList *urls, bool bAddOnlyNew)
 
       if (oldFileMTime >= addFileMTime)
       {
-        kdDebug() << "Old time is newer or same" << endl;
+        kdDebug(1601) << "Old time is newer or same" << endl;
         continue; // don't add this file to the list to be deleted.
       }
     }
     list.append(str);
 
-    kdDebug() << "To delete: " << str << endl;
+    kdDebug(1601) << "To delete: " << str << endl;
   }
   if(!list.isEmpty())
     remove(&list);
@@ -575,7 +610,7 @@ void TarArch::addFile( QStringList* urls )
   // those in urls.
   m_bNotifyWhenDeleteFails = false;
   connect( this, SIGNAL( removeDone() ), this, SLOT( deleteOldFilesDone() ) );
-  deleteOldFiles(urls, m_settings->getAddReplaceOnlyWithNewer());
+  deleteOldFiles(urls, Settings::replaceOnlyWithNewer());
 }
 
 void TarArch::deleteOldFilesDone()
@@ -590,15 +625,12 @@ void TarArch::deleteOldFilesDone()
 void TarArch::addFileCreateTempDone()
 {
   disconnect( this, SIGNAL( createTempDone() ), this, SLOT( addFileCreateTempDone() ) );
-  QString file, url, tmp;
   QStringList * urls = &m_filesToAdd;
-  url = urls->first();
-  file = KURL(url).path(-1); // remove trailing slash
 
   KProcess *kp = new KProcess;
   *kp << m_archiver_program;
 
-  if( m_settings->getAddReplaceOnlyWithNewer())
+  if( Settings::replaceOnlyWithNewer())
     *kp << "uvf";
   else
     *kp << "rvf";
@@ -608,39 +640,14 @@ void TarArch::addFileCreateTempDone()
   else
     *kp << m_filename;
 
-  if (m_settings->getTarUseAbsPathnames())
-    *kp << "-P";
-
-  QString base;
-
-  if( !m_settings->getaddPath() )
-    {
-      int pos;
-      pos = file.findRev( '/', -1, FALSE );
-      base = file.left( ++pos );
-      kdDebug(1601) << "base is " << base << endl;
-      //                pos++;
-      tmp = file.right( file.length()-pos );
-      file = tmp;
-      QDir::setCurrent(base);
-    }
-
-  QStringList::Iterator it=urls->begin();
-  while(1)
-    {
-      int pos;
-      *kp << file;
-      it++;
-      url = *it;
-
-      if( url.isNull() )
-        break;
-      file = KURL(url).path(-1); // remove trailing slash
-      pos = file.findRev( '/', -1, FALSE );
-      pos++;
-      tmp = file.right( file.length()-pos );
-      file = tmp;
-    }
+  QStringList::ConstIterator iter;
+  KURL url( urls->first() );
+  QDir::setCurrent( url.directory() );
+  for (iter = urls->begin(); iter != urls->end(); ++iter )
+  {
+    KURL fileURL( *iter );
+    *kp << fileURL.fileName();
+  }
 
   // debugging info
   QValueList<QCString> list = kp->args();
@@ -657,22 +664,13 @@ void TarArch::addFileCreateTempDone()
 
   connect( kp, SIGNAL(processExited(KProcess*)), this,
            SLOT(slotAddFinished(KProcess*)));
- // was this ever necessary here?
- // kdDebug(1601) << "Busy loop... waiting for temp tar to be created" << endl;
- // while (compressed && createTmpInProgress)
- //   qApp->processEvents(); // wait for temp to be created;
 
   if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
     {
-      KMessageBox::error( 0, i18n("Couldn't start a subprocess.") );
+      KMessageBox::error( 0, i18n("Could not start a subprocess.") );
       emit sigAdd(false);
     }
 
-#if 0
-  if( m_settings->getaddPath() )
-    file.remove( 0, 1 );  // Get rid of leading /
-#endif
-
   kdDebug(1601) << "-TarArch::addFile" << endl;
 }
 
@@ -726,9 +724,9 @@ void TarArch::unarchFile(QStringList * _fileList, const QString & _destDir,
     *kp << "--use-compress-program="+getUnCompressor();
 
   QString options = "-x";
-  if (!m_settings->getExtractOverwrite())
+  if (!Settings::extractOverwrite())
     options += "k";
-  if (m_settings->getTarPreservePerms())
+  if (Settings::preservePerms())
     options += "p";
   options += "f";
 
@@ -742,7 +740,8 @@ void TarArch::unarchFile(QStringList * _fileList, const QString & _destDir,
       for ( QStringList::Iterator it = _fileList->begin();
             it != _fileList->end(); ++it )
         {
-          *kp << (*it);/*.latin1() ;*/
+	    *kp << QString(m_dotslash ? "./" : "")+(*it);
+//	    *kp << (*it);/*.latin1() ;*/
         }
     }
 
@@ -756,7 +755,7 @@ void TarArch::unarchFile(QStringList * _fileList, const QString & _destDir,
 
   if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
     {
-      KMessageBox::error( 0, i18n("Couldn't start a subprocess.") );
+      KMessageBox::error( 0, i18n("Could not start a subprocess.") );
       emit sigExtract(false);
     }
 
@@ -788,8 +787,9 @@ void TarArch::removeCreateTempDone()
   QStringList::Iterator it = m_filesToRemove.begin();
   for ( ; it != m_filesToRemove.end(); ++it )
     {
-      kdDebug(1601) << *it << endl;
-      *kp << *it;
+        *kp << QString(m_dotslash ? "./" : "")+(*it);
+//      kdDebug(1601) << *it << endl;
+//      *kp << *it;
     }
   m_filesToRemove = QStringList();
 
@@ -803,7 +803,7 @@ void TarArch::removeCreateTempDone()
 
   if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
     {
-      KMessageBox::error( 0, i18n("Couldn't start a subprocess.") );
+      KMessageBox::error( 0, i18n("Could not start a subprocess.") );
       emit sigDelete(false);
     }
 
