@@ -38,8 +38,7 @@ class QStrList;
 class KProcess;
 class KTempDir;
 class KTarDirectory;
-class ArkWidgetBase;
-class ArkSettings;
+class ArkWidget;
 class Arch;
 class KTar;
 
@@ -54,7 +53,7 @@ class TarArch : public Arch
 {
   Q_OBJECT
 public:
-  TarArch( ArkSettings *_settings, ArkWidgetBase *_gui, const QString & _filename,
+  TarArch( ArkWidget *_gui, const QString & _filename,
             const QString & _openAsMimeType );
   virtual ~TarArch();
 
@@ -124,6 +123,7 @@ private: // data
     KProcess * m_pTmpProc2;
     KTar *tarptr;
     bool failed;
+    bool m_dotslash;
 };
 
 #endif /* TAR_H */
