@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: zip.h,v 1.28 2003/03/07 22:06:46 waba Exp $
+ $Id: zip.h,v 1.30 2004/05/31 20:31:43 bmeyer Exp $
 
   ark -- archiver for the KDE project
 
@@ -38,15 +38,13 @@ class QStringList;
 class KProcess;
 
 class Arch;
-class ArkSettings;
-class ArkWidgetBase;
+class ArkWidget;
 
 class ZipArch : public Arch
 {
   Q_OBJECT
 public:
-  ZipArch( ArkSettings *_settings, ArkWidgetBase *_gui,
-	   const QString & _fileName );
+  ZipArch( ArkWidget *_gui, const QString & _fileName );
   virtual ~ZipArch() { }
 	
   virtual void open();
