@@ -1,7 +1,5 @@
 /*
 
- $Id: zoo.cpp,v 1.2.2.4 2003/01/13 10:32:44 helio Exp $
-
  ark -- archiver for the KDE project
 
  Copyright (C)
@@ -21,7 +19,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
@@ -44,17 +42,16 @@
 #include <kprocess.h>
 
 // ark includes
-#include "arkwidgetbase.h"
-#include "arksettings.h"
+#include "settings.h"
+#include "arkwidget.h"
 #include "arch.h"
 #include "zoo.h"
 #include "arkutils.h"
 
 QString fixTime(const QString &_strTime);
 
-ZooArch::ZooArch( ArkSettings *_settings, ArkWidgetBase *_gui,
-		  const QString & _fileName )
-  : Arch(_settings, _gui, _fileName )
+ZooArch::ZooArch( ArkWidget *_gui, const QString & _fileName )
+  : Arch( _gui, _fileName )
 {
   kdDebug(1601) << "ZooArch constructor" << endl;
   m_archiver_program = "zoo";
@@ -126,7 +123,7 @@ void ZooArch::open()
 
   if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
     {
-      KMessageBox::error( 0, i18n("Couldn't start a subprocess.") );
+      KMessageBox::error( 0, i18n("Could not start a subprocess.") );
       emit sigOpen(this, false, QString::null, 0 );
     }
 
@@ -159,7 +156,7 @@ void ZooArch::setHeaders()
 void ZooArch::create()
 {
   emit sigCreate(this, true, m_filename,
-		 Arch::Extract | Arch::Delete | Arch::Add 
+		 Arch::Extract | Arch::Delete | Arch::Add
 		 | Arch::View);
 }
 
@@ -179,41 +176,23 @@ void ZooArch::addFile( QStringList *urls )
   KProcess *kp = new KProcess;
   kp->clearArguments();
   *kp << m_archiver_program;
-	
-  if (m_settings->getAddReplaceOnlyWithNewer())
+
+  if (Settings::replaceOnlyWithNewer())
     *kp << "-update";
   else
     *kp << "-add";
 
   *kp << m_filename;
 
-  QString base;
-  QString url;
-  QString file;
-
-	
   QStringList::ConstIterator iter;
+  KURL url( urls->first() );
+  QDir::setCurrent( url.directory() );
   for (iter = urls->begin(); iter != urls->end(); ++iter )
   {
-    url = *iter;
-    // comment out for now until I figure out what happened to this function!
-    //    KURL::decodeURL(url); // Because of special characters
-    file = url.right(url.length()-5);
-
-    if( file[file.length()-1]=='/' )
-      file[file.length()-1]='\0';
-    if( ! m_settings->getaddPath() )
-    {
-      int pos;
-      pos = file.findRev( '/' );
-      base = file.left( pos );
-      pos++;
-      QDir::setCurrent(base);
-      base = file.right( file.length()-pos );
-      file = base;
-    }
-    *kp << file;
+    KURL fileURL( *iter );
+    *kp << fileURL.fileName();
   }
+
   connect( kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
 	   this, SLOT(slotReceivedOutput(KProcess*, char*, int)));
   connect( kp, SIGNAL(receivedStderr(KProcess*, char*, int)),
@@ -224,7 +203,7 @@ void ZooArch::addFile( QStringList *urls )
 
   if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
     {
-      KMessageBox::error( 0, i18n("Couldn't start a subprocess.") );
+      KMessageBox::error( 0, i18n("Could not start a subprocess.") );
       emit sigAdd(false);
     }
 
@@ -232,7 +211,7 @@ void ZooArch::addFile( QStringList *urls )
 }
 
 void ZooArch::unarchFile(QStringList *_fileList, const QString & _destDir,
-			 bool viewFriendly)
+			 bool /*viewFriendly*/)
 {
   // if _fileList is empty, we extract all.
   // if _destDir is empty, abort with error.
@@ -256,29 +235,29 @@ void ZooArch::unarchFile(QStringList *_fileList, const QString & _destDir,
 
 
   QString tmp;
-	
+
   KProcess *kp = new KProcess;
   kp->clearArguments();
-  
+
   *kp << m_archiver_program;
 
-  if (!m_settings->getExtractOverwrite())
+  if (!Settings::extractOverwrite())
     *kp << "x";
   else
     *kp << "xOOS";
   *kp << m_filename;
-  
+
   // if the list is empty, no filenames go on the command line,
   // and we then extract everything in the archive.
   if (_fileList)
     {
       for ( QStringList::Iterator it = _fileList->begin();
-	    it != _fileList->end(); ++it ) 
+	    it != _fileList->end(); ++it )
 	{
 	  *kp << (*it);/*.latin1() ;*/
 	}
     }
- 
+
   connect( kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
 	   this, SLOT(slotReceivedOutput(KProcess*, char*, int)));
   connect( kp, SIGNAL(receivedStderr(KProcess*, char*, int)),
@@ -286,10 +265,10 @@ void ZooArch::unarchFile(QStringList *_fileList, const QString & _destDir,
 
   connect( kp, SIGNAL(processExited(KProcess*)), this,
 	   SLOT(slotExtractExited(KProcess*)));
-  
+
   if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
     {
-      KMessageBox::error( 0, i18n("Couldn't start a subprocess.") );
+      KMessageBox::error( 0, i18n("Could not start a subprocess.") );
       emit sigExtract(false);
     }
 }
@@ -304,7 +283,7 @@ void ZooArch::remove(QStringList *list)
   m_shellErrorData = "";
   KProcess *kp = new KProcess;
   kp->clearArguments();
-  
+
   *kp << m_archiver_program << "D" << m_filename;
   for ( QStringList::Iterator it = list->begin();
 	it != list->end(); ++it )
@@ -323,17 +302,17 @@ void ZooArch::remove(QStringList *list)
 
   if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
     {
-      KMessageBox::error( 0, i18n("Couldn't start a subprocess.") );
+      KMessageBox::error( 0, i18n("Could not start a subprocess.") );
       emit sigDelete(false);
     }
-  
+
   kdDebug(1601) << "-ZooArch::remove" << endl;
 }
 
 QString fixTime(const QString &_strTime)
 {
   // it may have come from a different time zone... get rid of trailing
-  // +3 or -3 etc. 
+  // +3 or -3 etc.
   QString strTime = _strTime;
 
   if (strTime.contains("+") || strTime.contains("-"))
@@ -356,7 +335,7 @@ QString fixTime(const QString &_strTime)
 	  strTime = strTime.left(8);
 	  strTime.sprintf("%2.2d%s", nHour, strTime.right(6).utf8().data());
 	  kdDebug(1601) << "The new time is " << strTime << endl;
-	}	
+	}
     }
   else
     {
