@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: zoo.h,v 1.10 2003/03/07 22:06:46 waba Exp $
+ $Id: zoo.h,v 1.12 2004/05/31 20:31:43 bmeyer Exp $
 
  ark -- archiver for the KDE project
 
@@ -33,14 +33,13 @@ class QCString;
 class QStringList;
 
 class Arch;
-class ArkSettings;
-class ArkWidgetBase;
+class ArkWidget;
 
 class ZooArch : public Arch
 {
   Q_OBJECT
 public:
-  ZooArch( ArkSettings *_settings, ArkWidgetBase *_gui,
+  ZooArch( ArkWidget *_gui,
 	   const QString & _fileName );
   virtual ~ZooArch() { }
 	
