@@ -1,6 +1,6 @@
 /*
 
- $Id: dlabel.h,v 1.3 2001/10/19 03:23:22 teran Exp $
+ $Id: dlabel.h,v 1.8 2003/10/14 21:42:32 kniederk Exp $
 
  KCalc 
 
@@ -20,7 +20,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
  */
 
@@ -28,32 +28,32 @@
 #ifndef _D_LABEL_H_
 #define _D_LABEL_H_
 
-#include <qlabel.h>
+#include <qvaluevector.h>
+#include "kcalcdisplay.h"
+#include "kcalctype.h"
 
-class DLabel : public QLabel
+class CalcEngine;
+
+
+class DispLogic : public KCalcDisplay
 {
 Q_OBJECT
 
 public:
-	DLabel(QWidget *parent=0, const char *name=0);
-	~DLabel() {}
+	DispLogic(QWidget *parent=0, const char *name=0);
+	~DispLogic();
 
-protected:
-	void  mousePressEvent ( QMouseEvent *);
-
-public:
-	bool isLit();
-	void setLit(bool _lit);
-	int Button();
+	void changeSettings();
+	void EnterDigit(int data);
+	bool history_next(void);
+	bool history_prev(void);
+	void update_from_core(CalcEngine const &core,
+			      bool store_result_in_history = false);
 
 private:
-	int button;
-	bool lit;
+	QValueVector<CALCAMNT> _history_list;
+	int _history_index;
 
-signals:
-	void clicked();
 };
 
-
-
 #endif
