@@ -27,8 +27,10 @@
 class QPushButton;
 class QRadioButton;
 class QButtonGroup;
+class QHButtonGroup;
 class QWidget;
 class DispLogic;
+class KCalcButton;
 #include <kmainwindow.h>
 
 /*
@@ -53,6 +55,7 @@ class DispLogic;
 
 // IMPORTANT this has to come after ../config.h
 #include "kcalc_core.h"
+#include "kcalc_button.h"
 
 class KCalculator : public KMainWindow
 {
@@ -62,6 +65,11 @@ public:
 	KCalculator(QWidget *parent = 0, const char *name = 0);
 	~KCalculator();
 
+signals:
+	void switchInverse(bool);
+	void switchMode(ButtonModeFlags,bool);
+	void switchShowAccels(bool);
+
 private:
 	virtual bool eventFilter( QObject *o, QEvent *e );
 	void updateGeometry();
@@ -72,16 +80,20 @@ private:
 	void setupLogExpKeys(QWidget *parent);
 	void setupTrigKeys(QWidget *parent);
 	void setupStatisticKeys(QWidget *parent);
-	void keyPressEvent( QKeyEvent *e );
+	void setupConstantsKeys(QWidget *parent);
+	void keyPressEvent(QKeyEvent *e);
+	void keyReleaseEvent(QKeyEvent *e);
 	void set_precision();
 	void set_style();
 	void history_next();
 	void history_prev();
+	void resetBase(void) { (BaseChooseGroup->find(1))->animateClick();};
 
 	void UpdateDisplay(bool get_amount_from_core = false,
 			   bool store_result_in_history = false);
 
 protected slots:
+    void changeButtonNames();
     void updateSettings();
     void set_colors();
     void EnterEqual();
@@ -91,6 +103,7 @@ protected slots:
     void slotTrigshow(bool toggled);
     void slotExpLogshow(bool toggled);
     void slotLogicshow(bool toggled);
+    void slotConstantsShow(bool toggled);   
     void slotShowAll(void);
     void slotHideAll(void);
     void slotAngleSelected(int number);
@@ -137,11 +150,18 @@ protected slots:
     void slotStatDataInputclicked(void);
     void slotStatClearDataclicked(void);
     void slotHyptoggled(bool flag);
-    void slotConfigureKeys();
+    void slotC1clicked(void);
+    void slotC2clicked(void);
+    void slotC3clicked(void);
+    void slotC4clicked(void);
+    void slotC5clicked(void);
+    void slotC6clicked(void);
+	
 private:
 	bool inverse;
 	bool hyp_mode;
 	CALCAMNT memory_num;
+	CALCAMNT setvalue;
 
 public:
 	static const CALCAMNT pi;
@@ -152,47 +172,61 @@ private:
     QWidget *mNumericPage;
 
     DispLogic*	calc_display; // for historic reasons in "dlabel.h"
-    QPushButton*        pbBaseChoose;
+    QRadioButton*        pbBaseChoose[4];
     QPushButton*        pbAngleChoose;
-    QDict<QPushButton>  pbStat;
-    QDict<QPushButton>  pbTrig;
-    QDict<QPushButton>  pbExp;
-    QDict<QPushButton>  pbLogic;
-    QPushButton* 	pbEE;
-    QPushButton* 	pbPi;
-    QPushButton* 	pbInv;
-    QPushButton* 	pbMR;
-    QPushButton* 	pbPlusMinus;
-    QPushButton* 	pbMPlusMinus;
-    QPushButton* 	pbReci;
-    QPushButton* 	pbFactorial;
-    QPushButton* 	pbSquare;
-    QPushButton* 	pbPower;
-    QPushButton* 	pbMC;
-    QPushButton* 	pbClear;
-    QPushButton* 	pbAC;
-    QPushButton* 	pbParenOpen;
-    QPushButton* 	pbParenClose;
-    QPushButton* 	pbX;
-    QPushButton* 	pbDivision;
-    QPushButton* 	pbPlus;
-    QPushButton* 	pbMinus;
-    QPushButton* 	pbPeriod;
-    QPushButton* 	pbEqual;
-    QPushButton* 	pbPercent;
-    QPushButton* 	pbMod;
+    QDict<KCalcButton>  pbStat;
+    QDict<KCalcButton>  pbTrig;
+    QDict<KCalcButton>  pbExp;
+    QDict<KCalcButton>  pbLogic;
+    QDict<KCalcButton>  pbConstant;
+    KCalcButton* 	pbAC;
+    KCalcButton* 	pbAND;
+    KCalcButton* 	pbC1; 
+    KCalcButton* 	pbC2; 		
+    KCalcButton* 	pbC3; 
+    KCalcButton* 	pbC4; 	
+    KCalcButton* 	pbC5; 
+    KCalcButton* 	pbC6;
+    KCalcButton* 	pbClear;
+    KCalcButton* 	pbDivision;
+    KCalcButton* 	pbEE;
+    KCalcButton* 	pbEqual;
+    KCalcButton* 	pbFactorial;
+    KCalcButton* 	pbInv;
+    KCalcButton* 	pbMC;
+    KCalcButton* 	pbMinus;
+    KCalcButton* 	pbMod;
+    KCalcButton* 	pbMPlusMinus;
+    KCalcButton* 	pbMR;
+    KCalcButton* 	pbOR;
+    KCalcButton* 	pbParenClose;
+    KCalcButton* 	pbParenOpen;
+    KCalcButton* 	pbPercent;
+    KCalcButton* 	pbPeriod;
+    KCalcButton* 	pbPi;
+    KCalcButton* 	pbPlus;
+    KCalcButton* 	pbPlusMinus;
+    KCalcButton* 	pbPower;
+    KCalcButton* 	pbReci;
+    KSquareButton* 	pbSquare;
+    KCalcButton* 	pbX;
+    KCalcButton* 	pbXOR;
+	
+    QHButtonGroup*      BaseChooseGroup;
     // NumButtonGroup: 0-9 = digits, 0xA-0xF = hex-keys
-    QButtonGroup*       NumButtonGroup;
+    QButtonGroup* 	NumButtonGroup;
 
     KToggleAction *actionStatshow;
     KToggleAction *actionTrigshow;
     KToggleAction *actionLogicshow;
     KToggleAction *actionExpLogshow;
+    KToggleAction *actionConstantsShow;
 
-    QPtrList<QPushButton> mFunctionButtonList;
-    QPtrList<QPushButton> mStatButtonList;
-    QPtrList<QPushButton> mMemButtonList;
-    QPtrList<QPushButton> mOperationButtonList;
+    QPtrList<KCalcButton> mFunctionButtonList;
+    QPtrList<KCalcButton> mStatButtonList;
+    QPtrList<KCalcButton> mMemButtonList;
+    QPtrList<KCalcButton> mOperationButtonList;
+    QPtrList<KCalcButton> mConstButtonList;
 
     int				mInternalSpacing;
 
