@@ -312,9 +312,14 @@ int isoddint(CALCAMNT input)
 
 static CALCAMNT ExecPower(CALCAMNT left_op, CALCAMNT right_op)
 {
-	// printf("ExecPowser %g left_op, %g right_op\n",left_op, right_op);
 	if (right_op == 0)
-		return 1L;
+		if (left_op == 0) // 0^0 not defined
+		{
+			_error = true;		
+			return 0L;
+		}
+		else
+			return 1L;
 
 	if (left_op < 0 && isoddint(1 / right_op))
 		left_op = -1L * POW((-1L * left_op), right_op);
@@ -324,7 +329,7 @@ static CALCAMNT ExecPower(CALCAMNT left_op, CALCAMNT right_op)
 	if (errno == EDOM || errno == ERANGE)
 	{
 		_error = true;
-		return 0;
+		return 0L;
 	}
 	else
 		return left_op;
@@ -645,6 +650,11 @@ void CalcEngine::Factorial(CALCAMNT input)
 
 }
 
+void CalcEngine::InvertSign(CALCAMNT input)
+{
+	_last_result = -input;
+}
+
 void CalcEngine::InvMod(CALCAMNT input)
 {
 	EnterStackFunction(FUNC_INTDIV, input);
@@ -872,9 +882,9 @@ void CalcEngine::Tangens(CALCAMNT input)
 		tmp = input;
 		break;
 	}
-
+	
 	aux = tmp;
-        // make aux positive
+	// make aux positive
 	if (aux < 0) aux = -aux;
 	// put aux between 0 and pi
 	while (aux > pi) aux -= pi;
