@@ -132,7 +132,7 @@ void KCardChooserMain::slotSelected(const QString &slot){
   if (!kapp->dcopClient()->call("kded", "kardsvc", "getCardATR(QString)", 
 			       dataATR, rettype, retval)){
     
-    setATR(i18n("No ATR found.DCOP Error"));
+    setATR(i18n("No ATR found. DCOP Error."));
     _kcardchooser->_managerLabel->setText(i18n("None"));
     enableButtonOK(FALSE);
     return;
@@ -172,24 +172,24 @@ void KCardChooserMain::slotOk(){
   
   
   if (_kcardchooser->_comboSlots->currentText()==QString::null){
-    KMessageBox::sorry (this,i18n("No slot selected"));
+    KMessageBox::sorry (this,i18n("No slot selected."));
     return;
   }
   
   if (_kcardchooser->_atrLabel->text()==QString::null){
-    KMessageBox::sorry (this,i18n("No card ATR detected in ")+_kcardchooser->_comboSlots->currentText());
+    KMessageBox::sorry (this,i18n("No card ATR detected in %1.").arg(kcardchooser->_comboSlots->currentText()));
     return;
   }
 
   if (_kcardchooser->_cardList->currentText()==QString::null){
-    KMessageBox::sorry (this,i18n("Please select an available card implementation "));
+    KMessageBox::sorry (this,i18n("Please select an available card implementation."));
     return;
   }
   KCardDB cardDB;
   if (cardDB.addHandler(_kcardchooser->_atrLabel->text(),
 			  _kcardchooser->_cardList->currentText())){
 
-    KMessageBox::error (this,i18n("Error accessing card database. Check 'ksmartcarddb' file"));
+    KMessageBox::error (this,i18n("Error accessing card database. Check 'ksmartcarddb' file."));
   }
    KDialogBase::slotOk();
 }
@@ -209,7 +209,7 @@ void KCardChooserMain::setSlot(const QString & slot){
     
   }
   
-  KMessageBox::error (this,i18n("Slot '%1' not found in available slots").arg(slot));
+  KMessageBox::error (this,i18n("Slot '%1' not found in available slots.").arg(slot));
   
 }
 
