@@ -30,9 +30,9 @@
 
 static KCmdLineOptions options[] =
 {
-	{ "slot <slot>", I18N_NOOP("Slot name of the card in question."), 0 },
-	{ "atr <atr>", I18N_NOOP("ATR of the card in question."), 0 },
-	{ 0, 0, 0}
+	{ "slot <slot>", I18N_NOOP("Slot name of the card in question"), 0 },
+	{ "atr <atr>", I18N_NOOP("ATR of the card in question"), 0 },
+	KCmdLineLastOption
 };
 
 
