@@ -33,7 +33,7 @@ int main(int argc, char **argv)
   KConfig *config = kapp->config();
 
   config->setGroup("General");
-  QString font(config->readEntry("font", KGlobalSettings::generalFont().family()));
+  QString font(config->readEntry("selectedFont", KGlobalSettings::generalFont().family()));
   QChar c = QChar(static_cast<unsigned short>(config->readNumEntry("char",33)));
   int tn = config->readNumEntry("table",0);
   bool direction = config->readNumEntry("entryDirection",0);
