@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: sshdlg.cpp,v 1.6 2003/04/10 18:17:31 ravi Exp $
+ * $Id: sshdlg.cpp,v 1.8 2004/02/22 21:42:07 mhunter Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -59,13 +59,13 @@ bool KDEsshDialog::checkPassword(const char *password)
 
     case SshProcess::SshNotFound:
 	KMessageBox::sorry(this,
-		i18n("The program `ssh' or `kdesu_stub` is not found!\n"
+		i18n("The programs 'ssh' or 'kdesu_stub' cannot be found.\n"
 		"Make sure your PATH is set correctly."));
 	done(Rejected);
 	return false;
 
     case SshProcess::SshIncorrectPassword:
-	KMessageBox::sorry(this, i18n("Incorrect password! Please try again."));
+	KMessageBox::sorry(this, i18n("Incorrect password. Please try again."));
 	return false;
 
     default:
