@@ -1,7 +1,7 @@
 /*
  * disklist.cpp
  *
- * $Id: disklist.cpp,v 1.34 2004/01/07 22:28:06 adridg Exp $
+ * $Id: disklist.cpp,v 1.36.2.1 2004/11/14 11:15:03 mcamen Exp $
  *
  * Copyright (c) 1999 Michael Kropfberger <michael.kropfberger@gmx.net>
  *
@@ -209,8 +209,10 @@ QFile f(FSTAB);
 	    //kdDebug() << "    Mount-Options: [" << disk->mountOptions() << "]" << endl;
          if ( (disk->deviceName() != "none")
 	      && (disk->fsType() != "swap")
+	      && (disk->fsType() != "sysfs")
 	      && (disk->mountPoint() != "/dev/swap")
 	      && (disk->mountPoint() != "/dev/pts")
+	      && (disk->mountPoint() != "/dev/shm")
 	      && (disk->mountPoint().find("/proc") == -1 ) )
 	   replaceDeviceEntry(disk);
          else
@@ -342,8 +344,10 @@ void DiskList::dfDone()
       if ( (disk->kBSize() > 0)
 	   && (disk->deviceName() != "none")
 	   && (disk->fsType() != "swap")
+	   && (disk->fsType() != "sysfs")
 	   && (disk->mountPoint() != "/dev/swap")
 	   && (disk->mountPoint() != "/dev/pts")
+	   && (disk->mountPoint() != "/dev/shm")
 	   && (disk->mountPoint().find("/proc") == -1 ) ) {
         disk->setMounted(TRUE);    // its now mounted (df lists only mounted)
 	replaceDeviceEntry(disk);
@@ -380,7 +384,7 @@ void DiskList::deleteAllMountedAt(const QString &mountpoint)
 **/
 void DiskList::replaceDeviceEntry(DiskEntry *disk)
 {
-  kdDebug() << k_funcinfo << endl;
+  //kdDebug() << k_funcinfo << disk->deviceRealName() << " " << disk->realMountPoint() << endl;
 
   //
   // The 'disks' may already already contain the 'disk'. If it do
@@ -394,14 +398,17 @@ void DiskList::replaceDeviceEntry(DiskEntry *disk)
   //
   //int pos=disks->find(disk);
 
+  QString deviceRealName = disk->deviceRealName();
+  QString realMountPoint = disk->realMountPoint();
+
   int pos = -1;
   for( u_int i=0; i<disks->count(); i++ )
   {
     DiskEntry *item = disks->at(i);
-    int res = disk->deviceName().compare( item->deviceName() );
+    int res = deviceRealName.compare( item->deviceRealName() );
     if( res == 0 )
     {
-      res = disk->mountPoint().compare( item->mountPoint() );
+      res = realMountPoint.compare( item->realMountPoint() );
     }
     if( res == 0 )
     {
@@ -415,13 +422,12 @@ void DiskList::replaceDeviceEntry(DiskEntry *disk)
     if ((disk->fsType() == "?") || (disk->fsType() == "cachefs")) {
       //search for fitting cachefs-entry in static /etc/vfstab-data
       DiskEntry* olddisk = disks->first();
-      QString odiskName;
       while (olddisk != 0) {
         int p;
         // cachefs deviceNames have no / behind the host-column
 	// eg. /cache/cache/.cfs_mnt_points/srv:_home_jesus
 	//                                      ^    ^
-        odiskName = olddisk->deviceName().copy();
+        QString odiskName = olddisk->deviceName();
         int ci=odiskName.find(':'); // goto host-column
         while ((ci =odiskName.find('/',ci)) > 0) {
            odiskName.replace(ci,1,"_");
@@ -464,6 +470,11 @@ void DiskList::replaceDeviceEntry(DiskEntry *disk)
       disk->setMountCommand(olddisk->mountCommand());
       disk->setUmountCommand(olddisk->umountCommand());
 
+      // Same device name, but maybe one is a symlink and the other is its target
+      // Keep the shorter one then, /dev/hda1 looks better than /dev/ide/host0/bus0/target0/lun0/part1
+      if ( disk->deviceName().length() > olddisk->deviceName().length() )
+          disk->setDeviceName(olddisk->deviceName());
+
       //FStab after an older DF ... needed for critFull
       //so the DF-KBUsed survive a FStab lookup...
       //but also an unmounted disk may then have a kbused set...
