@@ -22,6 +22,8 @@
  */
 
 #include <qregexp.h>
+#include <qfileinfo.h>
+#include <qdir.h>
 
 #include <kglobal.h>
 #include <kdebug.h>
@@ -261,12 +263,32 @@ void DiskEntry::setDeviceName(const QString & deviceName)
  emit deviceNameChanged();
 }
 
+QString DiskEntry::deviceRealName() const
+{
+ QFileInfo inf( device );
+ QDir dir( inf.dirPath( true ) );
+ QString relPath = inf.fileName();
+ if ( inf.isSymLink() ) {
+  QString link = inf.readLink();
+  if ( link.startsWith( "/" ) )
+    return link;
+  relPath = link;
+ }
+ return dir.canonicalPath() + "/" + relPath;
+}
+
 void DiskEntry::setMountPoint(const QString & mountPoint)
 {
   mountedOn=mountPoint;
  emit mountPointChanged();
 }
 
+QString DiskEntry::realMountPoint() const
+{
+ QDir dir( mountedOn );
+ return dir.canonicalPath();
+}
+
 void DiskEntry::setMountOptions(const QString & mountOptions)
 {
  options=mountOptions;
