@@ -1,5 +1,5 @@
 /*
- * $Id: kdf.cpp,v 1.28 2003/09/20 12:28:02 mlaurent Exp $
+ * $Id: kdf.cpp,v 1.31 2004/07/13 20:33:13 bmeyer Exp $
  *
  * kdf.cpp - KDiskFree
  *
@@ -27,15 +27,14 @@
 #include <kaboutdata.h>
 #include <kstdaction.h>
 #include <kaction.h>
-#include <kkeydialog.h>
 
 #include "kdf.h"
 #include <kpopupmenu.h>
 
-static const char *description =
+static const char description[] =
 	I18N_NOOP("KDE free disk space utility");
 
-static const char *version = "v0.5";
+static const char version[] = "v0.5";
 
 
 /***************************************************************/
@@ -48,11 +47,12 @@ KDFTopLevel::KDFTopLevel(QWidget *, const char *name)
 
   KStdAction::quit(this, SLOT(close()), actionCollection());
   KStdAction::preferences(kdf, SLOT(settingsBtnClicked()), actionCollection());
-  KStdAction::keyBindings( this, SLOT( slotConfigureKeys() ), actionCollection() );
+  KStdAction::keyBindings(guiFactory(), SLOT(configureShortcuts()), 
+actionCollection());
   setCentralWidget(kdf);
   //  kdf->setMinimumSize(kdf->sizeHint());
   kdf->resize(kdf->sizeHint());
-  createGUI();
+  setupGUI(KMainWindow::Keys | StatusBar | Save | Create);
 }
 
 
@@ -63,12 +63,6 @@ bool KDFTopLevel::queryExit( void )
 }
 
 
-void KDFTopLevel::slotConfigureKeys()
-{
-  KKeyDialog::configure( actionCollection(), this );
-}
-
-
 /***************************************************************/
 int main(int argc, char **argv)
 {
