@@ -13,7 +13,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
 
@@ -36,6 +36,7 @@ class COptionDialog : public KDialogBase
   protected slots:
     virtual void slotOk( void );
     virtual void slotApply( void );
+    void slotChanged();
 
   signals:
     void valueChanged( void );
@@ -43,6 +44,7 @@ class COptionDialog : public KDialogBase
   private:
     KDFConfigWidget *mConf;
     MntConfigWidget *mMnt;
+    bool dataChanged;
 };
 
 #endif
