@@ -27,6 +27,7 @@
 #include <kdiroperator.h>
 #include <krecentdocument.h>
 #include <ktoolbar.h>
+#include <kpushbutton.h>
 
 #include "ktextfiledlg.h"
 
@@ -146,7 +147,8 @@ KURL KTextFileDialog::getOpenURLwithEncoding(
      const QString& filter,
      QWidget *parent,
      const QString& caption,
-     const QString& encoding)
+     const QString& encoding,
+     const QString& buttontext)
 {
   KTextFileDialog dlg(startDir, filter, parent, "filedialog", true);
   dlg.setEncoding(encoding);
@@ -154,6 +156,8 @@ KURL KTextFileDialog::getOpenURLwithEncoding(
 
   dlg.setCaption(caption.isNull() ? i18n("Open") : caption);
   dlg.ops->clearHistory();
+  if (!buttontext.isEmpty())
+    dlg.okButton()->setText(buttontext);
   dlg.exec();
 
   KURL url = dlg.selectedURL();
