@@ -46,7 +46,7 @@
 
 FloppyData::FloppyData(QWidget * parent, const char * name)
  : KDialog( parent, name ),
-	formatActions(0L)
+	formatActions(0L), m_canLowLevel(false)
 {
 
 	formating = false;
@@ -96,12 +96,22 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
 	filesystemComboBox = new QComboBox( false, this, "ComboBox_2" );
 	g1->addWidget( filesystemComboBox, 2, 1, AlignLeft );
 
-	filesystemComboBox->insertItem(i18n("DOS"));
-#ifdef ANY_LINUX
-	filesystemComboBox->insertItem(i18n("ext2"));
-#endif
-#ifdef ANY_BSD
-	filesystemComboBox->insertItem(i18n("UFS"));
+        uint numFileSystems = 0;
+
+        if (FATFilesystem::runtimeCheck()) {
+            filesystemComboBox->insertItem(i18n("DOS"));
+            ++numFileSystems;
+        }
+#if defined(ANY_LINUX)
+        if (Ext2Filesystem::runtimeCheck()) {
+            filesystemComboBox->insertItem(i18n("ext2"));
+            ++numFileSystems;
+        }
+#elif defined(ANY_BSD)
+        if (UFSFilesystem::runtimeCheck()) {
+            filesystemComboBox->insertItem(i18n("UFS"));
+            ++numFileSystems;
+        }
 #endif
 
         v1->addSpacing( 10 );
@@ -118,9 +128,17 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
 
 	fullformat = new QRadioButton( buttongroup, "RadioButton_3" );
 	fullformat->setText(i18n( "Fu&ll format") );
-	fullformat->setChecked(true);
         v2->addWidget( fullformat, AlignLeft );
-
+        
+        m_canLowLevel = FDFormat::runtimeCheck();
+        if (m_canLowLevel){
+            fullformat->setChecked(true);
+        }
+        else {
+            fullformat->setDisabled(true);
+            quick->setChecked(true);
+        }
+        
 	verifylabel = new QCheckBox( buttongroup, "RadioButton_4" );
 	verifylabel->setText(i18n( "&Verify integrity" ));
 	verifylabel->setChecked(true);
@@ -136,7 +154,7 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
 
 	lineedit = new QLineEdit( buttongroup, "Lineedit" );
 	lineedit->setText(i18n( "KDE Floppy") );
-	lineedit->setMaxLength(11);
+	lineedit->setMaxLength(11); // ### TODO: translators need to need this limit!!!
         lineedit->setMinimumWidth( lineedit->sizeHint().width() );
         h2->addWidget( lineedit, AlignRight );
 
@@ -147,6 +165,8 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
 	formatbutton = new KPushButton( this, "PushButton_3" );
 	formatbutton->setText(i18n( "&Format") );
 	formatbutton->setAutoRepeat( false );
+        if (!numFileSystems)
+            formatbutton->setDisabled(false); // We have not any helper program for creating any file system
 	connect(formatbutton,SIGNAL(clicked()),this,SLOT(format()));
         v3->addWidget( formatbutton );
 
@@ -180,7 +200,12 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
 	readSettings();
 	setWidgets();
 
-	findExecutables();
+    if (!numFileSystems) {
+        // ### TODO: better error message
+        KMessageBox::error(this,
+            i18n("KFloppy cannot find the support programs needed "
+                    "for sensible operation."));
+    }
 
     int maxW = QMAX( deviceComboBox->sizeHint().width(),
                      densityComboBox->sizeHint().width() );
@@ -268,30 +293,6 @@ bool FloppyData::setInitialDevice(const QString& dev)
   return ok;
 }
 
-
-void FloppyData::findExecutables()
-{
-	bool fruitful = true ;
-	fruitful &= FDFormat::runtimeCheck();
-	fruitful &= FATFilesystem::runtimeCheck();
-#ifdef ANY_BSD
-	fruitful &= UFSFilesystem::runtimeCheck();
-#else
-#ifdef ANY_LINUX
-	fruitful &= Ext2Filesystem::runtimeCheck();
-#else
-	fruitful = false;
-#endif
-#endif
-
-  if (!fruitful) {
-    formatbutton->setEnabled(false);
-    KMessageBox::error(this,
-    	i18n("KFloppy cannot find the support programs needed "
-		"for sensible operation."));
-  }
-}
-
 void FloppyData::quit(){
   if (formatActions) formatActions->quit();
   writeSettings();
@@ -313,7 +314,7 @@ void FloppyData::setEnabled(bool b)
   filesystemComboBox->setEnabled(b);
   buttongroup->setEnabled(b);
   quick->setEnabled(b);
-  fullformat->setEnabled(b);
+  fullformat->setEnabled(b && m_canLowLevel);
   verifylabel->setEnabled(b);
   labellabel->setEnabled(b);
   lineedit->setEnabled(b);
@@ -507,7 +508,7 @@ void FloppyData::errslot(){
 
   if(errstring.contains("ioctl(FDFMTBEG)")){
 
-    QString str = i18n(
+    QString str = i 18n(
 		"Cannot access floppy or floppy drive.\n"
 		"Please insert a floppy and make sure that you "
 		"have selected a valid floppy drive.");
@@ -519,7 +520,7 @@ void FloppyData::errslot(){
 
   }
 
-  QString str = i18n("Cannot format: %1\n%2").arg(drive).arg(errstring);
+  QString str = i 18n("Cannot format: %1\n%2").arg(drive).arg(errstring);
 
   KMessageBox::error(this, str);
 
@@ -558,7 +559,7 @@ void FloppyData::readfsStdout(KProcess *, char *buffer, int buflen){
     if(findKeyWord(mystring,"BBF ")){
       int bblock = mystring.left(8).toInt();
       QString mstr;
-      mstr = i18n("Block %1 is bad. Continuing...").arg(bblock);
+      mstr = i 18n("Block %1 is bad. Continuing...").arg(bblock);
       frame->setText(mstr);
     }
 
@@ -636,7 +637,7 @@ void FloppyData::fserrslot(){
 
   if(fserrstring.contains("No such device")){
 
-    QString str = i18n(
+    QString str = i 18n(
 		"Cannot access floppy or floppy drive.\n"
 		"Please insert a floppy and make sure that you "
  		"have selected a valid floppy drive.");
@@ -649,7 +650,7 @@ void FloppyData::fserrslot(){
 
   reset();
 
-  QString str = i18n("Cannot create a filesystem on: %1\n%2")
+  QString str = i 18n("Cannot create a filesystem on: %1\n%2")
 	      .arg(drive).arg(fserrstring);
 
   KMessageBox::error(this, str);
@@ -676,7 +677,7 @@ void FloppyData::cf2done(){
     return;
 
   if(!lcquick){
-    QString str = i18n(
+    QString str = i 18n(
 		"The floppy was successfully formatted.\n"
 		"Blocks marked bad: %1\n"
 		"Raw Capacity: %2\n")
@@ -686,7 +687,7 @@ void FloppyData::cf2done(){
     KMessageBox::information(this, str);
   }
   else{
-    QString str = i18n("All files were successfully erased.");
+    QString str = i 18n("All files were successfully erased.");
 
     KMessageBox::information(this, str);
   }
@@ -764,9 +765,9 @@ void FloppyData::setWidgets(){
 
   labellabel->setChecked(labelconfig);
   verifylabel->setChecked(verifyconfig);
-  quick->setChecked(quickformatconfig);
+  quick->setChecked(quickformatconfig || !m_canLowLevel);
 
-  fullformat->setChecked(!quickformatconfig);
+  fullformat->setChecked(!quickformatconfig && m_canLowLevel);
   lineedit->setText(labelnameconfig);
 
   for(int i = 0 ; i < deviceComboBox->count(); i++){
