@@ -24,6 +24,8 @@
 #include <qstring.h>
 #include <qlabel.h>
 #include <qapplication.h>
+#include <kio/netaccess.h> 
+#include <qcheckbox.h>
 
 #include <kmessagebox.h>
 #include <klocale.h>
@@ -33,11 +35,19 @@
 #include <kcharsets.h>
 #include <kpassivepopup.h>
 #include <kiconloader.h>
-#include <kstartupinfo.h>
-
+#include <kaction.h>
 #include <qtextcodec.h>
+#include <kprocess.h>
+#include <kprocio.h>
+#include <kconfig.h>
+#include <qfile.h>
+#include <kled.h>
+#include <kdebug.h>
+#include <ktempfile.h>
 
 #include "kgpginterface.h"
+#include "listkeys.h"
+#include "detailedconsole.h"
 
 KgpgInterface::KgpgInterface()
 {}
@@ -103,10 +113,6 @@ void KgpgInterface::KgpgEncryptFile(QStringList encryptKeys,KURL srcUrl,KURL des
         /////////  when process ends, update dialog infos
         QObject::connect(proc, SIGNAL(processExited(KProcess *)),this,SLOT(encryptfin(KProcess *)));
         QObject::connect(proc,SIGNAL(readReady(KProcIO *)),this,SLOT(readencprocess(KProcIO *)));
-        // bad hack for kde3.2 - kgpg shows windows only after returning from newInstance(),
-        // but KUniqueApplication cancels the startup notification after return from newInstance(),
-        // and focus stealing prevention in kde3.2 can't handle that
-        KStartupInfo::disableAutoAppStartedSending( true );
         proc->start(KProcess::NotifyOnExit,true);
 }
 
@@ -117,7 +123,6 @@ KgpgInterface::~KgpgInterface()
 
 void KgpgInterface::encryptfin(KProcess *)
 {
-        KStartupInfo::disableAutoAppStartedSending( false );
         if (message.find("END_ENCRYPTION")!=-1)
                 emit encryptionfinished(sourceFile);
         else {
@@ -127,11 +132,10 @@ void KgpgInterface::encryptfin(KProcess *)
 
 void KgpgInterface::readencprocess(KProcIO *p)
 {
-        KStartupInfo::disableAutoAppStartedSending( false );
         QString required;
         while (p->readln(required,true)!=-1) {
                 if (required.find("BEGIN_ENCRYPTION",0,false)!=-1)
-                        emit processstarted();
+                        emit processstarted(sourceFile.path());
                 if (required.find("GET_")!=-1) {
                         if (required.find("openfile.overwrite.okay")!=-1)
                                 p->writeStdin("Yes");
@@ -160,9 +164,10 @@ void KgpgInterface::KgpgDecryptFile(KURL srcUrl,KURL destUrl,QStringList Options
 {
         message=QString::null;
         step=3;
+	decryptUrl=srcUrl.path();
         userIDs=QString::null;
         anonymous=false;
-	kdDebug()<<"Starting decrypt"<<endl;
+	
         KProcIO *proc=new KProcIO();
 
                 *proc<<"gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--status-fd=2"<<"--command-fd=0";
@@ -177,13 +182,11 @@ void KgpgInterface::KgpgDecryptFile(KURL srcUrl,KURL destUrl,QStringList Options
         
         QObject::connect(proc, SIGNAL(processExited(KProcess *)),this,SLOT(decryptfin(KProcess *)));
         QObject::connect(proc,SIGNAL(readReady(KProcIO *)),this,SLOT(readdecprocess(KProcIO *)));
-        KStartupInfo::disableAutoAppStartedSending( true );
         proc->start(KProcess::NotifyOnExit,true);
 }
 
 void KgpgInterface::decryptfin(KProcess *)
 {
-        KStartupInfo::disableAutoAppStartedSending( false );
         if ((message.find("DECRYPTION_OKAY")!=-1) && (message.find("END_DECRYPTION")!=-1)) //&& (message.find("GOODMDC")!=-1)
                 emit decryptionfinished();
         else
@@ -192,11 +195,10 @@ void KgpgInterface::decryptfin(KProcess *)
 
 void KgpgInterface::readdecprocess(KProcIO *p)
 {
-        KStartupInfo::disableAutoAppStartedSending( false );
         QString required;
         while (p->readln(required,true)!=-1) {
                 if (required.find("BEGIN_DECRYPTION",0,false)!=-1)
-                        emit processstarted();
+                        emit processstarted(decryptUrl);
                 if (required.find("USERID_HINT",0,false)!=-1)
 			updateIDs(required);
 
@@ -218,7 +220,7 @@ void KgpgInterface::readdecprocess(KProcIO *p)
                                 if ((step<3) && (!anonymous))
                                         passdlgmessage=i18n("<b>Bad passphrase</b>. You have %1 tries left.<br>").arg(step);
 
-                                passdlgmessage+=i18n("Enter passphrase for <b>%1</b>").arg(checkForUtf8(userIDs));
+                                passdlgmessage+=i18n("Enter passphrase for <b>%1</b>").arg(checkForUtf8bis(userIDs));
                                 int code=KPasswordDialog::getPassword(passphrase,passdlgmessage);
                                 if (code!=QDialog::Accepted) {
                                         delete p;
@@ -244,12 +246,12 @@ void KgpgInterface::readdecprocess(KProcIO *p)
 void KgpgInterface::KgpgEncryptText(QString text,QStringList userIDs, QStringList Options)
 {
         message=QString::null;
+	QString txtprocess;
 	//QTextCodec *codec = KGlobal::charsets()->codecForName(KGlobal::locale()->encoding());
 	QTextCodec *codec =QTextCodec::codecForLocale ();
 	if (codec->canEncode(text)) txtprocess=text;
 	else txtprocess=text.utf8();
 	
-        txtsent=false;
         KProcIO *proc=new KProcIO();
         *proc<<"gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--command-fd=0"<<"--status-fd=2";
         
@@ -268,15 +270,16 @@ void KgpgInterface::KgpgEncryptText(QString text,QStringList userIDs, QStringLis
 
         QObject::connect(proc, SIGNAL(processExited(KProcess *)),this,SLOT(txtencryptfin(KProcess *)));
         QObject::connect(proc,SIGNAL(readReady(KProcIO *)),this,SLOT(txtreadencprocess(KProcIO *)));
-        KStartupInfo::disableAutoAppStartedSending( true );
-        proc->start(KProcess::NotifyOnExit,true);
+        proc->start(KProcess::NotifyOnExit,false);
+	emit txtencryptionstarted();
+	proc->writeStdin(txtprocess,false);
+	proc->closeWhenDone();
 }
 
 
 void KgpgInterface::txtencryptfin(KProcess *)
 {
-        KStartupInfo::disableAutoAppStartedSending( false );
-        if (txtsent)
+        if (!message.isEmpty())
                 emit txtencryptionfinished(QString::fromUtf8(message.ascii()));
         else
                 emit txtencryptionfinished(QString::null);
@@ -284,7 +287,6 @@ void KgpgInterface::txtencryptfin(KProcess *)
 
 void KgpgInterface::txtreadencprocess(KProcIO *p)
 {
-        KStartupInfo::disableAutoAppStartedSending( false );
         QString required;
         while (p->readln(required,true)!=-1) {
 	if ((required.find("passphrase.enter")!=-1))
@@ -300,15 +302,7 @@ void KgpgInterface::txtreadencprocess(KProcIO *p)
               p->writeStdin(passphrase,true);
             } 
 	    else
-		if (required.find("BEGIN_ENCRYPTION")!=-1) {
-			emit txtencryptionstarted();
-                        p->writeStdin(txtprocess,false);
-                        p->closeWhenDone();
-                } else
-                        if (required.find("END_ENCRYPTION")!=-1)
-                                txtsent=true;
-                        else
-                                if (!required.startsWith("[GNUPG:]")) message+=required+"\n";
+		if (!required.startsWith("[GNUPG:]")) message+=required+"\n";
         }
 }
 
@@ -317,6 +311,7 @@ void KgpgInterface::txtreadencprocess(KProcIO *p)
 
 void KgpgInterface::KgpgDecryptText(QString text,QStringList Options)
 {
+ QString txtprocess;
   message=QString::null;
   userIDs=QString::null;
   step=3;
@@ -336,14 +331,12 @@ badmdc=false;
 
   QObject::connect(proc, SIGNAL(processExited(KProcess *)),this,SLOT(txtdecryptfin(KProcess *)));
   QObject::connect(proc,SIGNAL(readReady(KProcIO *)),this,SLOT(txtreaddecprocess(KProcIO *)));
-  KStartupInfo::disableAutoAppStartedSending( true );
   proc->start(KProcess::NotifyOnExit,false);
   proc->writeStdin(txtprocess,false);
 }
 
 void KgpgInterface::txtdecryptfin(KProcess *)
 {
-KStartupInfo::disableAutoAppStartedSending( false );
 if ((decok) && (!badmdc)) 
 {
 message.remove(0,message.find("BEGIN_DECRYPTION")+17);
@@ -361,7 +354,6 @@ emit txtdecryptionfailed(message);
 
 void KgpgInterface::txtreaddecprocess(KProcIO *p)
 {
-  KStartupInfo::disableAutoAppStartedSending( false );
   QString required;
   while (p->readln(required,true)!=-1)
     {
@@ -386,7 +378,7 @@ void KgpgInterface::txtreaddecprocess(KProcIO *p)
                 passdlgmessage=i18n("<b>No user id found</b>. Trying all secret keys.<br>");
               if ((step<3) && (!anonymous))
                 passdlgmessage=i18n("<b>Bad passphrase</b>. You have %1 tries left.<br>").arg(step);
-              passdlgmessage+=i18n("Enter passphrase for <b>%1</b>").arg(checkForUtf8(userIDs));
+              passdlgmessage+=i18n("Enter passphrase for <b>%1</b>").arg(checkForUtf8bis(userIDs));
               int code=KPasswordDialog::getPassword(passphrase,passdlgmessage);
               if (code!=QDialog::Accepted)
                 {
@@ -416,6 +408,94 @@ void KgpgInterface::txtreaddecprocess(KProcIO *p)
 	}
 }
 
+//////////////////////////////////////////////////////////////////////////////////////////////////////////    Text signing
+
+
+void KgpgInterface::KgpgSignText(QString text,QString userIDs, QStringList Options)
+{
+        message=QString::null;
+	step=4;
+	QString txtprocess;
+	QTextCodec *codec =QTextCodec::codecForLocale ();
+	if (codec->canEncode(text)) txtprocess=text;
+	else txtprocess=text.utf8();
+	
+        KProcIO *proc=new KProcIO();
+        *proc<<"gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--command-fd=0"<<"--status-fd=1";
+        
+	for ( QStringList::Iterator it = Options.begin(); it != Options.end(); ++it )
+		if (!QFile::encodeName(*it).isEmpty()) *proc<< QFile::encodeName(*it);
+        *proc<<"--clearsign"<<"-u"<<userIDs;
+
+        /////////  when process ends, update dialog infos
+
+        QObject::connect(proc, SIGNAL(processExited(KProcess *)),this,SLOT(txtsignfin(KProcess *)));
+        QObject::connect(proc,SIGNAL(readReady(KProcIO *)),this,SLOT(txtsignprocess(KProcIO *)));
+
+	//emit txtsigningstarted();
+
+	proc->start(KProcess::NotifyOnExit,false);
+	/*if (useAgent)
+	{
+	kdDebug(2100)<<"Using Agent+++++++++++++"<<endl;
+	//KMessageBox::sorry(0,"using agent");
+	proc->writeStdin(txtprocess,true);
+	proc->closeWhenDone();
+	}
+	else*/
+	message=txtprocess;
+}
+
+
+void KgpgInterface::txtsignfin(KProcess *)
+{
+        if (!message.isEmpty())
+                emit txtSignOver(message);
+        else
+                emit txtSignOver(QString::null);
+}
+
+void KgpgInterface::txtsignprocess(KProcIO *p)
+{
+        QString required;
+        while (p->readln(required,true)!=-1) {
+//	kdDebug(2100)<<"SIGNING: "<<required<<endl;
+	
+	if (required.find("USERID_HINT",0,false)!=-1)
+        updateIDs(required);
+	
+	if (required.find("GOOD_PASSPHRASE")!=-1)
+	{
+	p->writeStdin(message,true);
+	message=QString::null;
+	p->closeWhenDone();
+	}
+	
+	if ((required.find("passphrase.enter")!=-1))
+            {
+	      step--;
+              if (userIDs.isEmpty())
+                userIDs=i18n("[No user id found]");
+              QCString passphrase;
+              QString passdlgmessage;
+              if (step<3)
+              passdlgmessage=i18n("<b>Bad passphrase</b>. You have %1 tries left.<br>").arg(step);
+              passdlgmessage+=i18n("Enter passphrase for <b>%1</b>").arg(checkForUtf8bis(userIDs));
+              int code=KPasswordDialog::getPassword(passphrase,passdlgmessage);
+	      if (code!=QDialog::Accepted)
+                {
+                  delete p;
+                  return;
+                }
+              p->writeStdin(passphrase,true);		
+            } 
+	    else
+		if (!required.startsWith("[GNUPG:]")) message+=required+"\n";
+        }
+}
+
+
+////////////////////////////////////////////////   decrypt file to text
 
 void KgpgInterface::KgpgDecryptFileToText(KURL srcUrl,QStringList Options)
 {
@@ -438,10 +518,71 @@ badmdc=false;
 
   QObject::connect(proc, SIGNAL(processExited(KProcess *)),this,SLOT(txtdecryptfin(KProcess *)));
   QObject::connect(proc,SIGNAL(readReady(KProcIO *)),this,SLOT(txtreaddecprocess(KProcIO *)));
-  KStartupInfo::disableAutoAppStartedSending( true );
   proc->start(KProcess::NotifyOnExit,false);
 }
 
+
+///////////////////////////////////////////////////////          verify text
+
+
+void KgpgInterface::KgpgVerifyText(QString text)
+{
+
+		QTextCodec *codec =QTextCodec::codecForLocale ();
+		if (!codec->canEncode(text)) text=text.utf8();
+		signmiss=false;
+		signID=QString::null;
+		message=QString::null;
+		 KProcIO *verifyproc=new KProcIO();
+        	*verifyproc<<"gpg"<<"--no-secmem-warning"<<"--status-fd=2"<<"--command-fd=0"<<"--verify";
+        	connect(verifyproc, SIGNAL(processExited(KProcess *)),this, SLOT(slotverifyresult(KProcess *)));
+        	connect(verifyproc, SIGNAL(readReady(KProcIO *)),this, SLOT(slotverifyread(KProcIO *)));
+        	verifyproc->start(KProcess::NotifyOnExit,true);
+		verifyproc->writeStdin (text);
+		verifyproc->closeWhenDone();
+}		
+		
+		
+void KgpgInterface::slotverifyresult(KProcess*)
+{
+if (signmiss) emit missingSignature(signID);
+    else {
+	if (signID.isEmpty()) signID=i18n("No signature found.");
+	emit verifyOver(signID,message);
+	}
+//kdDebug(2100) << "GPG VERIFY OVER________"<<endl;
+}
+
+void KgpgInterface::slotverifyread(KProcIO *p)
+{
+QString required;
+  while (p->readln(required,true)!=-1)
+    {
+    message+=required+"\n";
+    required=required.section("]",1,-1).stripWhiteSpace();
+     if (required.startsWith("GOODSIG"))
+     {
+     signID=i18n("<qt>Good signature from:<br><b>%1</b><br>Key ID: %2</qt>").arg(required.section(" ",2,-1).replace(QRegExp("<"),"&lt;")).arg("0x"+required.section(" ",1,1).right(8));
+     }
+     if (required.startsWith("BADSIG")) 
+     {
+     signID=i18n("<qt><b>Bad signature</b> from:<br>%1<br>Key ID: %2<br><br><b>Text is corrupted.</b></qt>").arg(required.section(" ",2,-1).replace(QRegExp("<"),"&lt;")).arg("0x"+required.section(" ",1,1).right(8));
+     }
+     if (required.startsWith("NO_PUBKEY")) 
+     {
+     signID="0x"+required.section(" ",1,1).right(8);
+     signmiss=true;
+     }
+     if (required.startsWith("UNEXPECTED") || required.startsWith("NODATA"))
+	signID=i18n("No signature found.");
+     if (required.startsWith("TRUST_UNDEFINED"))
+     signID+=i18n("The signature is valid, but the key is untrusted");
+     if (required.startsWith("TRUST_ULTIMATE"))
+     signID+=i18n("The signature is valid, and the key is ultimately trusted");
+     }
+}
+
+
 ///////////////////////////////////////////////////////////////////////////////////////////////////   MD5
 
 Md5Widget::Md5Widget(QWidget *parent, const char *name,KURL url):KDialogBase( parent, name, true,i18n("MD5 Checksum"),Apply | Close)
@@ -540,7 +681,6 @@ void KgpgInterface::KgpgSignFile(QString keyID,KURL srcUrl,QStringList Options)
 
         QObject::connect(proc, SIGNAL(processExited(KProcess *)),this,SLOT(signfin(KProcess *)));
         QObject::connect(proc,SIGNAL(readReady(KProcIO *)),this,SLOT(readsignprocess(KProcIO *)));
-        KStartupInfo::disableAutoAppStartedSending( true );
         proc->start(KProcess::NotifyOnExit,true);
 }
 
@@ -548,7 +688,6 @@ void KgpgInterface::KgpgSignFile(QString keyID,KURL srcUrl,QStringList Options)
 
 void KgpgInterface::signfin(KProcess *)
 {
-        KStartupInfo::disableAutoAppStartedSending( false );
         if (message.find("SIG_CREATED")!=-1)
                 KMessageBox::information(0,i18n("The signature file %1 was successfully created.").arg(file.filename()));
         else if (message.find("BAD_PASSPHRASE")!=-1)
@@ -561,7 +700,6 @@ void KgpgInterface::signfin(KProcess *)
 
 void KgpgInterface::readsignprocess(KProcIO *p)
 {
-        KStartupInfo::disableAutoAppStartedSending( false );
         QString required;
         while (p->readln(required,true)!=-1) {
                 if (required.find("USERID_HINT",0,false)!=-1) 
@@ -577,7 +715,7 @@ void KgpgInterface::readsignprocess(KProcIO *p)
                                 QString passdlgmessage;
                                 if (step<3)
                                         passdlgmessage=i18n("<b>Bad passphrase</b>. you have %1 tries left.<br>").arg(step);
-                                passdlgmessage+=i18n("Enter passphrase for <b>%1</b>").arg(checkForUtf8(userIDs));
+                                passdlgmessage+=i18n("Enter passphrase for <b>%1</b>").arg(checkForUtf8bis(userIDs));
                                 int code=KPasswordDialog::getPassword(passphrase,passdlgmessage);
                                 if (code!=QDialog::Accepted) {
                                         delete p;
@@ -603,6 +741,8 @@ void KgpgInterface::KgpgVerifyFile(KURL sigUrl,KURL srcUrl)
 {
         //////////////////////////////////////   verify signature for a chosen file
         message=QString::null;
+	signID=QString::null;
+	signmiss=false;
         /////////////       create gpg command
         KProcIO *proc=new KProcIO();
         file=sigUrl;
@@ -613,59 +753,57 @@ void KgpgInterface::KgpgVerifyFile(KURL sigUrl,KURL srcUrl)
 
         QObject::connect(proc, SIGNAL(processExited(KProcess *)),this,SLOT(verifyfin(KProcess *)));
         QObject::connect(proc,SIGNAL(readReady(KProcIO *)),this,SLOT(readprocess(KProcIO *)));
-        KStartupInfo::disableAutoAppStartedSending( true );
         proc->start(KProcess::NotifyOnExit,true);
 }
 
 
 void KgpgInterface::readprocess(KProcIO *p)
 {
-        KStartupInfo::disableAutoAppStartedSending( false );
-        QString required;
-        while (p->readln(required,true)!=-1) {
-                if (required.find("GET_")!=-1) {
-                        p->writeStdin("quit");
-                        p->closeWhenDone();
-                }
-                message+=required+"\n";
+QString required;
+  while (p->readln(required,true)!=-1)
+    {
+    message+=required+"\n";
+	if (required.find("GET_")!=-1) {
+        p->writeStdin("quit");
+        p->closeWhenDone();
         }
+    required=required.section("]",1,-1).stripWhiteSpace();
+    if (required.startsWith("UNEXPECTED") || required.startsWith("NODATA"))
+	signID=i18n("No signature found.");
+    if (required.startsWith("GOODSIG"))
+    {
+    signID=i18n("<qt>Good signature from:<br><b>%1</b><br>Key ID: %2</qt>").arg(required.section(" ",2,-1).replace(QRegExp("<"),"&lt;")).arg("0x"+required.section(" ",1,1).right(8));
+    }
+    if (required.startsWith("BADSIG")) 
+    {
+    signID=i18n("<qt><b>BAD signature</b> from:<br> %1<br>Key id: %2<br><br>"
+                             "<b>The file is corrupted!</b></qt>").arg(required.section(" ",2,-1).replace(QRegExp("<"),"&lt;")).arg("0x"+required.section(" ",1,1).right(8));
+    }
+    if (required.startsWith("NO_PUBKEY")) 
+    {
+    signmiss=true;
+    signID="0x"+required.section(" ",1,1).right(8);
+    }
+    if (required.startsWith("TRUST_UNDEFINED"))
+    	signID+=i18n("The signature is valid, but the key is untrusted");
+    if (required.startsWith("TRUST_ULTIMATE"))
+	signID+=i18n("The signature is valid, and the key is ultimately trusted");
+    }
 }
 
+
 void KgpgInterface::verifyfin(KProcess *)
 {
-        KStartupInfo::disableAutoAppStartedSending( false );
-        QString keyID,keyMail;
-        if ((message.find("VALIDSIG")!=-1) && (message.find("GOODSIG")!=-1) && (message.find("BADSIG")==-1)) {
-                message.remove(0,message.find("GOODSIG")+7);
-                message=message.section('\n',0,0);
-                message=message.stripWhiteSpace();
-                keyID=message.section(' ',0,0);
-                message.remove(0,keyID.length());
-                keyMail=message;
-                KMessageBox::information(0,i18n("<qt>Good signature from:<br><b>%1</b><br>Key ID: %2</qt>").arg(keyMail.replace(QRegExp("<"),"&lt;")).arg(keyID),file.filename());
-        } else if (message.find("UNEXPECTED")!=-1)
-                KMessageBox::sorry(0,i18n("No signature found."),file.filename());
-        else if (message.find("BADSIG")!=-1) {
-                message.remove(0,message.find("BADSIG")+6);
-                message=message.section('\n',0,0);
-                message=message.stripWhiteSpace();
-                keyID=message.section(' ',0,0);
-//                 message.remove(0,keyID.length());
-                keyMail=message;
-                KMessageBox::sorry(0,i18n("<qt><b>BAD signature</b> from:<br> %1<br>Key id: %2<br><br>"
-                                          "<b>The file is corrupted!</b></qt>").arg(keyMail.replace(QRegExp("<"),"&lt;")).arg(keyID),file.filename());
-        } else if (message.find("NO_PUBKEY")!=-1) {
-                message.remove(0,message.find("NO_PUBKEY")+9);
-                message=message.section('\n',0,0);
-                keyID=message.stripWhiteSpace();
-                if (KMessageBox::questionYesNo(0,i18n("<qt><b>Missing signature:</b><br>Key id: %1<br><br>"
-                                                      "Do you want to import this key from a keyserver?</qt>").arg(keyID),file.filename())==KMessageBox::Yes)
-                        emit verifyquerykey(keyID);
-                emit verifyfinished();
-                return;
-        } else
-                KMessageBox::sorry(0,message);
-        emit verifyfinished();
+    if (!signmiss) {
+        if (signID.isEmpty()) signID=i18n("No signature found.");    
+        (void) new KDetailedInfo(0,"verify_result",signID,message);
+    }
+    else {
+    	if (KMessageBox::questionYesNo(0,i18n("<qt><b>Missing signature:</b><br>Key id: %1<br><br>"
+                                                      "Do you want to import this key from a keyserver?</qt>").arg(signID),file.filename())==KMessageBox::Yes)
+    	emit verifyquerykey(signID);
+    }
+    emit verifyfinished();
 }
 
 
@@ -696,13 +834,11 @@ void KgpgInterface::KgpgSignKey(QString keyID,QString signKeyID,QString signKeyM
 	else *conprocess<<"sign";
         QObject::connect(conprocess,SIGNAL(readReady(KProcIO *)),this,SLOT(sigprocess(KProcIO *)));
         QObject::connect(conprocess, SIGNAL(processExited(KProcess *)),this, SLOT(signover(KProcess *)));
-        KStartupInfo::disableAutoAppStartedSending( true );
         conprocess->start(KProcess::NotifyOnExit,true);
 }
 
 void KgpgInterface::sigprocess(KProcIO *p)
 {
-        KStartupInfo::disableAutoAppStartedSending( false );
         QString required=QString::null;
 
         while (p->readln(required,true)!=-1)
@@ -744,7 +880,7 @@ void KgpgInterface::sigprocess(KProcIO *p)
 		
                 if (required.find("passphrase.enter")!=-1) {
                         QCString signpass;
-                        int code=KPasswordDialog::getPassword(signpass,i18n("<qt>%1 Enter passphrase for <b>%2</b>:</qt>").arg(errMessage).arg(checkForUtf8(userIDs)));
+                        int code=KPasswordDialog::getPassword(signpass,i18n("<qt>%1 Enter passphrase for <b>%2</b>:</qt>").arg(errMessage).arg(checkForUtf8bis(userIDs)));
                         if (code!=QDialog::Accepted) {
                                 signSuccess=4;  /////  aborted by user mode
                                 required=QString::null;
@@ -779,7 +915,6 @@ void KgpgInterface::sigprocess(KProcIO *p)
 
 void KgpgInterface::signover(KProcess *)
 {
-        KStartupInfo::disableAutoAppStartedSending( false );
         if (signSuccess>1)
                 emit signatureFinished(signSuccess);  ////   signature successful or bad passphrase
         else {
@@ -797,7 +932,7 @@ void KgpgInterface::openSignConsole()
         KProcess conprocess;
 	KConfig *config = KGlobal::config();
 	config->setGroup("General");
-	conprocess<< config->readEntry("TerminalApplication","konsole");
+	conprocess<< config->readPathEntry("TerminalApplication","konsole");
         conprocess<<"-e"<<"gpg";
         conprocess<<"--no-secmem-warning"<<"--expert"<<"-u"<<konsSignKey;
         if (!konsLocal)
@@ -949,7 +1084,7 @@ void KgpgInterface::expprocess(KProcIO *p)
 
                 if (required.find("passphrase.enter")!=-1) {
                         QCString signpass;
-                        int code=KPasswordDialog::getPassword(signpass,i18n("<qt>Enter passphrase for <b>%1</b>:</qt>").arg(checkForUtf8(userIDs)));
+                        int code=KPasswordDialog::getPassword(signpass,i18n("<qt>Enter passphrase for <b>%1</b>:</qt>").arg(checkForUtf8bis(userIDs)));
                         if (code!=QDialog::Accepted) {
                                 expSuccess=3;  /////  aborted by user mode
                                 p->writeStdin("quit");
@@ -958,14 +1093,16 @@ void KgpgInterface::expprocess(KProcIO *p)
                         }
                         p->writeStdin(signpass,true);
                         required=QString::null;
-                        //               step=2;
+                        //              step=2;
                 }
                 if ((step==2) && (required.find("keyedit.prompt")!=-1)) {
                         p->writeStdin("save");
+			p->closeWhenDone();
                         required=QString::null;
                 }
 		if ((step==2) && (required.find("keyedit.save.okay")!=-1)) {
                         p->writeStdin("YES");
+			p->closeWhenDone();
                         required=QString::null;
                 }
                 if (required.find("BAD_PASSPHRASE")!=-1) {
@@ -1119,7 +1256,7 @@ void KgpgInterface::passprocess(KProcIO *p)
 
                         if (step==1) {
                                 QCString passphrase;
-                                int code=KPasswordDialog::getPassword(passphrase,i18n("<qt>%1 Enter passphrase for <b>%2</b></qt>").arg(message).arg(checkForUtf8(userIDs)));
+                                int code=KPasswordDialog::getPassword(passphrase,i18n("<qt>%1 Enter passphrase for <b>%2</b></qt>").arg(message).arg(checkForUtf8bis(userIDs)));
                                 if (code!=QDialog::Accepted) {
                                         p->writeStdin("quit");
                                         //				 p->closeWhenDone();
@@ -1191,7 +1328,7 @@ void KgpgInterface::slotReadKey(KProcIO *p)
 {
         QString outp;
         while (p->readln(outp)!=-1)
-		if (!outp.startsWith("gpg:")) keyString+=outp+"\n";
+                if (!outp.startsWith("gpg:")) keyString+=outp+"\n";
 }
 
 
@@ -1201,7 +1338,7 @@ void KgpgInterface::importKeyURL(KURL url)
 {
         /////////////      import a key
 
-        if( KIO::NetAccess::download( url, tempKeyFile ) ) {
+        if( KIO::NetAccess::download( url, tempKeyFile,0) ) {
                 message=QString::null;
                 KProcIO *conprocess=new KProcIO();
                 *conprocess<< "gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--status-fd=2"<<"--import";
@@ -1209,7 +1346,6 @@ void KgpgInterface::importKeyURL(KURL url)
                 *conprocess<<tempKeyFile;
                 QObject::connect(conprocess, SIGNAL(processExited(KProcess *)),this, SLOT(importURLover(KProcess *)));
                 QObject::connect(conprocess, SIGNAL(readReady(KProcIO *)),this, SLOT(importprocess(KProcIO *)));
-                KStartupInfo::disableAutoAppStartedSending( true );
                 conprocess->start(KProcess::NotifyOnExit,true);
         }
 }
@@ -1223,7 +1359,6 @@ void KgpgInterface::importKey(QString keystr)
         *conprocess<<"--allow-secret-key-import";
         QObject::connect(conprocess, SIGNAL(processExited(KProcess *)),this, SLOT(importover(KProcess *)));
         QObject::connect(conprocess, SIGNAL(readReady(KProcIO *)),this, SLOT(importprocess(KProcIO *)));
-        KStartupInfo::disableAutoAppStartedSending( true );
         conprocess->start(KProcess::NotifyOnExit,true);
         conprocess->writeStdin(keystr, true);
         conprocess->closeWhenDone();
@@ -1231,10 +1366,11 @@ void KgpgInterface::importKey(QString keystr)
 
 void KgpgInterface::importover(KProcess *)
 {
-        KStartupInfo::disableAutoAppStartedSending( false );
 QStringList importedKeysIds;
+QStringList messageList;
 QString resultMessage;
-kdDebug()<<"Importing is over"<<endl;
+bool secretImport=false;
+kdDebug(2100)<<"Importing is over"<<endl;
         QString parsedOutput=message;
         QStringList importedKeys;
 
@@ -1243,10 +1379,11 @@ kdDebug()<<"Importing is over"<<endl;
 		importedKeys<<parsedOutput.section("\n",0,0).stripWhiteSpace();
 		importedKeysIds<<parsedOutput.stripWhiteSpace().section(' ',0,0);
         }
+	
 
         if (message.find("IMPORT_RES")!=-1) {
                 parsedOutput=message.section("IMPORT_RES",-1,-1).stripWhiteSpace();
-		QStringList messageList=QStringList::split(" ",parsedOutput,true);
+		messageList=QStringList::split(" ",parsedOutput,true);
                 	
                 resultMessage=i18n("<qt>%1 key(s) processed.<br></qt>").arg(messageList[0]);
                 if (messageList[4]!="0")
@@ -1264,7 +1401,10 @@ kdDebug()<<"Importing is over"<<endl;
                 if (messageList[8]!="0")
                         resultMessage+=i18n("<qt>%1 revocation certificate(s) imported.<br></qt>").arg(messageList[8]);
                 if (messageList[9]!="0")
+			{
                         resultMessage+=i18n("<qt>%1 secret key(s) processed.<br></qt>").arg(messageList[9]);
+			secretImport=true;
+			}
                 if (messageList[10]!="0")
                         resultMessage+=i18n("<qt><b>%1 secret key(s) imported.</b><br></qt>").arg(messageList[10]);
                 if (messageList[11]!="0")
@@ -1273,18 +1413,23 @@ kdDebug()<<"Importing is over"<<endl;
                         resultMessage+=i18n("<qt>%1 secret key(s) not imported.<br></qt>").arg(messageList[12]);
                 if (messageList[2]!="0")
                         resultMessage+=i18n("<qt><b>%1 key(s) imported:</b><br></qt>").arg(messageList[2]);
+			
+		if (secretImport) resultMessage+=i18n("<qt><br><b>You have imported a secret key.</b> <br>"
+									"Please note that imported secret keys are not trusted by default.<br>"
+									"To fully use this secret key for signing and encryption, you must edit the key (double click on it) and set its trust to Full or Ultimate.</qt>");
         } else
                 resultMessage=i18n("No key imported... \nCheck detailed log for more infos");
-        KDetailedInfo *m_box=new KDetailedInfo(0,"import_result",resultMessage,message,importedKeys);
-        m_box->setMinimumWidth(300);
-        m_box->exec();
-        //KMessageBox::information(0,message);
+		
+	if (messageList[8]!="0") importedKeysIds="ALL";
+	if ((messageList[9]!="0") && (importedKeysIds.isEmpty())) // orphaned secret key imported
+	emit refreshOrphaned();
         emit importfinished(importedKeysIds);
+	
+	(void) new KDetailedInfo(0,"import_result",resultMessage,message,importedKeys);
 }
 
 void KgpgInterface::importURLover(KProcess *p)
 {
-        KStartupInfo::disableAutoAppStartedSending( false );
         KIO::NetAccess::removeTempFile(tempKeyFile);
         importover(p);
         //KMessageBox::information(0,message);
@@ -1351,7 +1496,7 @@ void KgpgInterface::adduidprocess(KProcIO *p)
 
                 if (required.find("passphrase.enter")!=-1) {
                         QCString delpass;
-                        int code=KPasswordDialog::getPassword(delpass,i18n("<qt>Enter passphrase for <b>%1</b>:</qt>").arg(checkForUtf8(userIDs)));
+                        int code=KPasswordDialog::getPassword(delpass,i18n("<qt>Enter passphrase for <b>%1</b>:</qt>").arg(checkForUtf8bis(userIDs)));
                         if (code!=QDialog::Accepted) {
                                 //deleteSuccess=false;
                                 p->writeStdin("quit");
@@ -1370,7 +1515,7 @@ void KgpgInterface::adduidprocess(KProcIO *p)
 
 		if ((required.find("GET_")!=-1)) /////// gpg asks for something unusal, turn to konsole mode
                 {
-                        kdDebug()<<"unknown request"<<endl;
+                        kdDebug(2100)<<"unknown request"<<endl;
                         addSuccess=false;  /////  switching to console mode
                         p->writeStdin("quit");
                         p->closeWhenDone();
@@ -1474,7 +1619,7 @@ void KgpgInterface::delphotoprocess(KProcIO *p)
 
                 if (required.find("passphrase.enter")!=-1) {
                         QCString delpass;
-                        int code=KPasswordDialog::getPassword(delpass,i18n("<qt>Enter passphrase for <b>%1</b>:</qt>").arg(checkForUtf8(userIDs)));
+                        int code=KPasswordDialog::getPassword(delpass,i18n("<qt>Enter passphrase for <b>%1</b>:</qt>").arg(checkForUtf8bis(userIDs)));
                         if (code!=QDialog::Accepted) {
                                 //deleteSuccess=false;
                                 p->writeStdin("quit");
@@ -1493,7 +1638,7 @@ void KgpgInterface::delphotoprocess(KProcIO *p)
 
 		if ((required.find("GET_")!=-1)) /////// gpg asks for something unusal, turn to konsole mode
                 {
-                        kdDebug()<<"unknown request"<<endl;
+                        kdDebug(2100)<<"unknown request"<<endl;
                         delSuccess=false;
                         p->writeStdin("quit");
                         p->closeWhenDone();
@@ -1536,13 +1681,20 @@ void KgpgInterface::addphotoprocess(KProcIO *p)
                 }
 		
 		if (required.find("photoid.jpeg.size")!=-1)  {
-		        p->writeStdin("Yes");
-		        required=QString::null;
+			if (KMessageBox::questionYesNo(0,i18n("This image is very large. Use it anyway?"))==KMessageBox::Yes)
+                        p->writeStdin("Yes");
+			else 
+			{
+			p->writeStdin("No");
+			p->writeStdin("");
+			p->writeStdin("quit");
+			}
+                        required=QString::null;
                 }
 
                 if (required.find("passphrase.enter")!=-1) {
                         QCString delpass;
-                        int code=KPasswordDialog::getPassword(delpass,i18n("<qt>Enter passphrase for <b>%1</b>:</qt>").arg(checkForUtf8(userIDs)));
+                        int code=KPasswordDialog::getPassword(delpass,i18n("<qt>Enter passphrase for <b>%1</b>:</qt>").arg(checkForUtf8bis(userIDs)));
                         if (code!=QDialog::Accepted) {
                                 //deleteSuccess=false;
                                 p->writeStdin("quit");
@@ -1561,7 +1713,7 @@ void KgpgInterface::addphotoprocess(KProcIO *p)
 
 		if ((required.find("GET_")!=-1)) /////// gpg asks for something unusal, turn to konsole mode
                 {
-                        kdDebug()<<"unknown request"<<endl;
+                        kdDebug(2100)<<"unknown request"<<endl;
                         p->writeStdin("quit");
 			addSuccess=false;
                         p->closeWhenDone();
@@ -1628,7 +1780,7 @@ void KgpgInterface::revokeprocess(KProcIO *p)
 
                 if (required.find("passphrase.enter")!=-1) {
                         QCString signpass;
-                        int code=KPasswordDialog::getPassword(signpass,i18n("<qt>Enter passphrase for <b>%1</b>:</qt>").arg(checkForUtf8(userIDs)));
+                        int code=KPasswordDialog::getPassword(signpass,i18n("<qt>Enter passphrase for <b>%1</b>:</qt>").arg(checkForUtf8bis(userIDs)));
                         if (code!=QDialog::Accepted) {
                                 expSuccess=3;  /////  aborted by user mode
                                 p->writeStdin("quit");
@@ -1640,14 +1792,14 @@ void KgpgInterface::revokeprocess(KProcIO *p)
 
                 }
                 if (required.find("ask_revocation_reason.text")!=-1) {
-                        //		kdDebug()<<"description"<<endl;
+                        //		kdDebug(2100)<<"description"<<endl;
                         p->writeStdin(revokeDescription);
                         revokeDescription=QString::null;
                         required=QString::null;
                 }
                 if ((required.find("GET_")!=-1)) /////// gpg asks for something unusal, turn to konsole mode
                 {
-                        kdDebug()<<"unknown request"<<endl;
+                        kdDebug(2100)<<"unknown request"<<endl;
                         expSuccess=1;  /////  switching to console mode
                         p->writeStdin("quit");
                         p->closeWhenDone();
@@ -1714,7 +1866,7 @@ void KgpgInterface::setGpgGroupSetting(QString name,QStringList values, QString
         QString textToWrite;
         bool found=false;
         QFile qfile(QFile::encodeName(configFile));
-        kdDebug()<<"Changing group: "<<name<<endl;
+        kdDebug(2100)<<"Changing group: "<<name<<endl;
         if (qfile.open(IO_ReadOnly) && (qfile.exists())) {
                 QString result;
                 QTextStream t( &qfile );
@@ -1725,8 +1877,8 @@ void KgpgInterface::setGpgGroupSetting(QString name,QStringList values, QString
                                 result2.remove(0,6);
                                 result2=result2.stripWhiteSpace();
                                 if (result2.startsWith(name) && (result2.remove(0,name.length()).stripWhiteSpace().startsWith("="))) {
-//                                        kdDebug()<<"Found group: "<<name<<endl;
-                                        //kdDebug()<<"New values: "<<values<<endl;
+//                                        kdDebug(2100)<<"Found group: "<<name<<endl;
+                                        //kdDebug(2100)<<"New values: "<<values<<endl;
                                         result=QString("group %1=%2").arg(name).arg(values.join(" "));
                                         found=true;
                                 }
@@ -1759,10 +1911,10 @@ QStringList KgpgInterface::getGpgGroupSetting(QString name,QString configFile)
                 while (result!=NULL) {
                         result=result.stripWhiteSpace();
                         if (result.startsWith("group ")) {
-                                kdDebug()<<"Found 1 group"<<endl;
+                                kdDebug(2100)<<"Found 1 group"<<endl;
                                 result.remove(0,6);
                                 if (result.stripWhiteSpace().startsWith(name)) {
-                                        kdDebug()<<"Found group: "<<name<<endl;
+                                        kdDebug(2100)<<"Found group: "<<name<<endl;
                                         result=result.section('=',1);
                                         result=result.section('#',0,0);
                                         return QStringList::split (" ",result);
@@ -1884,15 +2036,28 @@ void KgpgInterface::setGpgBoolSetting(QString name,bool enable,QString url)
         }
 }
 
+QString KgpgInterface::checkForUtf8bis(QString txt)
+{
+    if (strchr (txt.ascii(), 0xc3) || (txt.find("\\x")!=-1))
+	txt=checkForUtf8(txt);
+    else {
+	txt=checkForUtf8(txt);
+	txt=QString::fromUtf8(txt.ascii());
+    }
+    return txt;
+}
+
+
 QString KgpgInterface::checkForUtf8(QString txt)
 {
+
         //    code borrowed from gpa
         const char *s;
 
         /* Make sure the encoding is UTF-8.
          * Test structure suggested by Werner Koch */
         if (txt.isEmpty())
-                return "";
+                return QString::null;
 
         for (s = txt.ascii(); *s && !(*s & 0x80); s++)
                 ;
@@ -1909,8 +2074,8 @@ QString KgpgInterface::checkForUtf8(QString txt)
                 str[0] = (char) QString( txt.mid( idx + 2, 2 ) ).toShort( 0, 16 );
                 txt.replace( idx, 4, str );
         }
-        if (!strchr (txt.ascii(), 0xc3))
-                return QString::fromUtf8(txt.ascii());  // perform Utf8 twice, or some keys display badly
+	if (!strchr (txt.ascii(), 0xc3))
+                return QString::fromUtf8(txt.ascii());
         else
                 return QString::fromUtf8(QString::fromUtf8(txt.ascii()).ascii());  // perform Utf8 twice, or some keys display badly
 }
