@@ -19,28 +19,15 @@
 #define KGPGINTERFACE_H
 
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-#include <unistd.h>
-#include <qstring.h>
-#include <qfile.h>
-#include <qdatetime.h>
 #include <qobject.h>
-
-#include <kled.h>
-#include <kprocess.h>
-#include <kprocio.h>
+#include <kdialogbase.h>
 #include <kurl.h>
-#include <kconfig.h>
-#include <kio/netaccess.h>
-#include <kdebug.h>
-#include <ktempfile.h>
-#include <kio/renamedlg.h>
-
-#include "detailedconsole.h"
+#include <qdatetime.h>
 
 class QLabel;
+class KProcIO;
+class KProcess;
+class KLed;
 
 /**
  * Encrypt a file using gpg.
@@ -79,21 +66,26 @@ public slots:
          * @param destUrl Kurl for the decrypted file.
          * @param chances int number of trials left for decryption (used only as an info displayed in the password dialog)
          */
-        void KgpgDecryptFile(KURL srcUrl=0,KURL destUrl=0,QStringList Options="");
+        void KgpgDecryptFile(KURL srcUrl,KURL destUrl,QStringList Options=QStringList());
 
         /**Sign file function
          * @param keyID QString the signing key ID.
          * @param srcUrl Kurl of the file to sign.
          * @param Options String with the wanted gpg options. ex: "--armor"
          */
-        void KgpgSignFile(QString keyID="",KURL srcUrl=0,QStringList Options=QString::null);
+        void KgpgSignFile(QString keyID,KURL srcUrl,QStringList Options=QStringList());
 
         /**Verify file function
          * @param sigUrl Kurl of the signature file.
          * @param srcUrl Kurl of the file to be verified. If empty, gpg will try to find it using the signature file name (by removing the .sig extensio)
          */
-        void KgpgVerifyFile(KURL sigUrl,KURL srcUrl=NULL) ;
+        void KgpgVerifyFile(KURL sigUrl,KURL srcUrl=KURL()) ;
 
+	void KgpgVerifyText(QString text);
+	void slotverifyread(KProcIO *p);
+	void slotverifyresult(KProcess*);
+	
+	
         /**Import key function
          * @param url Kurl the url of the key file. Allows public & secret key import.
          */
@@ -109,13 +101,13 @@ public slots:
          * @param signKeyMail QString the name of the signing key (only used to prompt user for passphrase)
          * @param local bool should the signature be local
          */
-        void KgpgSignKey(QString keyID="",QString signKeyID="",QString signKeyMail="",bool local=false,int checking=0);
+        void KgpgSignKey(QString keyID,QString signKeyID,QString signKeyMail=QString::null,bool local=false,int checking=0);
 
         /**Key signature deletion function
          * @param keyID QString the ID of the key
          * @param signKeyID QString the ID of the signature key
          */
-        void KgpgDelSignature(QString keyID="",QString signKeyID="");
+        void KgpgDelSignature(QString keyID,QString signKeyID);
 
         /**Encrypt text function
          * @param text QString text to be encrypted.
@@ -156,6 +148,7 @@ public slots:
 	void KgpgAddUid(QString keyID,QString name,QString email,QString comment);
 	
         void KgpgDecryptFileToText(KURL srcUrl,QStringList Options);
+	void KgpgSignText(QString text,QString userIDs, QStringList Options);
 
         static QString getGpgSetting(QString name,QString configFile);
         static void setGpgSetting(QString name,QString ID,QString url);
@@ -166,6 +159,7 @@ public slots:
 	static void setGpgGroupSetting(QString name,QStringList values, QString configFile);
 	static void delGpgGroup(QString name, QString configFile);
 	static QString checkForUtf8(QString txt);
+	static QString checkForUtf8bis(QString txt);
 	static int getGpgVersion();
 
 
@@ -264,6 +258,9 @@ private slots:
 	void photoreadprocess(KProcIO *p);
 	bool isPhotoId(int uid);
 	void updateIDs(QString txtString);
+	
+	void txtsignprocess(KProcIO *p);
+	void txtsignfin(KProcess *);
 
         //void txtreaddecprocess(KProcIO *p);
         //void txtdecryptfin(KProcess *);
@@ -271,6 +268,9 @@ private slots:
 
 signals:
 
+	void missingSignature(QString);
+	void verifyOver(QString,QString);
+
 	/**
                *  emitted when a txt decryption failed. returns log output
                */
@@ -312,7 +312,7 @@ signals:
         /**
                 *  emitted when the process starts
                 */
-        void processstarted();
+        void processstarted(QString);
         /**
                 *  true if decryption successful, false on error.
                 */
@@ -342,6 +342,7 @@ signals:
 	
 	void addPhotoFinished();
 	void addPhotoError(QString);
+	void refreshOrphaned();
 	
 	void addUidFinished();
 	void addUidError(QString);
@@ -352,6 +353,8 @@ signals:
         void expirationFinished(int);
 	void signalPhotoList(QStringList);
 	void passwordChanged();
+	
+	void txtSignOver(QString);
 
 
 
@@ -359,9 +362,11 @@ private:
         /**
         * @internal structure for communication
         */
-        QString message,tempKeyFile,userIDs,txtprocess,output,keyString;
+        QString message,tempKeyFile,userIDs,output,keyString;
         QCString passphrase;
-        bool deleteSuccess,konsLocal,anonymous,txtsent,decfinished,decok,badmdc,revokeSuccess,addSuccess,delSuccess;
+        bool deleteSuccess,konsLocal,anonymous,decfinished,decok,badmdc,revokeSuccess,addSuccess,delSuccess;
+	bool signmiss;
+	QString signID;
         int signSuccess,expSuccess,trustValue,konsChecked;
         int step,signb,sigsearch,expirationDelay;
         QString konsSignKey, konsKeyID,errMessage;
@@ -370,6 +375,7 @@ private:
 	QStringList photoList;
 	QString uidName, uidEmail, uidComment;
         KURL sourceFile;
+	QString decryptUrl;
 
         /**
          * @internal structure for the file information
@@ -382,7 +388,7 @@ class  Md5Widget :public KDialogBase
 {
         Q_OBJECT
 public:
-        Md5Widget(QWidget *parent=0, const char *name=0,KURL url=0);
+        Md5Widget(QWidget *parent=0, const char *name=0,KURL url=KURL());
         ~Md5Widget();
 public slots:
         void slotApply();
@@ -392,4 +398,5 @@ private:
         QLabel *TextLabel1_2;
 };
 
-#endif
+#endif // KGPGINTERFACE_HKGPGINTERFACE_H
+
