@@ -23,23 +23,29 @@
 #include <kconfig.h>
 #include <kmessagebox.h>
 #include <krun.h>
-
+#include <qfile.h>
+#include <kpassivepopup.h>
+#include <kiconloader.h>
 #include "kgpglibrary.h"
+#include "popuppublic.h"
+#include "kgpginterface.h"
+#include <kio/renamedlg.h>
 
-KgpgLibrary::KgpgLibrary(bool pgpExtension)
+KgpgLibrary::KgpgLibrary(QWidget *parent, bool pgpExtension)
 {
         if (pgpExtension)
                 extension=".pgp";
         else
                 extension=".gpg";
 	popIsActive=false;
+	panel=parent;
 }
 
 KgpgLibrary::~KgpgLibrary()
 {}
 
 
-void KgpgLibrary::slotFileEnc(KURL::List urls,QStringList opts,QString defaultKey)
+void KgpgLibrary::slotFileEnc(KURL::List urls,QStringList opts,QString defaultKey,KShortcut goDefaultKey)
 {
         /////////////////////////////////////////////////////////////////////////  encode file file
         if (!urls.empty()) {
@@ -47,7 +53,7 @@ void KgpgLibrary::slotFileEnc(KURL::List urls,QStringList opts,QString defaultKe
                 if (defaultKey.isEmpty()) {
 			QString fileNames=urls.first().filename();
 			if (urls.count()>1) fileNames+=",...";
-                        popupPublic *dialogue=new popupPublic(0,"Public keys",fileNames,true);
+                        popupPublic *dialogue=new popupPublic(0,"Public keys",fileNames,true,goDefaultKey);
                         connect(dialogue,SIGNAL(selectedKey(QStringList,QStringList,bool,bool)),this,SLOT(startencode(QStringList,QStringList,bool,bool)));
                         dialogue->exec();
                         delete dialogue;
@@ -59,14 +65,17 @@ void KgpgLibrary::slotFileEnc(KURL::List urls,QStringList opts,QString defaultKe
 void KgpgLibrary::startencode(QStringList encryptKeys,QStringList encryptOptions,bool shred,bool symetric)
 {
 	popIsActive=false;
-        KURL::List::iterator it;
-	filesToEncode=urlselecteds.count();
-        for ( it = urlselecteds.begin(); it != urlselecteds.end(); ++it )
-                fastencode(*it,encryptKeys,encryptOptions,shred,symetric);
+        //KURL::List::iterator it;
+	//filesToEncode=urlselecteds.count();
+	_encryptKeys=encryptKeys;
+	_encryptOptions=encryptOptions;
+	_shred=shred;
+	_symetric=symetric;
+		fastencode(urlselecteds.first(),encryptKeys,encryptOptions,symetric);
 }
 
 
-void KgpgLibrary::fastencode(KURL &fileToCrypt,QStringList selec,QStringList encryptOptions,bool shred,bool symetric)
+void KgpgLibrary::fastencode(KURL &fileToCrypt,QStringList selec,QStringList encryptOptions,bool symetric)
 {
         //////////////////              encode from file
         if ((selec.isEmpty()) && (!symetric)) {
@@ -87,93 +96,83 @@ void KgpgLibrary::fastencode(KURL &fileToCrypt,QStringList selec,QStringList enc
 		    	if (over->exec()==QDialog::Rejected)
 	    		{
                 	delete over;
+			emit systemMessage(QString::null,true);
                 	return;
             		}
 	    		dest=over->newDestURL();
 	    		delete over;
         }
-
+	int filesToEncode=urlselecteds.count();
+	if (filesToEncode>1)
+	emit systemMessage(i18n("<b>%1 Files left.</b>\nEncrypting </b>%2").arg(filesToEncode).arg(urlselecteds.first().path()));
+	else emit systemMessage(i18n("<b>Encrypting </b>%2").arg(urlselecteds.first().path()));
         KgpgInterface *cryptFileProcess=new KgpgInterface();
-	
-	pop = new KPassivePopup();
+	pop = new KPassivePopup(panel);
         cryptFileProcess->KgpgEncryptFile(selec,urlselected,dest,encryptOptions,symetric);
-        if (!popIsActive) 
+         if (!popIsActive) 
 	{
-	connect(cryptFileProcess,SIGNAL(processstarted()),this,SLOT(processpopup2()));
+	//connect(cryptFileProcess,SIGNAL(processstarted(QString)),this,SLOT(processpopup2(QString)));
 	popIsActive=true;	
 	}
-        if (shred)
-                connect(cryptFileProcess,SIGNAL(encryptionfinished(KURL)),this,SLOT(shredpreprocessenc(KURL)));
-        else
-                connect(cryptFileProcess,SIGNAL(encryptionfinished(KURL)),this,SLOT(processenc(KURL)));
+	connect(cryptFileProcess,SIGNAL(encryptionfinished(KURL)),this,SLOT(processenc(KURL)));
         connect(cryptFileProcess,SIGNAL(errormessage(QString)),this,SLOT(processencerror(QString)));
 }
 
-void KgpgLibrary::processpopup2()
+void KgpgLibrary::processpopup2(QString fileName)
 {
-	pop->setTimeout(0);
-        pop->setView(i18n("Processing encryption"),i18n("Please wait..."),KGlobal::iconLoader()->loadIcon("kgpg",KIcon::Desktop));
+        
+	//pop->setTimeout(0);
+        pop->setView(i18n("Processing encryption (%1)").arg(fileName),i18n("Please wait..."),KGlobal::iconLoader()->loadIcon("kgpg",KIcon::Desktop));
         pop->show();
-        QRect qRect(QApplication::desktop()->screenGeometry());
+        /*QRect qRect(QApplication::desktop()->screenGeometry());
         int iXpos=qRect.width()/2-pop->width()/2;
         int iYpos=qRect.height()/2-pop->height()/2;
-        pop->move(iXpos,iYpos);
+        pop->move(iXpos,iYpos);*/
+
 }
 
 void KgpgLibrary::shredpreprocessenc(KURL fileToShred)
 {
-	filesToEncode--;
-	if (filesToEncode==0) delete pop;
 	popIsActive=false;
+	emit systemMessage(QString::null);
 	shredprocessenc(fileToShred);
 }
 
-void KgpgLibrary::shredprocessenc(KURL fileToShred)
+void KgpgLibrary::shredprocessenc(KURL::List filesToShred)
 {
-	if (!fileToShred.isLocalFile())
-{
-KMessageBox::sorry(0,i18n("<qt>File <b>%1</b> is a remote file.<br>You cannot shred it.</qt>").arg(fileToShred.path()));
-return;
-}
-	KPassivePopup *shredPopup=new KPassivePopup();
- 	shredPopup->setAutoDelete(false);
-	QVBox *vbox=shredPopup->standardView(i18n("Shredding"),i18n("<qt>Shredding file <b>%1</b></qt>").arg(fileToShred.filename()),KGlobal::iconLoader()->loadIcon("kgpg",KIcon::Desktop));
-	   
-	   shredProgressBar= new KProgress(vbox);
-    shredPopup->setView( vbox );
-    shredPopup->show();
-    kapp->processEvents();
-        shredProgressBar->setTotalSteps(QFile(fileToShred.path()).size());
-
-KShred *shredres=new KShred(fileToShred.path());
-        connect(shredres,SIGNAL(processedSize(KIO::filesize_t)),this,SLOT(setShredProgress(KIO::filesize_t)));
-        if (shredres->shred())
-                delete shredPopup;
-        else
-                KMessageBox::sorry(0,i18n("<qt><b>ERROR</b> during file shredding.<br>File <b>%1</b> was not securely deleted. Please check your permissions.</qt>").arg(fileToShred.path()));
+emit systemMessage(i18n("Shredding %1 file(s)").arg(filesToShred.count()));
 
+KIO::Job *job;
+job = KIO::del( filesToShred, true );
+connect( job, SIGNAL( result( KIO::Job * ) ),SLOT( slotShredResult( KIO::Job * ) ) );	
 }
 
-
-void KgpgLibrary::setShredProgress(KIO::filesize_t shredSize)
+void KgpgLibrary::slotShredResult( KIO::Job * job )
 {
-shredProgressBar->setProgress((int) shredSize);
-
+    emit systemMessage(QString::null);
+    if (job && job->error())
+    {
+    job->showErrorDialog( (QWidget*)parent() );
+    emit systemMessage(QString::null,true);
+    KPassivePopup::message(i18n("KGpg Error"),i18n("Process halted, not all files were shredded."),KGlobal::iconLoader()->loadIcon("kgpg",KIcon::Desktop),panel,"kgpg_error",0);
+    }
 }
 
 
 void KgpgLibrary::processenc(KURL)
 {
-	filesToEncode--;
-	if (filesToEncode==0) delete pop;
-	popIsActive=false;
+	emit systemMessage(QString::null);
+	if (_shred) shredprocessenc(urlselecteds.first());
+	urlselecteds.pop_front ();
+	if (urlselecteds.count()>0)
+	fastencode(urlselecteds.first(),_encryptKeys,_encryptOptions,_symetric);
 }
 
 void KgpgLibrary::processencerror(QString mssge)
 {
-	filesToEncode--;
-	if (filesToEncode==0) delete pop;
-	popIsActive=false;        KMessageBox::detailedSorry(0,i18n("Encryption failed."),mssge);
+	popIsActive=false;
+	emit systemMessage(QString::null,true);
+	KMessageBox::detailedSorry(panel,i18n("<b>Process halted</b>.<br>Not all files were encrypted."),mssge);
 }
 
 
@@ -185,14 +184,15 @@ void KgpgLibrary::slotFileDec(KURL srcUrl,KURL destUrl,QStringList customDecrypt
         pop = new KPassivePopup();
 	urlselected=srcUrl;
         decryptFileProcess->KgpgDecryptFile(srcUrl,destUrl,customDecryptOption);
-        connect(decryptFileProcess,SIGNAL(processaborted(bool)),this,SIGNAL(decryptionOver()));
-        connect(decryptFileProcess,SIGNAL(processstarted()),this,SLOT(processpopup()));
+        connect(decryptFileProcess,SIGNAL(processaborted(bool)),this,SLOT(processdecover()));
+        connect(decryptFileProcess,SIGNAL(processstarted(QString)),this,SLOT(processpopup(QString)));
         connect(decryptFileProcess,SIGNAL(decryptionfinished()),this,SLOT(processdecover()));
         connect(decryptFileProcess,SIGNAL(errormessage(QString)),this,SLOT(processdecerror(QString)));
 }
 
-void KgpgLibrary::processpopup()
+void KgpgLibrary::processpopup(QString fileName)
 {
+	emit systemMessage(i18n("Decrypting %1").arg(fileName));
 	pop->setTimeout(0);
         pop->setView(i18n("Processing decryption"),i18n("Please wait..."),KGlobal::iconLoader()->loadIcon("kgpg",KIcon::Desktop));
         pop->show();
@@ -204,6 +204,7 @@ void KgpgLibrary::processpopup()
 
 void KgpgLibrary::processdecover()
 {
+	emit systemMessage(QString::null);
 	delete pop;
         emit decryptionOver();
 }
@@ -211,8 +212,9 @@ void KgpgLibrary::processdecover()
 
 void KgpgLibrary::processdecerror(QString mssge)
 {
-        ///// test if file is a public key
 	delete pop;
+	emit systemMessage(QString::null);
+        ///// test if file is a public key
         QFile qfile(QFile::encodeName(urlselected.path()));
         if (qfile.open(IO_ReadOnly)) {
                 QTextStream t( &qfile );
@@ -227,7 +229,6 @@ void KgpgLibrary::processdecerror(QString mssge)
                                 KgpgInterface *importKeyProcess=new KgpgInterface();
                                 importKeyProcess->importKeyURL(urlselected);
 				connect(importKeyProcess,SIGNAL(importfinished(QStringList)),this,SIGNAL(importOver(QStringList)));
-				
                                 return;
                         }
                 } else if (result.startsWith("-----BEGIN PGP PRIVATE KEY BLOCK")) {//////  dropped file is a public key, ask for import
