@@ -30,11 +30,26 @@
 #include <kstdaction.h>
 #include <kurldrag.h>
 
+#include <kmessagebox.h>
+#include <qfile.h>
+#include <qlayout.h>
+#include <kbuttonbox.h>
+#include <unistd.h>
+#include <kaction.h>
+#include <klineedit.h>
+#include <qtextcodec.h>
+
+
 #include "kgpgsettings.h"
 #include "kgpginterface.h"
 #include "kgpgview.h"
+#include "keyservers.h"
+#include "keyserver.h"
 #include "kgpg.h"
-
+#include "kgpgeditor.h"
+#include "listkeys.h"
+#include "popuppublic.h"
+#include "detailedconsole.h"
 
 //////////////// configuration for editor
 
@@ -81,13 +96,13 @@ void MyEditor::slotDroppedFile(KURL url)
         else {
                 if (KMessageBox::warningContinueCancel(0,i18n("<qt><b>Remote file dropped</b>.<br>The remote file will now be copied to a temporary file to process requested operation. This temporary file will be deleted after operation.</qt>"),0,KStdGuiItem::cont(),"RemoteFileWarning")!=KMessageBox::Continue)
                         return;
-                if (!KIO::NetAccess::download (url, tempFile)) {
+                if (!KIO::NetAccess::download (url, tempFile,this)) {
                         KMessageBox::sorry(this,i18n("Could not download file."));
                         return;
                 }
         }
 
-        
+
                 /////////////  if dropped filename ends with gpg, pgp or asc, try to decode it
                 if ((tempFile.endsWith(".gpg")) || (tempFile.endsWith(".asc")) || (tempFile.endsWith(".pgp"))) {
                         slotDecodeFile(tempFile);
@@ -101,7 +116,7 @@ bool MyEditor::slotCheckContent(QString fileToCheck, bool checkForPgpMessage)
 QFile qfile(fileToCheck);
         if (qfile.open(IO_ReadOnly)) {
                 //////////   open file
-                
+
                         QTextStream t( &qfile );
                         QString result(t.read());
                         //////////////     if  pgp data found, decode it
@@ -125,7 +140,7 @@ QFile qfile(fileToCheck);
                                 } else {
                                         if (result.startsWith("-----BEGIN PGP PRIVATE KEY BLOCK")) {
 						qfile.close();
-                                                KMessageBox::information(0,i18n("This file is a private key!\nPlease use kgpg key management to import it."));
+                                                KMessageBox::information(0,i18n("This file is a private key.\nPlease use kgpg key management to import it."));
                                                 KIO::NetAccess::removeTempFile(fileToCheck);
                                                 return true;
                                         }
@@ -155,7 +170,7 @@ void MyEditor::slotDecodeFile(QString fname)
 {
         ////////////////     decode file from given url into editor
         QFile qfile(QFile::encodeName(fname));
-        if (qfile.open(IO_ReadOnly)) {			
+        if (qfile.open(IO_ReadOnly)) {
 	KgpgInterface *txtDecrypt=new KgpgInterface();
         connect (txtDecrypt,SIGNAL(txtdecryptionfinished(QString)),this,SLOT(editorUpdateDecryptedtxt(QString)));
 	connect (txtDecrypt,SIGNAL(txtdecryptionfailed(QString)),this,SLOT(editorFailedDecryptedtxt(QString)));
@@ -178,6 +193,7 @@ void MyEditor::slotProcessResult(QStringList iKeys)
 KgpgView::KgpgView(QWidget *parent, const char *name) : QWidget(parent, name)
 {
         editor=new MyEditor(this);
+	windowAutoClose=true;
 
         /////    layout
 
@@ -220,146 +236,89 @@ void KgpgView::modified()
 
 }
 
+void KgpgView::slotAskForImport(QString ID)
+{
+if (KMessageBox::questionYesNo(0,i18n("<qt><b>Missing signature:</b><br>Key id: %1<br><br>"
+	"Do you want to import this key from a keyserver?</qt>").arg(ID),i18n("Missing Key"))==KMessageBox::Yes) {
+        keyServer *kser=new keyServer(0,"server_dialog",false,true);
+        kser->page->kLEimportid->setText(ID);
+        kser->slotImport();
+	windowAutoClose=false;
+        }
+	else emit verifyFinished();
+}
+
+void KgpgView::slotVerifyResult(QString mssge,QString log)
+{
+emit verifyFinished();
+//KMessageBox::information(0,mssge);
+(void) new KDetailedInfo(0,"verify_result",mssge,log);
+}
+
 void KgpgView::clearSign()
 {
         QString mess=editor->text();
         if (mess.startsWith("-----BEGIN PGP SIGNED")) {
                 //////////////////////   this is a signed message, verify it
-
-                ///////////////////  generate gpg command
-
-                ///////////////// run command
-                FILE *fp,*cmdstatus;
-                int process[2];
-
-                pipe(process);
-                cmdstatus = fdopen(process[1], "w");
-                QString line="echo "+KShellProcess::quote(mess.utf8());
-                line+=" | gpg --no-tty  --no-secmem-warning --status-fd="+QString::number(process[1])+" --verify";
-                fp=popen(QFile::encodeName(line),"r");
-                pclose(fp);
-                fclose(cmdstatus);
-
-                int Len;
-                char Buff[500]="\0";
-                QString verifyResult,lineRead;
-
-                //////////////////////////   read gpg output
-                while (read(process[0], &Len, sizeof(Len)) > 0) {
-                        read(process[0],Buff, Len);
-                        lineRead=Buff;
-                        if (lineRead.find("GOODSIG",0,FALSE)!=-1)
-                                lineRead.remove(0,lineRead.find("GOODSIG",0,FALSE)+7);
-                        if (lineRead.find("BADSIG",0,FALSE)!=-1)
-                                lineRead.remove(0,lineRead.find("BADSIG",0,FALSE)+6);
-                        if (lineRead.find("NO_PUBKEY",0,FALSE)!=-1)
-                                lineRead.remove(0,lineRead.find("NO_PUBKEY",0,FALSE)+9);
-                        verifyResult+=Buff;
-                }
-                if ((verifyResult.find("GOODSIG",0,FALSE)!=-1) && (verifyResult.find("BADSIG",0,FALSE)==-1)) {
-                        lineRead=lineRead.left(lineRead.find("\n",0,FALSE));
-                        lineRead=lineRead.stripWhiteSpace();
-                        QString resultKey=lineRead.section(" ",1,-1);
-                        QString resultID=lineRead.section(" ",0,0);
-                        KMessageBox::information(this,i18n("<qt>Good signature from:<br><b>%1</b><br>Key ID: %2</qt>").arg(resultKey.replace(QRegExp("<"),"&lt;")).arg(resultID));
-                } else
-                        if ((verifyResult.find("NO_PUBKEY",0,FALSE)!=-1) && (verifyResult.find("BADSIG",0,FALSE)==-1)) {
-                                lineRead=lineRead.left(lineRead.find("\n",0,FALSE));
-                                lineRead=lineRead.stripWhiteSpace();
-
-                                if (KMessageBox::questionYesNo(0,i18n("<qt><b>Missing signature:</b><br>Key id: %1<br><br>"
-                                                                      "Do you want to import this key from a keyserver?</qt>").arg(lineRead),i18n("Missing Key"))==KMessageBox::Yes) {
-                                        keyServer *kser=new keyServer(0,"server_dialog",false);
-                                        kser->page->kLEimportid->setText(lineRead);
-                                        kser->slotImport();
-                                }
-                                return;
-                        } else {
-                                lineRead=lineRead.left(lineRead.find("\n",0,FALSE));
-                                lineRead=lineRead.stripWhiteSpace();
-                                QString resultKey=lineRead.section(" ",1,-1);
-                                QString resultID=lineRead.section(" ",0,0);
-                                KMessageBox::sorry(this,i18n("<qt><b>BAD signature</b> from:<br>%1<br>Key ID: %2<br><br><b>Text is corrupted!</b></qt>").arg(resultKey.replace(QRegExp("<"),"&lt;")).arg(resultID));
-                        }
-        } else {
+		KgpgInterface *verifyProcess=new KgpgInterface();
+		connect(verifyProcess,SIGNAL(missingSignature(QString)),this,SLOT(slotAskForImport(QString)));
+		connect(verifyProcess,SIGNAL(verifyOver(QString,QString)),this,SLOT(slotVerifyResult(QString,QString)));
+		verifyProcess->KgpgVerifyText(mess);                                                
+        	} 
+		else {
                 /////    Sign the text in Editor
-
-
-                QString signKeyID,signKeyMail;
-                FILE *fp,*pass;
-                int ppass[2];
-                char buffer[200];
-                QCString password;
-
-                ///// open key selection dialog
+		QString signKeyID;
+		///// open key selection dialog
                 KgpgSelKey *opts=new KgpgSelKey(this,0);
 
                 if (opts->exec()==QDialog::Accepted) {
                         signKeyID=opts->getkeyID();
-                        signKeyMail=opts->getkeyMail();
                 } else {
                         delete opts;
                         return;
                 }
                 delete opts;
-                /////////////////////  get passphrase
 		
-                bool useAgent=KgpgInterface::getGpgBoolSetting("use-agent",KGpgSettings::gpgConfigPath());
-		
-                if (!getenv("GPG_AGENT_INFO") || !useAgent) {
-                        int code=KPasswordDialog::getPassword(password,i18n("Enter passphrase for <b>%1</b>:").arg(signKeyMail.replace(QRegExp("<"),"&lt;")));
-                        ///////////////////   ask for password
-                        if (code!=QDialog::Accepted)
-                                return;
-
-                        ///////////////////   pipe passphrase
-                        pipe(ppass);
-                        pass = fdopen(ppass[1], "w");
-                        fwrite(password, sizeof(char), strlen(password), pass);
-                        //        fwrite("\n", sizeof(char), 1, pass);
-                        fclose(pass);
-                }
-                ///////////////////  generate gpg command
-                QString line="echo ";
-                //mess=mess.replace(QRegExp("\\\\") , "\\\\").replace(QRegExp("\\\"") , "\\\"").replace(QRegExp("\\$") , "\\$");
-                line+=KShellProcess::quote(mess.utf8());
-                line+=" | gpg ";
-                if (KGpgSettings::pgpCompatibility())
-                        line+="--pgp6 ";
-                if (!getenv("GPG_AGENT_INFO") || !useAgent) {
-                        line+="--passphrase-fd ";
-                        QString fd;
-                        fd.setNum(ppass[0]);
-                        line+=fd;
-                }
-                line+=" --no-tty --clearsign -u ";
-                line+=KShellProcess::quote(signKeyID);
-                //KMessageBox::sorry(0,QString(line));
-                QString tst=QString::null;
-
-                ///////////////// run command
-                fp = popen(QFile::encodeName(line), "r");
-                while ( fgets( buffer, sizeof(buffer), fp))
-                        tst+=buffer;
-                pclose(fp);
-
-                /////////////////  paste result into editor
-                if (!tst.isEmpty()) {
-                        editor->setText(QString::fromUtf8(tst.ascii()));
-                        KgpgApp *win=(KgpgApp *) parent();
-                        win->editRedo->setEnabled(false);
-                        win->editUndo->setEnabled(false);
-                } else
-                        KMessageBox::sorry(this,i18n("Signing not possible: bad passphrase or missing key"));
-        }
+		KgpgInterface *signProcess=new KgpgInterface();
+		connect(signProcess,SIGNAL(txtSignOver(QString)),this,SLOT(slotSignResult(QString)));
+		QStringList options=NULL;
+		if (KGpgSettings::pgpCompatibility())
+                        options<<"--pgp6";
+		signProcess->KgpgSignText(mess,signKeyID,options);
 }
+}
+
+
+void KgpgView::slotSignResult(QString signResult)
+{
+if (signResult.isEmpty())
+KMessageBox::sorry(this,i18n("Signing not possible: bad passphrase or missing key"));
+else
+{
+	if (checkForUtf8(signResult))
+	{
+	editor->setText(QString::fromUtf8(signResult.ascii()));
+	emit resetEncoding(true);
+	}
+	else
+	{
+	editor->setText(signResult);
+	emit resetEncoding(false);
+	}
+	KgpgApp *win=(KgpgApp *) parent();
+	win->editRedo->setEnabled(false);
+	win->editUndo->setEnabled(false);
+}
+}
+
+
 
 void KgpgView::popuppublic()
 {
         /////    popup dialog to select public key for encryption
 
         ////////  open dialog --> popuppublic.cpp
-        popupPublic *dialogue=new popupPublic(this, "public_keys", 0,false);
+        popupPublic *dialogue=new popupPublic(this, "public_keys", 0,false,((KgpgApp *) parent())->goDefaultKey);
         connect(dialogue,SIGNAL(selectedKey(QStringList,QStringList,bool,bool)),this,SLOT(encodetxt(QStringList,QStringList,bool,bool)));
         dialogue->exec();
         delete dialogue;
@@ -380,7 +339,7 @@ void KgpgView::slotdecode()
         connect (txtDecrypt,SIGNAL(txtdecryptionfinished(QString)),this,SLOT(updateDecryptedtxt(QString)));
 	connect (txtDecrypt,SIGNAL(txtdecryptionfailed(QString)),this,SLOT(failedDecryptedtxt(QString)));
         txtDecrypt->KgpgDecryptText(editor->text(),QStringList::split(QString(" "),KGpgSettings::customDecrypt().simplifyWhiteSpace()));
-	
+
 	/*
         KgpgApp *win=(KgpgApp *) parent();
         if (!resultat.isEmpty()) {
@@ -392,36 +351,23 @@ void KgpgView::slotdecode()
 
 void KgpgView::updateDecryptedtxt(QString newtxt)
 {
-	//kdDebug()<<"UTF8 Test Result--------------"<<KgpgView::checkForUtf8()<<endl;
-	if (checkForUtf8(newtxt)) 
+	//kdDebug(2100)<<"UTF8 Test Result--------------"<<KgpgView::checkForUtf8()<<endl;
+	if (checkForUtf8(newtxt))
 	{
 	editor->setText(QString::fromUtf8(newtxt.ascii()));
 	emit resetEncoding(true);
 	}
-	else 
+	else
 	{
 	editor->setText(newtxt);
 	emit resetEncoding(false);
 	}
 }
 
-bool KgpgView::checkForUtf8(QString text)    
+bool KgpgView::checkForUtf8(QString text)
 {  //// try to guess if the decrypted text uses utf-8 encoding
-const unsigned char *s=(unsigned char *) text.ascii();
-int n=text.length();
-unsigned char c;
-for (int ct=0;ct<n;ct++)
-{
-c=s[ct];
-  //kdDebug()<<"Testing --------- "<<c<<"caractere"<<n<<endl;
-if ((c>0xc2) && (c<0xdf)) 
-if (ct+1<n) 
-{
-c=s[ct+1];
-if ((c>0x80) && (c<0xbf)) 
-return true;
-}
-}
+QTextCodec *codec =QTextCodec::codecForLocale ();
+		if (!codec->canEncode(text)) return true;
 return false;
 }
 
@@ -436,9 +382,9 @@ void KgpgView::encodetxt(QStringList selec,QStringList encryptOptions,bool, bool
         //////////////////              encode from editor
         if (KGpgSettings::pgpCompatibility())
                 encryptOptions<<"--pgp6";
-        
+
 	if (symmetric) selec.clear();
-		
+
 	KgpgInterface *txtCrypt=new KgpgInterface();
         connect (txtCrypt,SIGNAL(txtencryptionfinished(QString)),this,SLOT(updatetxt(QString)));
         txtCrypt->KgpgEncryptText(editor->text(),selec,encryptOptions);
@@ -459,7 +405,9 @@ void KgpgView::updatetxt(QString newtxt)
 
 
 KgpgView::~KgpgView()
-{}
+{
+delete editor;
+}
 
 /*
 void KgpgView::print(QPrinter *pPrinter)
