@@ -29,6 +29,47 @@
 #include "fileinfodialog.h"
 #include "listview.h"
 
+// quick'n'dirty hack to have the occurrence column sorted correctly
+class CStatisticListViewItem : public QListViewItem
+{
+  public:
+    CStatisticListViewItem( QListView * parent, QListViewItem * after,
+			    QString label1, QString label2, QString label3, QString label4,
+			    QString label5, QString label6, QString label7, int i, int o)
+  : QListViewItem( parent, after, label1, label2, label3, label4, label5, label6, label7),
+    item( i ),
+    occurrence( o )
+    {}
+
+    virtual int compare( QListViewItem *i, int col, bool ascending/*Qt doc says: ignore this one*/ ) const
+    {
+      // occurrence column (or the percent one)?
+      if( col == 5 || col == 6 )
+      {
+	const int otherOccurrence = ((CStatisticListViewItem*)i)->occurrence;
+	return occurrence < otherOccurrence ? -1 : occurrence == otherOccurrence ? 0 : 1;
+      }
+      // char column?
+      else if( col == 4 )
+      {
+	const int otherItem = ((CStatisticListViewItem*)i)->item;
+	return item < otherItem ? -1 : item == otherItem ? 0 : 1;
+      }
+      // default
+      else
+	return QListViewItem::compare(i,col,ascending);
+    }
+
+  protected:
+    // no of byte
+    int item;
+    // number of the byte's occurrences
+    int occurrence;
+};
+
+
+
+
 CFileInfoDialog::CFileInfoDialog( QWidget *parent,const char *name,bool modal)
   :KDialogBase( Plain, i18n("Statistics"), Help|User1|Cancel, User1,
 		parent, name, modal, true, i18n("&Update") ),
@@ -171,20 +212,12 @@ void CFileInfoDialog::setStatistics( void ) // Default
     o.sprintf("%03o", i );
     b.sprintf("%s", printBin(i) );
 
-    if( QChar((char)i).isPrint() == true )
-    {
-      c = QChar((char)i);
-    }
-    else
-    {
-      c = QChar('.');
-    }
+    const QChar _i((char)i);
+    c = _i.isPrint() ? _i : QChar('.'); 
 
-    item = new QListViewItem( mFrequencyList, item, h, d, o, b, c, u, u );
+    item = new CStatisticListViewItem( mFrequencyList, item, h, d, o, b, c, u, u, i, -1 );
     if( i == 0 )
-    {
       mFrequencyList->setSelected( item, true );
-    }
   }
 }
 
@@ -201,15 +234,12 @@ void CFileInfoDialog::setStatistics( SStatisticControl &sc )
   QListViewItem *item = 0;
 
   uint size, pre, i;
-
+  // find width of occurrences
   for( i=size=0; i<256; i++ )
-  {
-    if( sc.occurrence[i] > size ) { size = sc.occurrence[i]; }
-  }
+    if( sc.occurrence[i] > size ) 
+      size = sc.occurrence[i];
   for( pre = 1; size > 0 ; pre++ )
-  {
     size /= 10;
-  }
 
   for( i=0; i<256; i++ )
   {
@@ -220,29 +250,19 @@ void CFileInfoDialog::setStatistics( SStatisticControl &sc )
 
     n = QString("%1").arg( sc.occurrence[i], pre );
     if( sc.documentSize == 0 )
-    {
-      p.sprintf("0.00" );
-    }
+      p = "0.00";
     else
     {
       double val = 100.0*((double)sc.occurrence[i]/(double)sc.documentSize);
       p = QString("%1").arg( val, 6, 'f', 2 );
     }
 
-    if( QChar((char)i).isPrint() == true )
-    {
-      c = QChar((char)i);
-    }
-    else
-    {
-      c = QChar('.');
-    }
+    const QChar _i((char)i);
+    c = _i.isPrint() ? _i : QChar('.'); 
 
-    item = new QListViewItem( mFrequencyList, item, h, d, o, b, c, n, p );
+    item = new CStatisticListViewItem( mFrequencyList, item, h, d, o, b, c, n, p, i, sc.occurrence[i] );
     if( i == 0 )
-    {
       mFrequencyList->setSelected( item, true );
-    }
   }
 }
 
