@@ -30,6 +30,8 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <ktempfile.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
 
 #include "chartabledialog.h"
 #include "converterdialog.h"
@@ -762,7 +764,13 @@ bool CHexEditorWidget::selectDocument( const QString &url,
 
 void CHexEditorWidget::insertFile( void )
 {
-  KURL file = KFileDialog::getOpenURL( mWorkDir, "*", topLevelWidget());
+  KFileDialog fdlg(mWorkDir, QString::null, topLevelWidget(), 0, TRUE);
+  fdlg.setOperationMode( KFileDialog::Opening );
+  fdlg.okButton()->setGuiItem( KStdGuiItem::insert() );
+  fdlg.setCaption(i18n("Insert File"));
+
+  if (!fdlg.exec()) return;
+  KURL file = fdlg.selectedURL();
 
   if( file.isEmpty() )
     return;
@@ -1965,27 +1973,16 @@ int CHexEditorWidget::readURL( const QString &url, bool insert )
   }
 
   //
-  // 2) Verify that the url is valid URL string. If not, try to repair it.
+  // 2) Verify that the url is valid URL string.
   // This will work if the url contains a name of a file in the
   // current directory.
   //
   KURL kurl( url );
   if( !kurl.isValid() )
   {
-    QString tmp( "file:" );
-    if( url.find( '/' ) != 0 ) // The '/' is not the first character
-    {
-      tmp += QDir::currentDirPath() + '/';
-    }
-    tmp += url;
-    kurl = tmp;
-
-    if( !kurl.isValid() )
-    {
-      QString msg = i18n("Malformed URL\n%1").arg( kurl.url() );
-      KMessageBox::sorry( topLevelWidget(), msg, i18n("Read URL") );
-      return( Err_IllegalArgument );
-    }
+    QString msg = i18n("Malformed URL\n%1").arg( kurl.url() );
+    KMessageBox::sorry( topLevelWidget(), msg, i18n("Read URL") );
+    return( Err_IllegalArgument );
   }
 
   //
@@ -1993,16 +1990,11 @@ int CHexEditorWidget::readURL( const QString &url, bool insert )
   // or a "remote" file. The local file can be opened as a regular file.
   //
   QString tmpfile;
-  if ( !kurl.isLocalFile() ) {
-      if ( !KIO::NetAccess::download( kurl, tmpfile, this ) )
-          return Err_ReadFailed;
-      kurl = tmpfile;
-  }
+  if ( !KIO::NetAccess::download( kurl, tmpfile, this ) )
+    return Err_ReadFailed;
 
-  bool success = readFile( kurl.path(), kurl.url(), insert );
-
-  if ( !tmpfile.isNull() )
-      KIO::NetAccess::removeTempFile( tmpfile );
+  bool success = readFile( tmpfile, kurl.url(), insert );
+  KIO::NetAccess::removeTempFile( tmpfile );
 
   return( success == true ? Err_Success : Err_ReadFailed );
 }
@@ -2011,18 +2003,21 @@ int CHexEditorWidget::readURL( const QString &url, bool insert )
 void CHexEditorWidget::writeURL( QString &url )
 {
   KURL kurl( url );
-  QString tempfile;
-  KTempFile tf;
-  if( !kurl.isLocalFile() ) {
-      tempfile = tf.name();
-      tf.setAutoDelete( true );
-      writeFile( tempfile );
+  if( kurl.isLocalFile() )
+    writeFile( kurl.path() );
+  else
+  {
+    bool modified = mHexView->modified();
+    KTempFile tf;
+    tf.setAutoDelete( true );
+    writeFile( tf.name() );
+    if( !KIO::NetAccess::upload(tf.name(),url,this) )
+    {
+      mHexView->setModified( modified );
+      QString msg = i18n("You do not have write permission."); // not precise, it simply failed for whatever reason
+      KMessageBox::sorry( topLevelWidget(), msg, i18n("Write Failure") );
+    }
   }
-  else 
-      writeFile( KURL( url ).path() );
-
-  if ( !tempfile.isNull() )
-      KIO::NetAccess::upload( tempfile, url, 0 );
 }
 
 bool CHexEditorWidget::modifiedByAlien( const QString &url )
