@@ -14,7 +14,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
 
@@ -132,6 +132,7 @@ class CHexEditorWidget : public QWidget
     void toggleOffsetAsDecimal( void );
     void toggleDataUppercase( void );
     void toggleOffsetUppercase( void );
+    void toggleInsertMode( void );
     void benchmark( void );
     void copy( void );
     void copyText( void );
@@ -189,9 +190,6 @@ class CHexEditorWidget : public QWidget
     void collectStrings( void );
     void collectStatistics( SStatisticControl &sc );
 
-    void kioReadFinished( KIO::Job * job );
-    void kioWriteFinished( KIO::Job * job );
-
   protected:
     void resizeEvent( QResizeEvent *e );
 
@@ -201,9 +199,8 @@ class CHexEditorWidget : public QWidget
     int  readURL( const QString &url, bool insert );
     void writeURL( QString &url );
     bool readFile( const QString &diskPath, const QString &url, bool insert );
-    bool writeFile( QString &diskPath );
+    bool writeFile( const QString &diskPath );
     void saveWorkingDirectory( const QString &url );
-    QString createTemporaryFileName( void );
 
     bool confirmPrintPageNumber( CHexPrinter &printer );
 
@@ -224,10 +221,6 @@ class CHexEditorWidget : public QWidget
     bool busy( bool showWarning );
 
   private:
-    QPtrDict <QString> mKioRemote;
-    QPtrDict <QString> mKioLocal;
-    QPtrDict <bool> mKioFlag; 
-
     QString  mWorkDir; // Remembers last directroy used by file dialogs 
  
     uint mUntitledCount;
