@@ -139,14 +139,7 @@ void CDragManager::timerEvent( QTimerEvent *e )
     if( mPending == true )
     {
       mPending = false;
-
-      Window root, w;
-      uint mask;
-      int i;
-
-      root = RootWindow( x11Display(), x11Screen() );
-      XQueryPointer( x11Display(), root, &w, &w, &i, &i, &i, &i, &mask );
-      emit startDrag( mask & ShiftMask ? true : false );
+      emit startDrag( ( kapp->keyboardModifiers() & KApplication::ShiftModifier ) );
     }
   }
 }
@@ -1295,10 +1288,10 @@ void CHexViewWidget::benchmark( void )
   uint area  = width() * height();
   uint last = (t2.tv_sec-t1.tv_sec) * 1000000 + (t2.tv_usec - t1.tv_usec);
 
-  kdDebug() << "Duration: " << (float)last/ 1000000.0 << endl;
-  kdDebug() << "Duration/loop: " << (float)last/ (1000000.0*(float)loop) << endl;
-  kdDebug() << "Area: " << area << endl;
-  kdDebug() << "Loop: " << loop << endl;
+  kdDebug(1501) << "Duration: " << (float)last/ 1000000.0 << endl;
+  kdDebug(1501) << "Duration/loop: " << (float)last/ (1000000.0*(float)loop) << endl;
+  kdDebug(1501) << "Area: " << area << endl;
+  kdDebug(1501) << "Loop: " << loop << endl;
 }
 
 
@@ -1523,14 +1516,12 @@ void CHexViewWidget::keyPressEvent( QKeyEvent *e )
 
 void CHexViewWidget::keyReleaseEvent( QKeyEvent *e )
 {
-  if( e->state() & ShiftButton && shiftButtonState() == false )
+  if( ( e->state() & ShiftButton ) && shiftButtonState() == false )
   {
     //
     // The shift button was pressed when event was triggered, but is
     // now released. I use this as a sign to copy selected data to the
-    // clipboard. The shiftButtonState() uses X-lib functions so have a
-    // look in the headerfile (inlined method) if you want to remove
-    // this dependency.
+    // clipboard.
     //
     autoCopy();
   }
