@@ -14,6 +14,7 @@
  *                                                                         *
  ***************************************************************************/
 
+ 
 //#include <kdebug.h>
 
 // c specific
@@ -119,7 +120,7 @@ KHexEdit::KHexEdit( KDataBuffer *Buffer, QWidget *Parent, const char *Name, WFla
   viewport()->installEventFilter( this );
   installEventFilter( this );
 
-  connect( CursorBlinkTimer, SIGNAL(timeout()), this, SLOT(blinkCursor()));
+  connect( CursorBlinkTimer, SIGNAL(timeout()), this, SLOT(blinkCursor()) );
   connect( ScrollTimer,      SIGNAL(timeout()), this, SLOT(autoScrollTimerDone()) );
   connect( DragStartTimer,   SIGNAL(timeout()), this, SLOT(startDrag()) );
   
@@ -1336,7 +1337,7 @@ void KHexEdit::drawContents( QPainter *P, int cx, int cy, int cw, int ch )
 
 void KHexEdit::updateColumn( KColumn &Column )
 {
-  //kdDebug() << "updateColumn\n";
+  //kdDebug(1501) << "updateColumn\n";
   updateContents( Column.x(), 0, Column.width(), totalHeight() );
 }
 
@@ -1589,6 +1590,7 @@ bool KHexEdit::handleLetter( QKeyEvent *KeyEvent )
       D[0] = S.latin1()[0];
 //         clearUndoRedoInfo = false;
     insert( D );
+    ensureCursorVisible();    
   }
   else
   {
@@ -2284,28 +2286,36 @@ void KHexEdit::handleMouseMove( const QPoint& Point ) // handles the move of the
 
 void KHexEdit::startDrag()
 {
+  // reset states
   MousePressed = false;
   InDoubleClick = false;
   DragStartPossible = false;
 
+  // create data
   QDragObject *Drag = dragObject( true, viewport() );
   if( !Drag )
     return;
 
+  // will we only copy the data?
   if( isReadOnly() || OverWrite )
     Drag->dragCopy();
-  else if( Drag->drag() && QDragObject::target() != this && QDragObject::target() != viewport() )
-    removeSelectedData();
+  // or is this left to the user and he choose to move?
+  else if( Drag->drag() )
+    // Not inside this widget itself?
+    if( QDragObject::target() != this && QDragObject::target() != viewport() )
+      removeSelectedData();
 }
 
 
 void KHexEdit::contentsDragEnterEvent( QDragEnterEvent *e )
 {
+  // interesting for this widget?
   if( isReadOnly() || !KBufferDrag::canDecode(e) )
   {
     e->ignore();
     return;
   }
+  
   e->acceptAction();
   InDnD = true;
 }
@@ -2313,24 +2323,25 @@ void KHexEdit::contentsDragEnterEvent( QDragEnterEvent *e )
 
 void KHexEdit::contentsDragMoveEvent( QDragMoveEvent *e )
 {
-  // is this content for us?
+  // is this content still interesting for us? 
   if( isReadOnly() || !KBufferDrag::canDecode(e) )
   {
     e->ignore();
     return;
   }
+  
   // let text cursor follow mouse
   pauseCursor( true );
-
   placeCursor( e->pos() );
-
   unpauseCursor();
+  
   e->acceptAction();
 }
 
 
 void KHexEdit::contentsDragLeaveEvent( QDragLeaveEvent * )
 {
+  // bye... and thanks for all the cursor movement...
   InDnD = false;
 }
 
