@@ -30,10 +30,10 @@
 #include "version.h" // Contains khexedit name string and version string
 
 
-static const char *description =
-	I18N_NOOP("KDE Hex editor");
+static const char description[] =
+	I18N_NOOP("KDE hex editor");
 
-static const char *version = APP_VERSION_STRING;
+static const char version[] = APP_VERSION_STRING;
 
 static KCmdLineOptions option[] =
 {
@@ -95,11 +95,9 @@ int main( int argc, char **argv )
         uint _offset = parseDecimalOrHexadecimal(offsetStr.data() );
         hexEdit->setStartupOffset( _offset );
     }
-    
+
     for(int i = 0; i < args->count(); i++)
-    {
-       hexEdit->addStartupFile( QFile::decodeName(args->arg(i)) );
-    }
+       hexEdit->addStartupFile( args->url(i).url() );
 
     args->clear();
   }
