@@ -180,7 +180,6 @@ class KHexEdit : public KMainWindow
 
     void setEncoding( void );
     void documentMenuCB( int id );
-    void slotConfigureKeys();
 
 protected:
     virtual bool queryExit( void );
@@ -212,7 +211,6 @@ protected:
     void makeExitFileList( void );
     void writeConfiguration( KConfig &config );
     void readConfiguration( KConfig &config );
-    void setStartupGeometry( void );
     bool eventFilter( QObject *obj, QEvent *event );
 
     int acceleratorNumKey( uint index );
