@@ -2,7 +2,7 @@
 //  kjots
 //
 //  Copyright (C) 1997 Christoph Neerfeld
-//  Copyright (C) 2002, 2003 Aaron J. Seigo
+//  Copyright (C) 2002-2004 Aaron J. Seigo
 //  Copyright (C) 2003 Stanislav Kljuhhin
 //
 //  This program is free software; you can redistribute it and/or modify
@@ -25,23 +25,20 @@
 #include <kio/netaccess.h>
 
 #include <kaction.h>
-#include <kbookmarkmenu.h>
 #include <kapplication.h>
-#include <kedittoolbar.h>
-#include <kfiledialog.h>
+#include <kbookmarkmenu.h>
+#include <kconfigdialog.h>
 #include <kdebug.h>
-#include <kkeydialog.h>
+#include <keditcl.h>
+#include <kfiledialog.h>
+#include <kglobalsettings.h>
 #include <kinputdialog.h>
 #include <kmessagebox.h>
+#include <kpopupmenu.h>
 #include <krun.h>
 #include <kstandarddirs.h>
 #include <kstdaccel.h>
-#include <kglobalsettings.h>
 #include <ktextbrowser.h>
-#include <keditcl.h>
-#include <kconfigdialog.h>
-
-//#include <kglobal.h>
 
 #include "KJotsMain.h"
 #include "KJotsSettings.h"
@@ -109,22 +106,32 @@ KJotsMain::KJotsMain(const char* name)
     bookGrid->setMargin(0);
     splitter->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding, 2, 1));
 
-    // create menu
+    // create actions
     KAction *action = KStdAction::openNew(this, SLOT(newEntry()), actionCollection());
     action->setText(i18n("&New Page"));
-
     action = new KAction(i18n("New &Book..."), "contents", CTRL + SHIFT + Key_N, this,
             SLOT(createFolder()), actionCollection(), "new_book");
-    action = new KAction(i18n("Save Book to ASCII File..."), QString::null, 0, this,
-            SLOT(writeBook()), actionCollection(), "save_book_to_ascii");
-    action = new KAction(i18n("Save Page to ASCII File..."), QString::null, 0, this,
-            SLOT(writePage()), actionCollection(), "save_page_to_ascii");
 
-    action = new KAction(i18n("Delete Boo&k"), "editdelete", 0, this,
-            SLOT(deleteFolder()), actionCollection(), "del_folder");
+    KActionMenu* actionMenu = new KActionMenu(i18n("Export Page"), actionCollection(), "save_page_to");
+    action = new KAction(i18n("To Text File..."), QString::null, 0, this,
+            SLOT(writePage()), actionCollection(), "save_page_to_ascii");
+    action->plug(actionMenu->popupMenu());
+    action = new KAction(i18n("To HTML File..."), QString::null, 0, this,
+            SLOT(writePageToHTML()), actionCollection(), "save_page_to_html");
+    action->plug(actionMenu->popupMenu());
+
+    actionMenu = new KActionMenu(i18n("Export Book"), actionCollection(), "save_book_to");
+    action = new KAction(i18n("To Text File..."), QString::null, 0, this,
+            SLOT(writeBook()), actionCollection(), "save_book_to_ascii");
+    action->plug(actionMenu->popupMenu());
+    action = new KAction(i18n("To HTML File..."), QString::null, 0, this,
+            SLOT(writeBookToHTML()), actionCollection(), "save_book_to_html");
+    action->plug(actionMenu->popupMenu());
 
     action = new KAction(i18n("&Delete Page"), "editdelete", 0, this,
             SLOT(deleteEntry()), actionCollection(), "del_page");
+    action = new KAction(i18n("Delete Boo&k"), "editdelete", 0, this,
+            SLOT(deleteFolder()), actionCollection(), "del_folder");
 
     action = new KAction(i18n("Manual Save"), 0, KStdAccel::save(),
                          this, SLOT(autoSave()), actionCollection(), "manual_save");
@@ -153,9 +160,6 @@ KJotsMain::KJotsMain(const char* name)
     action = new KAction(i18n("Insert Date"), "date", CTRL + Key_I, this,
             SLOT(insertDate()), actionCollection(), "insert_date");
 
-    action = KStdAction::showToolbar(this, SLOT(slotShowHideToolbars()), actionCollection());
-    action = KStdAction::keyBindings(this, SLOT(configureKeys()), actionCollection());
-    action = KStdAction::configureToolbars(this, SLOT(configureToolbars()), actionCollection());
     action = KStdAction::preferences(this, SLOT(configure()), actionCollection());
 
     KActionMenu* bookmarkMenu = new KActionMenu(i18n("Bookmarks"), "bookmarks", actionCollection(), "bookmarks");
@@ -164,7 +168,7 @@ KJotsMain::KJotsMain(const char* name)
     new KBookmarkMenu(KBookmarkManager::managerForFile(locateLocal("appdata","bookmarks.xml")),
                       bookmarks, bookmarkMenu->popupMenu(),
                       actionCollection(), true);
-    createGUI();
+    setupGUI();
     /*
      * TODO: add a bookmark bar, something like this
     KToolBar* bar = dynamic_cast<KToolBar *>(child("bookmarkToolBar", "KToolBar"));
@@ -194,8 +198,6 @@ KJotsMain::KJotsMain(const char* name)
     updateConfiguration();
     updateMenu();
 
-    resize(KJotsSettings::width(), KJotsSettings::height());
-
     QTimer::singleShot(0, this, SLOT(slotSetupInterface()));
 
     //connect new slots
@@ -217,16 +219,8 @@ KJotsMain::KJotsMain(const char* name)
             this, SLOT(autoSave()));
 }
 
-
-KJotsMain::~KJotsMain()
-{
-
-}
-
 void KJotsMain::slotSetupInterface()
 {
-    static_cast<KToggleAction*>(actionCollection()->action("options_show_toolbar"))->setChecked(toolBar()->isVisible());
-
     if (subjectList->childCount() == 0)
         createFolder();
 }
@@ -301,7 +295,7 @@ bool KJotsMain::createFolder()
     if (!ok)
         return false;
 
-    if(subjectList->findItem(name,0))
+    if (subjectList->findItem(name,0))
     {
         KMessageBox::sorry(topLevelWidget(),i18n("A book with this name already exists."),"KJots");
         return false;
@@ -400,21 +394,6 @@ void KJotsMain::deleteEntry()
     updateMenu();
 }
 
-void KJotsMain::configureToolbars()
-{
-  saveMainWindowSettings(kapp->config(), "kjots");
-  KEditToolbar dlg(actionCollection());
-  connect( &dlg, SIGNAL(newToolbarConfig()), SLOT(updateToolbars()) );
-  dlg.exec();
-}
-
-void KJotsMain::updateToolbars()
-{
-  createGUI();
-  applyMainWindowSettings(kapp->config(), "kjots");
-  updateMenu();
-}
-
 void KJotsMain::configure()
 {
     if(KConfigDialog::showDialog("settings"))
@@ -448,18 +427,6 @@ void KJotsMain::slotReplace()
     me_text->replace();
 }
 
-void KJotsMain::slotShowHideToolbars()
-{
-    if (toolBar()->isVisible())
-    {
-        toolBar()->hide();
-    }
-    else
-    {
-        toolBar()->show();
-    }
-}
-
 void KJotsMain::updateConfiguration()
 {
     me_text->setFont(KJotsSettings::font());
@@ -467,8 +434,6 @@ void KJotsMain::updateConfiguration()
         m_autosaveTimer->changeInterval(KJotsSettings::autoSaveInterval()*1000*60);
     else
         m_autosaveTimer->stop();
-
-    toolBar(0)->applySettings(kapp->config(), "MainToolbar");
 }
 
 void KJotsMain::autoSave(void)
@@ -493,6 +458,16 @@ void KJotsMain::autoSave(void)
 }
 
 void KJotsMain::writeBook()
+{
+    saveBookToFile(true);
+}
+
+void KJotsMain::writeBookToHTML()
+{
+    saveBookToFile(false);
+}
+
+void KJotsMain::saveBookToFile(bool plainText)
 {
     KJotsBook* b = currentBook();
 
@@ -519,11 +494,21 @@ void KJotsMain::writeBook()
 
     if (!url.isEmpty())
     {
-        b->saveToFile(url);
+        b->saveToFile(url, plainText);
     }
 }
 
 void KJotsMain::writePage()
+{
+    savePageToFile(true);
+}
+
+void KJotsMain::writePageToHTML()
+{
+    savePageToFile(false);
+}
+
+void KJotsMain::savePageToFile(bool plainText)
 {
     KJotsSubject* e = currentSubject();
 
@@ -550,15 +535,10 @@ void KJotsMain::writePage()
 
     if (!url.isEmpty())
     {
-        e->saveToFile(url);
+        e->saveToFile(url, plainText);
     }
 }
 
-void KJotsMain::configureKeys()
-{
-  KKeyDialog::configure(actionCollection(), this);
-}
-
 void KJotsMain::copySelection()
 {
     //TODO: Strip HTML tags
@@ -626,7 +606,9 @@ void KJotsMain::updateMenu()
         actionCollection()->action("del_page")->setEnabled(false);
         actionCollection()->action(KStdAction::stdName(KStdAction::New))->setEnabled(false);
         actionCollection()->action("save_book_to_ascii")->setEnabled(false);
+        actionCollection()->action("save_book_to_html")->setEnabled(false);
         actionCollection()->action("save_page_to_ascii")->setEnabled(false);
+        actionCollection()->action("save_page_to_html")->setEnabled(false);
         actionCollection()->action("rename_entry")->setEnabled(false);
         actionCollection()->action("insert_date")->setEnabled(false);
         actionCollection()->action("bookmarks")->setEnabled(false);
@@ -638,7 +620,9 @@ void KJotsMain::updateMenu()
         actionCollection()->action("del_page")->setEnabled(false);
         actionCollection()->action(KStdAction::stdName(KStdAction::New))->setEnabled(true);
         actionCollection()->action("save_book_to_ascii")->setEnabled(true);
+        actionCollection()->action("save_book_to_html")->setEnabled(true);
         actionCollection()->action("save_page_to_ascii")->setEnabled(false);
+        actionCollection()->action("save_page_to_html")->setEnabled(false);
         actionCollection()->action("rename_entry")->setEnabled(true);
         actionCollection()->action("insert_date")->setEnabled(true);
         actionCollection()->action("bookmarks")->setEnabled(true);
@@ -650,7 +634,9 @@ void KJotsMain::updateMenu()
         actionCollection()->action("del_page")->setEnabled(true);
         actionCollection()->action(KStdAction::stdName(KStdAction::New))->setEnabled(true);
         actionCollection()->action("save_book_to_ascii")->setEnabled(true);
+        actionCollection()->action("save_book_to_html")->setEnabled(true);
         actionCollection()->action("save_page_to_ascii")->setEnabled(true);
+        actionCollection()->action("save_page_to_html")->setEnabled(true);
         actionCollection()->action("rename_entry")->setEnabled(true);
         actionCollection()->action("insert_date")->setEnabled(true);
         actionCollection()->action("bookmarks")->setEnabled(true);
@@ -756,10 +742,6 @@ bool KJotsMain::queryClose()
 
 void KJotsMain::saveProperties()
 {
-    toolBar(0)->saveSettings(kapp->config(), "MainToolbar");
-
-    KJotsSettings::setWidth(width());
-    KJotsSettings::setHeight(height());
     KJotsSettings::setSplitterSizes(splitter->sizes());
 
     KJotsBook* selBook = currentBook();
@@ -1026,7 +1008,7 @@ void KJotsMain::slotItemMoved(QListViewItem *item, QListViewItem * afterFirst, Q
         {
             // we don't accept books inside books right now
             // move the book outside
-            KMessageBox::sorry(this,i18n("You can't have a book inside another book."));
+            KMessageBox::sorry(this,i18n("You cannot have a book inside another book."));
             p_item_parent->takeItem(p_item);
             subjectList->insertItem(p_item);
 
@@ -1055,7 +1037,7 @@ void KJotsMain::slotItemMoved(QListViewItem *item, QListViewItem * afterFirst, Q
                                             "Would you like to create a new book to put the page in, "
                                             "or would you prefer to not move the page at all?"),
                                        QString::null,
-                                       i18n("Create New Book"), i18n("Don't Move The Page")) ==
+                                       i18n("Create New Book"), i18n("Do Not Move The Page")) ==
             KMessageBox::No ||
             !createFolder())
         {
