@@ -2,7 +2,7 @@
 //  kjots
 //
 //  Copyright (C) 1997 Christoph Neerfeld
-//  Copyright (C) 2002, 2003 Aaron J. Seigo
+//  Copyright (C) 2002-2004 Aaron J. Seigo
 //  Copyright (C) 2003 Stanislav Kljuhhin
 //
 //  This program is free software; you can redistribute it and/or modify
@@ -58,7 +58,6 @@ class KJotsMain : public KMainWindow
 
     public:
         KJotsMain( const char* name = 0 );
-        virtual ~KJotsMain();
 
         QString currentTitle();
         QString currentBookmarkURL();
@@ -71,9 +70,6 @@ class KJotsMain : public KMainWindow
         void deleteEntry();
         void slotRenameEntry();
         void configure();
-        void configureKeys();
-        void configureToolbars();
-        void updateToolbars();
         void updateConfiguration();
 
         void copySelection();
@@ -83,7 +79,6 @@ class KJotsMain : public KMainWindow
         void slotRepeatSearch();
         void slotReplace();
         void slotQuit();
-        void slotShowHideToolbars();
         void slotFindSuccessful();
 
         void slotExpandBook(QListViewItem* item);
@@ -92,7 +87,11 @@ class KJotsMain : public KMainWindow
         void slotItemRenamed(QListViewItem*,const QString&,int);
         void slotItemMoved(QListViewItem*,QListViewItem*,QListViewItem*);
         void writeBook();
+        void writeBookToHTML();
+        void saveBookToFile(bool plainText);
         void writePage();
+        void writePageToHTML();
+        void savePageToFile(bool plainText);
 
         // handling page changes in the listview
         void showListviewContextenu(KListView* l, QListViewItem* i, const QPoint& p);
