@@ -161,7 +161,7 @@ BatteryConfig::BatteryConfig (QWidget * parent, const char *name)
             (void)startTimer(30*1000);	// update 2x every minute
       }
 
-      QLabel* explain = new QLabel( i18n("This panel controls whether the battery status\nmonitor appears in the dock and what it looks like."), this);
+      QLabel* explain = new QLabel( i18n("This panel controls whether the battery status monitor\nappears in the system tray and what it looks like."), this);
       top_layout->addWidget(explain, 0);
       laptop_portable::extra_config(this, config, top_layout);
     }
