@@ -4,7 +4,7 @@
  *
  * This file contains the docked widget for the laptop battery monitor
  *
- * $Id: daemondock.cpp,v 1.56.2.1 2004/03/11 11:41:10 lukas Exp $
+ * $Id: daemondock.cpp,v 1.61.2.1 2004/10/04 11:31:04 waba Exp $
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -47,7 +47,7 @@ extern void wake_laptop_daemon();
 laptop_dock::laptop_dock( laptop_daemon* parent )
   : KSystemTray()
 {
-
+    KGlobal::locale()->insertCatalogue("klaptopdaemon"); // For translation of klaptopdaemon messages
     _pcmcia = NULL;
     pdaemon = parent;
     current_code = -1;
@@ -233,7 +233,7 @@ void laptop_dock::slotGoRoot(int /*id*/) {
 		int rc = KMessageBox::warningContinueCancel(0,
 				i18n("You will need to supply a root password "
 					"to allow KLaptopDaemon to restart "
-					"itself as the superuser.  It may take "
+					"itself as the superuser. It may take "
 					"up to a minute for the new daemon to "
 					"start up and the old one to close."),
 				i18n("KLaptopDaemon"), KStdGuiItem::cont(),
@@ -252,18 +252,18 @@ void laptop_dock::slotGoRoot(int /*id*/) {
 			// We should disable this menu item here now.
 		}
 	} else {
-		KMessageBox::sorry(0, i18n("PCMCIA cannot be enabled since kdesu cannot be found.  Please make sure that it is installed correctly."),
+		KMessageBox::sorry(0, i18n("PCMCIA cannot be enabled since kdesu cannot be found. Please make sure that it is installed correctly."),
 				i18n("KLaptopDaemon"));
 	}
 #else
-	KMessageBox::sorry(0, i18n("PCMCIA cannot be enabled just now - this area is a work in progress as we move to a KDED based daemon - do not translate this string it will go away real soon now"),
+	KMessageBox::sorry(0, i18n("PCMCIA cannot be enabled just now."),
 			i18n("KLaptopDaemon"));
 #endif
 }
 
 
 void laptop_dock::slotHide() {
-	int confirm = KMessageBox::questionYesNo(0, i18n("Are you sure you want to hide the battery monitor?  Your battery will still be monitored in the background."), QString::null, KStdGuiItem::yes(), KStdGuiItem::no(), "hideConfirm");
+	int confirm = KMessageBox::questionYesNo(0, i18n("Are you sure you want to hide the battery monitor? Your battery will still be monitored in the background."), QString::null, KStdGuiItem::yes(), KStdGuiItem::no(), "hideConfirm");
 
 	if (confirm != KMessageBox::Yes)
 		return;
@@ -365,17 +365,18 @@ void laptop_dock::mousePressEvent( QMouseEvent *event )
 		} else {
 			QString tmp;
 
-			if (pdaemon->left < 0) {	// buggy BIOS
-				if (pdaemon->val >= 0) {
-					tmp = i18n("%1% charged").arg(pdaemon->val);
+			if (pdaemon->val >= 0) {
+				if (pdaemon->left >= 0) {
+					QString num3;
+					num3.setNum(pdaemon->left%60);
+					num3 = num3.rightJustify(2, '0');
+					tmp = i18n("%1:%2 time left").arg(pdaemon->left/60).arg(num3);
 				} else {
-					tmp = i18n("No Battery");
+					// no remaining time available
+					tmp = i18n("%1% charged").arg(pdaemon->val);
 				}
 			} else {
-				QString num3;
-				num3.setNum(pdaemon->left%60);
-				num3 = num3.rightJustify(2, '0');
-				tmp = i18n("%1:%2 time left").arg(pdaemon->left/60).arg(num3);
+				tmp = i18n("No Battery");
 			}
 			popup->insertItem(tmp);
 			popup->setItemEnabled(0, 0);
@@ -496,11 +497,7 @@ void laptop_dock::invokeLockHibernation()
 {
   DCOPClient* client = kapp->dcopClient();
   if (client)
-    {
-      client->attach();
       client->send("kdesktop", "KScreensaverIface", "lock()", "");
-      client->detach();
-    }
   laptop_portable::invoke_hibernation();
 }
 void laptop_dock::invokeStandby()
@@ -517,11 +514,7 @@ void laptop_dock::invokeLockSuspend()
 {
   DCOPClient* client = kapp->dcopClient();
   if (client)
-    {
-      client->attach();
       client->send("kdesktop", "KScreensaverIface", "lock()", "");
-      client->detach();
-    }
   laptop_portable::invoke_suspend();
 }
 
@@ -639,29 +632,35 @@ quit:
 	if (pdaemon->powered) {
 		if (pdaemon->val == 100) {
 			tmp = i18n("Plugged in - fully charged");;
-		} else {
+		} else if (pdaemon->val >= 0) {
 			if (pdaemon->left >= 0) {
 				QString num3;
 				num3.setNum(pdaemon->left%60);
 				num3 = num3.rightJustify(2, '0');
 				tmp = i18n("Plugged in - %1% charged (%2:%3 time left)")
 					.arg(pdaemon->val).arg(pdaemon->left/60).arg(num3);
-			} else
-			if (pdaemon->val == -1) {
-				tmp = i18n("Plugged in - no battery");
 			} else {
+				// no remaining time available
 				tmp = i18n("Plugged in - %1% charged").arg(pdaemon->val);
 			}
+		} else {
+			tmp = i18n("Plugged in - no battery");
 		}
 	} else {
-		if (pdaemon->left >= 0) {
-			QString num3;
-			num3.setNum(pdaemon->left%60);
-			num3 = num3.rightJustify(2, '0');
-			tmp = i18n("Running on batteries - %1% charged (%2:%3 time left)")
-					.arg(pdaemon->val).arg(pdaemon->left/60).arg(num3);
+		if (pdaemon->val >= 0) {
+			if (pdaemon->left >= 0) {
+				QString num3;
+				num3.setNum(pdaemon->left%60);
+				num3 = num3.rightJustify(2, '0');
+				tmp = i18n("Running on batteries - %1% charged (%2:%3 time left)")
+						.arg(pdaemon->val).arg(pdaemon->left/60).arg(num3);
+			} else {
+				tmp = i18n("Running on batteries - %1% charged").arg(pdaemon->val);
+			}
 		} else {
-			tmp = i18n("Running on batteries  - %1% charged").arg(pdaemon->val);
+			// running without any power source...
+			// happens eg. due to ACPI not being able to handle battery hot-plugin
+			tmp = i18n("No power source found");
 		}
 	}
 	QToolTip::add(this, tmp);
