@@ -9,7 +9,7 @@
  *
  * This file contains the implementation of the main laptop battery monitoring daemon
  *
- * $Id: laptop_daemon.cpp,v 1.50.2.1 2004/03/11 11:41:10 lukas Exp $
+ * $Id: laptop_daemon.cpp,v 1.54 2004/06/26 14:15:02 binner Exp $
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -539,13 +539,13 @@ void laptop_daemon::haveBatteryLow(int t, const int num, const int type)
 	// notify if we must (must be last since it's synchronous)
 	if (s.notify[t]) {
             if (type) {
-                KPassivePopup::message(i18n("Battery power is running out!"),
+                KPassivePopup::message(i18n("Battery power is running out."),
                                        i18n("%1 % charge left.").arg(num),
                                        BarIcon("laptop_battery"), dock_widget,
                                        0, 20000);
             }
             else {
-                KPassivePopup::message(i18n("Battery power is running out!"),
+                KPassivePopup::message(i18n("Battery power is running out."),
                                        i18n("%1 minutes left.").arg(num),
                                        BarIcon("laptop_battery"), dock_widget,
                                        0, 20000);
@@ -677,7 +677,7 @@ void laptop_daemon::checkBatteryNow()
 		knownFullyCharged = 1;
 	} else
 	if (s.notifyMeWhenFull && oldval != val && val == 100)
-		KMessageBox::queuedMessageBox(0, KMessageBox::Information, i18n("Your battery is now fully charged"), i18n("Laptop Battery"));
+		KMessageBox::queuedMessageBox(0, KMessageBox::Information, i18n("Your battery is now fully charged."), i18n("Laptop Battery"));
 	changed =  oldpowered != powered||oldexists != s.exists||oldval != val || oldleft!=left;
 	oldpowered = powered;
 	oldexists = s.exists;
