@@ -36,7 +36,6 @@ public:
     KVaioModule(QWidget *parent, const char *name, const QStringList &);
 
     QString quickHelp() const;
-    const KAboutData* aboutData() const;
     void  save();
     void  load();
     void defaults();
@@ -44,7 +43,6 @@ public:
 protected slots:
     void moduleChanged();
     void timeout();
-    void setBrightness(int);
     void vaioEvent (int);
 private:
     KCMKVaioGeneral *mKVaioGeneral;
