@@ -25,7 +25,6 @@
 
 #include <qlayout.h>
 
-#include <kglobal.h>
 #include <kaboutapplication.h>
 #include <kbugreport.h>
 #include <kaboutdata.h>
@@ -36,7 +35,6 @@ extern "C"
 {
   KPanelExtension *init(QWidget *parent, const QString &configFile)
   {
-    KGlobal::locale()->insertCatalogue("ksim");
     return new KSim::PanelExtension(configFile, KPanelExtension::Normal,
     KPanelExtension::About | KPanelExtension::Help |
     KPanelExtension::Preferences | KPanelExtension::ReportBug,
@@ -49,15 +47,11 @@ KSim::PanelExtension::PanelExtension(const QString &configFile,
    : KPanelExtension(configFile, type, actions, parent, name)
 {
   m_dcopClient = new DCOPClient;
-  m_layout = new QBoxLayout(this, QBoxLayout::TopToBottom);
   m_view = new KSim::MainView(config(), true, this, "m_view");
-  m_layout->addWidget(m_view);
+  m_view->positionChange(orientation());
 
   m_dcopClient->registerAs(name, false);
 
-  QSpacerItem *item = new QSpacerItem(20, 20, QSizePolicy::Fixed, QSizePolicy::Expanding);
-  m_layout->addItem(item);
-
   m_aboutData = new KAboutData(name, I18N_NOOP("KSim"), KSIM_VERSION_STRING,
      I18N_NOOP("A plugin based system monitor for KDE"),
      KAboutData::License_GPL, I18N_NOOP("(C) 2001-2003 Robbie Ward"));
@@ -78,9 +72,14 @@ KSim::PanelExtension::~PanelExtension()
   delete m_dcopClient;
 }
 
-QSize KSim::PanelExtension::sizeHint(Position, QSize) const
+QSize KSim::PanelExtension::sizeHint(Position p, QSize maxSize) const
 {
-  return QSize(m_view->sizeHint().width(), m_view->size().height());
+  return m_view->sizeHint(p, maxSize);
+}
+
+void KSim::PanelExtension::resizeEvent(QResizeEvent *)
+{
+  m_view->resize(size());
 }
 
 KPanelExtension::Position KSim::PanelExtension::preferedPosition() const
@@ -121,18 +120,7 @@ void KSim::PanelExtension::reportBug()
 
 void KSim::PanelExtension::positionChange(Position)
 {
-  // NOTE: ksim looks ugly when in horizontal mode
-  switch (orientation())
-  {
-    case Horizontal:
-      m_layout->setDirection(QBoxLayout::LeftToRight);
-      break;
-    case Vertical:
-      m_layout->setDirection(QBoxLayout::TopToBottom);
-      break;
-    default:
-      break;
-  }
+  m_view->positionChange(orientation());
 }
 
 #include "ksim.moc"
