@@ -54,6 +54,7 @@
 #include <qpainter.h>
 #include <qcursor.h>
 #include <qpopupmenu.h>
+#include <qvbox.h>
 
 #include <unistd.h>
 #include <sys/param.h>
@@ -100,12 +101,18 @@ KSim::MainView::MainView(KConfig *config,
   m_leftFrame = new KSim::Frame(KSim::Types::LeftFrame, this);
   m_sizeLayout->addWidget(m_leftFrame);
 
-  m_pluginLayout = new QVBoxLayout;
+  m_pluginLayout = new QBoxLayout(QBoxLayout::TopToBottom);
   m_sizeLayout->addLayout(m_pluginLayout);
 
+  QVBoxLayout *vb = new QVBoxLayout;
+  QSpacerItem *item = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Expanding);
+  vb->addItem(item);
+  
   m_hostLabel = new KSim::Label(KSim::Types::Host, this);
   m_hostLabel->installEventFilter(this);
-  m_pluginLayout->addWidget(m_hostLabel);
+  vb->addWidget(m_hostLabel);
+  
+  m_pluginLayout->addLayout(vb);
 
   char hostName[MAXHOSTNAMELEN];
   if (gethostname(hostName, sizeof(hostName)))
@@ -119,8 +126,12 @@ KSim::MainView::MainView(KConfig *config,
     m_hostLabel->setText(host);
   }
 
+  vb = new QVBoxLayout;
+  item = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Expanding);
+  vb->addItem(item);
   m_sysinfo = new KSim::Sysinfo(m_config, this);
-  m_pluginLayout->addWidget(m_sysinfo);
+  vb->addWidget(m_sysinfo);
+  m_pluginLayout->addLayout(vb);
 
   m_bottomFrame = new KSim::Frame(KSim::Types::BottomFrame, this);
   m_subLayout->addWidget(m_bottomFrame);
@@ -138,6 +149,8 @@ KSim::MainView::MainView(KConfig *config,
   if (loadPlugins) {
     addPlugins();
   }
+  
+  connect(&m_maskTimer, SIGNAL(timeout()), SLOT(slotMaskMainView()));
 }
 
 KSim::MainView::~MainView()
@@ -147,8 +160,8 @@ KSim::MainView::~MainView()
 
 void KSim::MainView::show()
 {
-  QWidget::show();
   maskMainView();
+  QWidget::show();
 }
 
 void KSim::MainView::cleanup()
@@ -192,15 +205,22 @@ const QString &KSim::MainView::hostname() const
   return m_hostLabel->text();
 }
 
+void KSim::MainView::slotMaskMainView()
+{
+  maskMainView();
+}
+
 void KSim::MainView::maskMainView()
 {
-  parentWidget()->clearMask();
   if (!m_topFrame->background()->mask() ||
       !m_leftFrame->background()->mask() ||
       !m_rightFrame->background()->mask() ||
       !m_bottomFrame->background()->mask())
+  {
+    topLevelWidget()->clearMask();
     return;
-
+  }
+  
   QBitmap topPixmap(*m_topFrame->background()->mask());
   QBitmap leftPixmap(*m_leftFrame->background()->mask());
   QBitmap rightPixmap(*m_rightFrame->background()->mask());
@@ -209,26 +229,32 @@ void KSim::MainView::maskMainView()
   QSize insideSize(m_pluginLayout->geometry().size());
 
   // make a cleared bigrect where we can put our pixmap masks on
-  QBitmap bigBitmap(m_subLayout->geometry().size(), true);
+  QBitmap bigBitmap(topLevelWidget()->size(), true);
 
   // better return if our bitmap is null so we can avoid crashes
   if (bigBitmap.isNull())
     return;
 
+  QPoint ofs = mapTo(topLevelWidget(), QPoint(0,0));
+  int ofsX = ofs.x();
+  int ofsY = ofs.y();
+
   QPainter painter;
   painter.begin(&bigBitmap);
   painter.setBrush(color1);
   painter.setPen(color1);
-  painter.drawRect(m_pluginLayout->geometry());
-  painter.drawPixmap(0, 0, topPixmap);
-  painter.drawPixmap(0, topPixmap.height(), leftPixmap);
-  painter.drawPixmap(insideSize.width() + leftPixmap.width(),
-     topPixmap.height(), rightPixmap);
-  painter.drawPixmap(0, height() - bottomPixmap.height(),
+  QRect rect = m_pluginLayout->geometry();
+  rect.moveBy(ofsX, ofsY);
+  painter.drawRect(rect);
+  painter.drawPixmap(ofsX, ofsY, topPixmap);
+  painter.drawPixmap(ofsX, topPixmap.height()+ofsY, leftPixmap);
+  painter.drawPixmap(ofsX+insideSize.width() + leftPixmap.width(),
+     ofsY+ topPixmap.height(), rightPixmap);
+  painter.drawPixmap(ofsX, ofsY + height() - bottomPixmap.height(),
      bottomPixmap);
 
   painter.end();
-  parentWidget()->setMask(bigBitmap);
+  topLevelWidget()->setMask(bigBitmap);
 }
 
 void KSim::MainView::reparseConfig(bool emitReload,
@@ -272,12 +298,14 @@ void KSim::MainView::reparseConfig(bool emitReload,
   for (it = list.begin(); it != list.end(); ++it) {
     if ((*it).isDifferent()) {
       if ((*it).isEnabled()) { // Go through the added/removed plugins and load/unload them
-        addPlugin((*it).filename());
+        const KDesktopFile kdf((*it).filename());
+        addPlugin(kdf);
         m_prefDialog->createPage((*it).libName());
       }
       else {
         m_prefDialog->removePage((*it).libName());
-        removePlugin((*it).filename());
+        const KDesktopFile kdf((*it).filename());
+        removePlugin(kdf);
       }
     }
   }
@@ -304,13 +332,14 @@ void KSim::MainView::addPlugins()
   QStringList locatedFiles = KGlobal::dirs()->findAllResources("data", "ksim/monitors/*.desktop");
   QStringList::ConstIterator it;
   for (it = locatedFiles.begin(); it != locatedFiles.end(); ++it)
-    addPlugin(*it);
+  {
+    const KDesktopFile kdf(*it, true);
+    addPlugin(kdf);
+  }
 }
 
-void KSim::MainView::addPlugin(const QString& _file, bool force)
+void KSim::MainView::addPlugin(const KDesktopFile &file, bool force)
 {
-  KDesktopFile file(_file);
-
   if (force || m_config->enabledMonitor(file.readEntry("X-KSIM-LIBRARY")))
     KSim::PluginLoader::self().loadPlugin(file);
 }
@@ -371,9 +400,10 @@ void KSim::MainView::preferences()
   destroyPref();
 }
 
-void KSim::MainView::resizeEvent(QResizeEvent *)
+void KSim::MainView::resizeEvent(QResizeEvent *re)
 {
-  maskMainView();
+  QWidget::resizeEvent(re);
+  m_maskTimer.start(0, true);
 }
 
 void KSim::MainView::paletteChange(const QPalette &)
@@ -398,3 +428,39 @@ void KSim::MainView::destroyPref()
     m_prefDialog = 0L;
   }
 }
+
+QSize KSim::MainView::sizeHint(KPanelExtension::Position p, QSize) const
+{
+  int width = 0;
+  int height = 0;
+  
+  QLayoutItem *child;
+  for( QLayoutIterator it = m_pluginLayout->iterator();
+       (child = it.current()) != 0; ++it)
+  {
+     QSize sz = child->minimumSize();
+     if ((p == KPanelExtension::Right) || (p == KPanelExtension::Left))
+     {
+        width = QMAX(width, sz.width());
+        height += sz.height();
+     }
+     else
+     {
+        width += sz.width();
+        height = QMAX(height, sz.height());
+     }
+  }
+
+  width += m_leftFrame->minimumWidth() + m_rightFrame->minimumWidth();
+  height += m_topFrame->minimumHeight() + m_bottomFrame->minimumHeight();
+
+  return QSize(width, height);
+}
+
+void KSim::MainView::positionChange(KPanelExtension::Orientation o)
+{
+  if (o == KPanelExtension::Vertical)
+     m_pluginLayout->setDirection(QBoxLayout::TopToBottom);
+  else
+     m_pluginLayout->setDirection(QBoxLayout::LeftToRight);
+}
