@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #ifndef KSIMNET_H
@@ -27,12 +27,6 @@
 class QTimer;
 class QVBoxLayout;
 class QTextStream;
-namespace KSim
-{
-  class Chart;
-  class LedLabel;
-  class Label;
-}
 
 class NetPlugin : public KSim::PluginObject
 {
@@ -57,49 +51,30 @@ class NetView : public KSim::PluginView
 
   private slots:
     void cleanup();
-    void init(int amount);
     void updateLights();
     void updateGraph();
-    void newNetMonitor(const NetDevice &device, int value);
+    void addDisplay();
     void runConnectCommand(int);
     void runDisconnectCommand(int);
 
+  protected:
+    bool eventFilter(QObject *, QEvent *);
+
   private:
-    class NetData
-    {
-      public:
-        NetData() : in(0), out(0) {}
-        NetData &operator=(const NetData &rhs)
-        {
-          in = rhs.in;
-          out = rhs.out;
-          return *this;
-        }
+    Network::List createList() const;
 
-        NetData &operator=(int value)
-        {
-          in = out = value;
-          return *this;
-        }
-
-        unsigned long in;
-        unsigned long out;
-    };
-
-    DeviceList createDeviceList(int amount) const;
     KSim::Chart *addChart();
     KSim::LedLabel *addLedLabel(const QString &device);
     KSim::Label *addLabel();
     QPopupMenu *addPopupMenu(const QString &device, int value);
+
     void netStatistics(const QString &device, NetData &data);
     bool isOnline(const QString &device);
 
-    NetData *m_data;
-    NetData *m_oldData;
-    unsigned long *m_max;
-    int m_firstTime;
-    DeviceList m_deviceList;
-    DeviceList m_widgetList;
+    void showMenu(int i);
+
+    bool m_firstTime;
+    Network::List m_networkList;
     QTimer *m_netTimer;
     QTimer *m_lightTimer;
     QVBoxLayout *m_netLayout;
@@ -110,6 +85,6 @@ class NetView : public KSim::PluginView
 #ifdef __FreeBSD__
     char *m_buf;
     int m_allocSize;
-#endif	
+#endif
 };
 #endif
