@@ -268,7 +268,7 @@ void NetConfig::getStats()
     if ( ( *it ).name() == netDialog->deviceName() )
     {
       KMessageBox::sorry(0, i18n("You already have a network "
-        "interface by this name. please select a different interface"));
+        "interface by this name. Please select a different interface"));
 
       return;
     }
