@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #include "themeprefs.h"
@@ -66,7 +66,7 @@ KSim::ThemePrefs::ThemePrefs(QWidget *parent, const char *name)
 
   m_label = new QLabel(this);
   m_label->setText(i18n("GKrellm theme support. To use"
-     " gkrellm themes just untar the themes into the directory below"));
+     " gkrellm themes just untar the themes into the folder below"));
   m_label->setAlignment(QLabel::WordBreak |
      QLabel::AlignVCenter | QLabel::AlignLeft);
   m_themeLayout->addMultiCellWidget(m_label, 0, 0, 0, 4);
@@ -75,7 +75,7 @@ KSim::ThemePrefs::ThemePrefs(QWidget *parent, const char *name)
   themeDir += QString::fromLatin1("/themes");
 
   m_urlLabel = new KURLLabel(this);
-  m_urlLabel->setText(i18n("Open Konqueror in KSim's theme directory"));
+  m_urlLabel->setText(i18n("Open Konqueror in KSim's theme folder"));
   m_urlLabel->setURL(QString::fromLatin1("file://") + themeDir);
   connect(m_urlLabel, SIGNAL(leftClickedURL(const QString &)),
      this, SLOT(openURL(const QString &)));
@@ -162,13 +162,7 @@ void KSim::ThemePrefs::setCurrentTheme(const ThemeInfo &theme)
     return;
 
   m_currentTheme = theme;
-  for (QListViewItemIterator it(m_listView); it.current(); it++)
-    if (it.current()->text(0) == theme.name) {
-      m_listView->setSelected(it.current(), true);
-      m_listView->setCurrentItem(it.current());
-      m_listView->ensureItemVisible(it.current());
-      break;
-    }
+  completed();
 }
 
 void KSim::ThemePrefs::setThemeAlts(int alternatives)
@@ -205,14 +199,20 @@ void KSim::ThemePrefs::clear()
 
 void KSim::ThemePrefs::completed()
 {
-  kdDebug() << "Finished listing" << endl;
+  kdDebug(2003) << "Finished listing" << endl;
+
   for (QListViewItemIterator it(m_listView); it.current(); it++)
-    if (it.current()->text(0) == m_currentTheme.name) {
+  {
+    if (it.current()->text(0) == m_currentTheme.name)
+    {
       m_listView->setSelected(it.current(), true);
       m_listView->setCurrentItem(it.current());
       m_listView->ensureItemVisible(it.current());
+
+      selectItem( it.current() );
       break;
     }
+  }
 }
 
 void KSim::ThemePrefs::selectItem(QListViewItem *item)
@@ -232,22 +232,24 @@ void KSim::ThemePrefs::selectItem(QListViewItem *item)
   const KSim::Theme &theme(KSim::ThemeLoader::self().theme(m_currentTheme.url.path()));
   if (theme.name() != "ksim")
     KSim::ThemeLoader::self().parseDir(theme.path(), theme.alternatives());
+
   QToolTip::remove(m_authLabel);
   if (theme.author().isEmpty()) {
     m_authLabel->setText(i18n("None Specified"));
-    QToolTip::add(m_authLabel, i18n("None Specified"));
+    QToolTip::add(m_authLabel, i18n("None specified"));
   }
   else {
     m_authLabel->setText(theme.author());
     QToolTip::add(m_authLabel, theme.author());
   }
 
+  kdDebug( 2003 ) << "theme.alternatives() = " << theme.alternatives() << endl;
   setThemeAlts(theme.alternatives());
 }
 
 void KSim::ThemePrefs::readThemes(const QString &location)
 {
-  kdDebug() << "readThemes(" << location << ")" << endl;
+  kdDebug(2003) << "readThemes(" << location << ")" << endl;
   ThemeInfoList themeList;
   QStringList items(QDir(location).entryList(QDir::Dirs, QDir::IgnoreCase));
   QStringList::ConstIterator it;
