@@ -26,7 +26,7 @@
 #include <kconfig.h>
 #include <kdialog.h>
 #include <kgenericfactory.h>
-#include <klineeditdlg.h>
+#include <kinputdialog.h>
 #include <kpopupmenu.h>
 #include <kwallet.h>
 
@@ -43,6 +43,14 @@ K_EXPORT_COMPONENT_FACTORY(kcm_kwallet, KWalletFactory("kcmkwallet"))
 KWalletConfig::KWalletConfig(QWidget *parent, const char *name, const QStringList&)
 : KCModule(KWalletFactory::instance(), parent, name) {
 
+	KAboutData *about =
+		new KAboutData(I18N_NOOP("kcmkwallet"),
+				I18N_NOOP("KDE Wallet Control Module"),
+				0, 0, KAboutData::License_GPL,
+				I18N_NOOP("(c) 2003 George Staikos"));
+		about->addAuthor("George Staikos", 0, "staikos@kde.org");
+	setAboutData( about );
+
 	_cfg = new KConfig("kwalletrc", false, false);
 
 	QVBoxLayout *vbox = new QVBoxLayout(this, 0, KDialog::spacingHint());
@@ -66,6 +74,11 @@ KWalletConfig::KWalletConfig(QWidget *parent, const char *name, const QStringLis
 
 	updateWalletLists();
 	load();
+
+	if (DCOPClient::mainClient()->isApplicationRegistered("kwalletmanager")) {
+		_wcw->_launch->hide();
+	}
+
 }
 
 
@@ -100,7 +113,7 @@ void KWalletConfig::updateWalletLists() {
 QString KWalletConfig::newWallet() {
 	bool ok;
 
-	QString n = KLineEditDlg::getText(i18n("New Wallet"),
+	QString n = KInputDialog::getText(i18n("New Wallet"),
 			i18n("Please choose a name for the new wallet:"),
 			QString::null,
 			&ok,
@@ -262,17 +275,6 @@ QString KWalletConfig::quickHelp() const {
 }
 
 
-const KAboutData *KWalletConfig::aboutData() const {
-KAboutData *about =
-	new KAboutData(I18N_NOOP("kcmkwallet"),
-			I18N_NOOP("KDE Wallet Control Module"),
-			0, 0, KAboutData::License_GPL,
-			I18N_NOOP("(c) 2003 George Staikos"));
-	about->addAuthor("George Staikos", 0, "staikos@kde.org");
-return about;
-}
-
-
 void KWalletConfig::contextMenuRequested(QListViewItem *item, const QPoint& pos, int col) {
 	Q_UNUSED(col)
 	if (item && item->parent()) {
