@@ -26,15 +26,18 @@
 #include <dcopref.h>
 #include <kaction.h>
 #include <kapplication.h>
+#include <kdebug.h>
+#include <kfiledialog.h>
 #include <kiconview.h>
-#include <kkeydialog.h>
-#include <klineeditdlg.h>
+#include <kio/netaccess.h>
+#include <kinputdialog.h>
 #include <klocale.h>
+#include <kmdcodec.h>
 #include <kmessagebox.h>
 #include <kpopupmenu.h>
 #include <ksqueezedtextlabel.h>
 #include <kstdaction.h>
-#include <kdebug.h>
+#include <ktempfile.h>
 
 #include <qcheckbox.h>
 #include <qcombobox.h>
@@ -143,7 +146,7 @@ KWalletEditor::KWalletEditor(const QString& wallet, bool isPath, QWidget *parent
 		connect(_w, SIGNAL(folderListUpdated()), this, SLOT(updateFolderList()));
 		updateFolderList();
 	} else {
-		kdDebug() << "Wallet open failed!" << endl;
+		kdDebug(2300) << "Wallet open failed!" << endl;
 	}
 
 	createActions();
@@ -166,11 +169,6 @@ KWalletEditor::~KWalletEditor() {
 	}
 }
 
-void KWalletEditor::slotConfigureKeys()
-{
-  KKeyDialog::configure( actionCollection(), this );
-}
-
 void KWalletEditor::createActions() {
 	_newFolderAction = new KAction(i18n("&New Folder..."), "folder_new",
 			0, this, SLOT(createFolder()), actionCollection(),
@@ -190,8 +188,13 @@ void KWalletEditor::createActions() {
 			SLOT(changePassword()), actionCollection(),
 			"change_password");
 
+	_exportAction = new KAction(i18n("&Export..."), 0, 0, this,
+			SLOT(exportXML()), actionCollection(),
+			"export");
+
 	KStdAction::close(this, SLOT(close()), actionCollection());
-        KStdAction::keyBindings( this, SLOT( slotConfigureKeys() ), actionCollection() );
+         KStdAction::keyBindings(guiFactory(), SLOT(configureShortcuts()),
+actionCollection());
 	emit enableFolderActions(_w != 0L);
 	emit enableContextFolderActions(false);
 }
@@ -233,11 +236,11 @@ void KWalletEditor::deleteFolder() {
 	if (_w) {
 		QIconViewItem *ivi = _folderView->currentItem();
 		if (ivi) {
-			int rc = KMessageBox::warningYesNo(this, i18n("Are you sure you wish to delete the folder '%1' from the wallet?").arg(_folderView->currentItem()->text()));
-			if (rc == KMessageBox::Yes) {
-				int rc = _w->removeFolder(ivi->text());
-				if (rc != 0) {
-					KMessageBox::sorry(this, i18n("Error deleting folder.  Error code=%1").arg(rc));
+			int rc = KMessageBox::warningContinueCancel(this, i18n("Are you sure you wish to delete the folder '%1' from the wallet?").arg(_folderView->currentItem()->text()),"",KStdGuiItem::del());
+			if (rc == KMessageBox::Continue) {
+				bool rc = _w->removeFolder(ivi->text());
+				if (!rc) {
+					KMessageBox::sorry(this, i18n("Error deleting folder.  Error code=%1").arg((int)rc));
 					return;
 				}
 				updateFolderList();
@@ -254,7 +257,7 @@ void KWalletEditor::createFolder() {
 		bool ok;
 
 		do {
-			n = KLineEditDlg::getText(i18n("New Folder"),
+			n = KInputDialog::getText(i18n("New Folder"),
 					i18n("Please choose a name for the new folder:"),
 					QString::null,
 					&ok,
@@ -519,7 +522,7 @@ void KWalletEditor::newEntry() {
 	bool ok;
 
 	do {
-		n = KLineEditDlg::getText(i18n("New Entry"),
+		n = KInputDialog::getText(i18n("New Entry"),
 				i18n("Please choose a name for the new entry:"),
 				QString::null,
 				&ok,
@@ -602,8 +605,8 @@ void KWalletEditor::listItemRenamed(QListViewItem* item, int, const QString& t)
 void KWalletEditor::deleteEntry() {
 QListViewItem *item = _entryList->selectedItem();
 	if (_w && item) {
-		int rc = KMessageBox::warningYesNo(this, i18n("Are you sure you wish to delete the item '%1'?").arg(item->text(0)));
-		if (rc == KMessageBox::Yes) {
+		int rc = KMessageBox::warningContinueCancel(this, i18n("Are you sure you wish to delete the item '%1'?").arg(item->text(0)),"",KStdGuiItem::del());
+		if (rc == KMessageBox::Continue) {
 			_w->removeEntry(item->text(0));
 			delete item;
 			entrySelectionChanged(_entryList->currentItem());
@@ -656,5 +659,70 @@ void KWalletEditor::showHideMapEditorValue(bool show) {
 }
 
 
+void KWalletEditor::exportXML() {
+KTempFile tf;
+tf.setAutoDelete(true);
+QTextStream& ts(*tf.textStream());
+QStringList fl = _w->folderList();
+
+	ts << "<wallet name=\"" << _walletName << "\">" << endl;
+	for (QStringList::Iterator i = fl.begin(); i != fl.end(); ++i) {
+		ts << "  <folder name=\"" << *i << "\">" << endl;
+		_w->setFolder(*i);
+		QStringList entries = _w->entryList();
+		for (QStringList::Iterator j = entries.begin(); j != entries.end(); ++j) {
+			switch (_w->entryType(*j)) {
+				case KWallet::Wallet::Password:
+					{
+						QString pass;
+						if (_w->readPassword(*j, pass) == 0) {
+							ts << "    <password name=\"" << QStyleSheet::escape(*j) << "\">";
+							ts << QStyleSheet::escape(pass);
+							ts << "</password>" << endl;
+						}
+						break;
+					}
+				case KWallet::Wallet::Stream:
+					{
+						QByteArray ba;
+						if (_w->readEntry(*j, ba) == 0) {
+							ts << "    <stream name=\"" << QStyleSheet::escape(*j) << "\">";
+							ts << KCodecs::base64Encode(ba);
+
+							ts << "</stream>" << endl;
+						}
+						break;
+					}
+				case KWallet::Wallet::Map:
+					{
+						QMap<QString,QString> map;
+						if (_w->readMap(*j, map) == 0) {
+							ts << "    <map name=\"" << QStyleSheet::escape(*j) << "\">" << endl;
+							for (QMap<QString,QString>::ConstIterator k = map.begin(); k != map.end(); ++k) {
+								ts << "      <mapentry name=\"" << QStyleSheet::escape(k.key()) << "\">" << QStyleSheet::escape(k.data()) << "</mapentry>" << endl;
+							}
+							ts << "    </map>" << endl;
+						}
+						break;
+					}
+				case KWallet::Wallet::Unknown:
+				default:
+					break;
+			}
+		}
+		ts << "  </folder>" << endl;
+	}
+
+	ts << "</wallet>" << endl;
+	tf.close();
+
+	KURL url = KFileDialog::getSaveURL(QString::null, "*.xml", this);
+
+	if (!url.isEmpty()) {
+		KIO::NetAccess::upload(tf.name(), url, this);
+	}
+}
+
+
 #include "kwalleteditor.moc"
 
